-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2011.  All Rights Reserved.
-- US Government Users Restricted Rights - Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- ------------------------------------------------------------------------------------
--
-- Script file to create database and tablespaces for SQL Server UDB 
--
-- ------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script:
-- @COG_DB_NAME@ = the database name, eg CCS

-- @COG_DB_USER@ = database user for the monitor schema
-- @COG_DB_PASSWORD@ = the database user password
--
--    For a database install with enhanced security:
--    Remove the following three lines in the script:
--
--        -- Add the monitor user to the db_owner role
--        EXEC sp_addrolemember 'db_owner', @COG_DB_USER@
--        GO 
--
--    then follow the instructions in the createTables.sql script.
--
-- Run the script in the sqlcmd command line processor
--
-- USAGE:  sqlcmd -U <userid> -P <password> -e -i createDatabase.sql
--
-- ------------------------------------------------------------------------------------
-- create the database
USE master
CREATE DATABASE @COG_DB_NAME@ COLLATE SQL_Latin1_General_CP1_CI_AS
GO

USE master;
-- Create a login for the monitor database user if is does not exist
IF NOT EXISTS (SELECT * FROM syslogins WHERE NAME = '@COG_DB_USER@') CREATE LOGIN @COG_DB_USER@ WITH PASSWORD = '@COG_DB_PASSWORD@', DEFAULT_DATABASE=@COG_DB_NAME@;

-- Create a database user for the monitor user
IF NOT EXISTS (SELECT * FROM sysusers WHERE NAME = '@COG_DB_USER@') CREATE USER @COG_DB_USER@ FOR LOGIN @COG_DB_USER@;
GO

-- Add monitor user the XA JDBC role
EXEC sp_addrolemember [SqlJDBCXAUser], @COG_DB_USER@
GO

USE @COG_DB_NAME@

-- Add the user to the MONITOR databaes
EXEC sp_adduser @COG_DB_USER@
GO


-- The following grants are required by COGNOS for schema creation.
-- Following successful COGNOS initialization and initial schema creation,
-- the addition privileges can be removed by the following commands:
--
--  EXEC sp_droprolemember 'db_datawriter', @COG_DB_USER@
--  GO 
--  EXEC sp_droprolemember 'db_ddladmin', @COG_DB_USER@
--  GO 


-- Add the monitor user to the db_datareader role
EXEC sp_addrolemember 'db_datareader', @COG_DB_USER@
GO 
-- Add the monitor user to the db_datawriter role
EXEC sp_addrolemember 'db_datawriter', @COG_DB_USER@
GO 
-- Add the monitor user to the db_ddladmin role
EXEC sp_addrolemember 'db_ddladmin', @COG_DB_USER@
GO 


