-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2007, 2011. All Rights Reserved.
-- US Government Users Restricted Rights- Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- ------------------------------------------------------------------------------------
--
-- Script file to upgrade database from v6.1 to v8.0 for DB2 UDB 
--
-- ------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script:
-- @SCHEMA@ = the schema name, eg MONITOR
-- @TSDIR@ = the directory or prefix for tablespace datafiles, eg DEFAULTTS
--
-- Run the script in the DB2 command line processor with admin privileges.
--
-- USAGE:   db2 -tf upgradeSchema610.sql
--
-- ------------------------------------------------------------------------------------


------------- user temporary tablespace (temp)
-- User Temporary Tablespace added for MQT Support
CREATE USER TEMPORARY TABLESPACE UTMPTS32K PAGESIZE 32 K  
MANAGED BY SYSTEM USING ('@TSDIR@_UTMPTS32K' ) 
EXTENTSIZE 8 OVERHEAD 10.5 PREFETCHSIZE 32 TRANSFERRATE 0.14 
BUFFERPOOL TMPBP32K;

---------------------------------------------------------CHANGED:  SCHEMA_VERSION
DELETE FROM @SCHEMA@.SCHEMA_VERSION;
INSERT INTO @SCHEMA@.SCHEMA_VERSION 
        (SCHEMA_VERSION, DATA_MIGRATION) 
        VALUES( 80, 0 );

---------------------------------------------------------------OLD:  UNIQUE_KEY_T
DROP TABLE @SCHEMA@.UNIQUE_KEY_T;

---------------------------------------------------------------OLD:  KEY_HELPER_T
DROP TABLE @SCHEMA@.KEY_HELPER_T;

-----------------------------------------------------------NEW: MODERATOR_NEXT_ID
CREATE TABLE @SCHEMA@.MODERATOR_NEXT_ID  
(
  MODEL_ID                      VARCHAR(256) NOT NULL,
  UNIQUE_ID_KEY                 VARCHAR(256) NOT NULL, 
  START_ID_OF_NEXT_SET          BIGINT NOT NULL, 
  PRIMARY KEY ( MODEL_ID, UNIQUE_ID_KEY )
) IN DSTS32K;

-------------------------------------------------------------NEW: RECORD/PLAYBACK
CREATE TABLE @SCHEMA@.RECORDED_EVENTS
(
  ID                                 BIGINT NOT NULL GENERATED ALWAYS AS IDENTITY,
  PAYLOAD_VARCHAR                    VARCHAR(30000) FOR BIT DATA,
  PAYLOAD_BLOB                       BLOB(1048576000),
  TIME_RECORDED                      TIMESTAMP DEFAULT CURRENT TIMESTAMP,
  BACKUP_ID                          VARCHAR(32),
  PRIMARY KEY ( ID )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.RECORDED_EVENTS_MODELVERSIONS
(
  EVENT_ID                           BIGINT NOT NULL, 
  MODEL_ID                           VARCHAR(128) NOT NULL,
  VERSION                            BIGINT NOT NULL,
  PRIMARY KEY ( EVENT_ID, MODEL_ID, VERSION ),
  FOREIGN KEY ( EVENT_ID ) REFERENCES @SCHEMA@.RECORDED_EVENTS( ID ) ON DELETE CASCADE
) IN DSTS32K;

---------------------------------------------------------------NEW: KPI_HISTORY_T
CREATE TABLE @SCHEMA@.KPI_HISTORY_T
(
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  KPI_DYNAMIC_FILTER_VALUE           VARCHAR(500)                      NOT NULL ,
  PERIOD_TIMESTAMP                   TIMESTAMP                         NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  OBSERVED_TIME                      TIMESTAMP                                  ,
  OBSERVED_VALUE                     DOUBLE                                     ,
  TARGET                             DOUBLE                                     ,
  HISTORY_UPDATE_TIME                TIMESTAMP                                  ,
  HISTORY_VALUE                      DOUBLE                                     ,
  PREDICTION_BASIS_VALUE             DOUBLE                                     ,
  PREDICTION_BASIS_TIME              TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_ID, VERSION, KPI_DYNAMIC_FILTER_VALUE, PERIOD_TIMESTAMP )
) IN DSTS32K;

--------------------------------------------------------------NEW: KPI_PREDICTION
CREATE TABLE @SCHEMA@.KPI_TS_PREDICTION_T
(
  KPI_PREDICTION_ID                  VARCHAR(512)                      NOT NULL ,
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  PREDICTION_MODEL_ID                VARCHAR(384)                      NOT NULL ,
  PREDICTED_FOR_TIME                 TIMESTAMP                                  ,
  PREDICTED_VALUE                    DOUBLE                                     ,
  LAST_KPI_TIME                      TIMESTAMP                         NOT NULL ,
  STANDARD_DEVIATION                 DOUBLE                                     ,
  VALUE_PLUS_STDDEV                  DOUBLE                                     ,
  VALUE_MINUS_STDDEV                 DOUBLE                                     ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_PREDICTION_ID, VERSION, LAST_KPI_TIME )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.KPI_TS_PREDICTION_MODEL_T
(
  PREDICTION_MODEL_ID                VARCHAR(384)                      NOT NULL ,
  PREDICTION_MODEL_NAME              VARCHAR(256)                      NOT NULL ,
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  MODEL_ID                           VARCHAR(128)                               ,
  KPI_DYNAMIC_FILTER_VALUE           VARCHAR(500)                               ,
  MODEL_XML                          BLOB(1000M)                                ,
  PREDICTION_HORIZON                 INTEGER                                    ,
  PREDICT_TO_PERIOD_END              SMALLINT                          NOT NULL ,
  PREDICTION_INTERVAL_NUM            INTEGER                                    ,
  PREDICTION_INTERVAL_UNIT           SMALLINT                                   ,
  INTERVALS_PER_CYCLE                INTEGER                                    ,
  CYCLE_LENGTH_UNIT                  SMALLINT                                   ,
  KPI_BEHAVIOR                       SMALLINT                                   ,
  PREDICTION_SUBMODEL_ID             VARCHAR(384)                               ,
  MODEL_OPTIMIZE_SCHEDULE            SMALLINT                                   ,
  CREATION_USER_ID                   VARCHAR(256)                               ,
  UPDATE_USER_ID                     VARCHAR(256)                               ,
  NEXT_EVAL_TIME                     TIMESTAMP                                  ,
  NEXT_OPTIMIZE_TIME                 TIMESTAMP                                  ,
  CREATION_TIME                      TIMESTAMP                                  ,
  UPDATE_TIME                        TIMESTAMP                                  ,
  INITIAL_KPI_TIME                   TIMESTAMP                                  ,
  LAST_KPI_TIME                      TIMESTAMP                                  ,
  PREDICTION_LAST_RUN                TIMESTAMP                                  ,
  TIME_LAST_OPTIMIZED                TIMESTAMP                                  ,
  IS_VALID                           SMALLINT                          NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( PREDICTION_MODEL_ID, VERSION )
) IN DSTS32K;

---------------------------------------------------------------NEW: WAS SCHEDULER
CREATE TABLE @SCHEMA@.MONSCHED_TASK  
(
  TASKID BIGINT NOT NULL , 
  VERSION VARCHAR(5) NOT NULL , 
  ROW_VERSION INTEGER NOT NULL , 
  TASKTYPE INTEGER NOT NULL , 
  TASKSUSPENDED SMALLINT NOT NULL , 
  CANCELLED SMALLINT NOT NULL , 
  NEXTFIRETIME BIGINT NOT NULL , 
  STARTBYINTERVAL VARCHAR(254) , 
  STARTBYTIME BIGINT , 
  VALIDFROMTIME BIGINT , 
  VALIDTOTIME BIGINT , 
  REPEATINTERVAL VARCHAR(254) , 
  MAXREPEATS INTEGER NOT NULL , 
  REPEATSLEFT INTEGER NOT NULL , 
  TASKINFO BLOB(102400) LOGGED NOT COMPACT , 
  NAME VARCHAR(254) NOT NULL , 
  AUTOPURGE INTEGER NOT NULL , 
  FAILUREACTION INTEGER , 
  MAXATTEMPTS INTEGER , 
  QOS INTEGER , 
  PARTITIONID INTEGER , 
  OWNERTOKEN VARCHAR(200) NOT NULL , 
  CREATETIME BIGINT NOT NULL 
) IN DSTS32K; 

ALTER TABLE @SCHEMA@.MONSCHED_TASK ADD PRIMARY KEY(TASKID);

CREATE INDEX @SCHEMA@.MONSCHED_TASK_IDX1 ON @SCHEMA@.MONSCHED_TASK 
		(TASKID ASC, OWNERTOKEN ASC) ALLOW REVERSE SCANS;

CREATE INDEX @SCHEMA@.MONSCHED_TASK_IDX2 ON @SCHEMA@.MONSCHED_TASK 
		(NEXTFIRETIME ASC, REPEATSLEFT ASC, PARTITIONID ASC) CLUSTER ALLOW REVERSE SCANS;

CREATE TABLE @SCHEMA@.MONSCHED_TREG  
(
  REGKEY VARCHAR(254) NOT NULL , 
  REGVALUE VARCHAR(254) 
) IN DSTS32K ; 

CREATE TABLE @SCHEMA@.MONSCHED_LMGR  
(
  LEASENAME VARCHAR(254) NOT NULL , 
  LEASEOWNER VARCHAR(254) NOT NULL , 
  LEASE_EXPIRE_TIME BIGINT , 
  DISABLED VARCHAR(5) 
) IN DSTS32K ; 

CREATE TABLE @SCHEMA@.MONSCHED_LMPR  
(
  LEASENAME VARCHAR(254) NOT NULL , 
  NAME VARCHAR(254) NOT NULL , 
  VALUE VARCHAR(254) NOT NULL 
) IN DSTS32K ; 

CREATE INDEX @SCHEMA@.MONSCHED_LMPR_IDX1 ON @SCHEMA@.MONSCHED_LMPR 
		(LEASENAME ASC, NAME ASC) ALLOW REVERSE SCANS;

----------------------------------------------------------------NEW: DS SCHEDULER
CREATE TABLE @SCHEMA@.DSS_MODEL_CONFIG_T
(
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  PRIORITY                           BIGINT                            NOT NULL ,
  STATUS                             BIGINT                            NOT NULL ,
  LAST_STARTED                       TIMESTAMP                                  ,
  LAST_COMPLETED                     TIMESTAMP                                  ,
  LAST_RUN_STATUS                    BIGINT                                     ,
  TASK_ID                            VARCHAR(128)                               ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MODEL_ID)  
) IN DSTS32K;

CREATE TABLE @SCHEMA@.DSS_MODEL_SERVICE_CONFIG_T
(
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  SERVICE_NAME                       VARCHAR(128)                      NOT NULL ,
  SERVICE_PRIORITY                   BIGINT                            NOT NULL ,
  SERVICE_INTERVAL                   BIGINT                            NOT NULL ,
  SERVICE_INT_UNIT                   BIGINT                            NOT NULL ,
  START_TIME                         TIMESTAMP                         NOT NULL ,
  STATUS                             BIGINT                            NOT NULL ,
  LAST_STARTED                       TIMESTAMP                                  ,
  LAST_COMPLETED                     TIMESTAMP                                  ,
  LAST_RUN_STATUS                    BIGINT                                     ,
  NEXT_EVALUATION                    TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MODEL_ID, SERVICE_NAME )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.DSS_MODEL_SERVICE_VER_CONFIG_T
(
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  SERVICE_NAME                       VARCHAR(128)                      NOT NULL ,
  STATUS                             BIGINT                            NOT NULL ,
  LAST_STARTED                       TIMESTAMP                                  ,
  LAST_COMPLETED                     TIMESTAMP                                  ,
  LAST_RUN_STATUS                    BIGINT                                     ,
  MESSAGE                            VARCHAR(4000)                              ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MODEL_ID, VERSION, SERVICE_NAME)  
) IN DSTS32K;

CREATE TABLE @SCHEMA@.DSS_MODEL_CUBE_STATUS_T
(
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MC_ID                              VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  SERVER                             VARCHAR(128)                      NOT NULL ,
  IS_STALE                           SMALLINT                          NOT NULL ,
  STALE_TIME                         TIMESTAMP                                  ,
  FRESH_TIME                         TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MODEL_ID, MC_ID, VERSION, SERVER )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.DSS_MODEL_ARCHIVE_VER_CONFIG_T
(
  MODEL_ID		                VARCHAR(128)	                NOT NULL ,
  VERSION             	                BIGINT   	                NOT NULL ,	
  OPERATION_NAME 	                VARCHAR(32)	                NOT NULL ,  	
  TIME_SPAN                      	VARCHAR(128)            	NOT NULL ,
  PATH_NAME           	                VARCHAR(1000)                            ,		
  LAST_TIMESTAMP  	                VARCHAR(32)                              ,	    		
  APPEND_FLAG     	                SMALLINT                                 ,	
  MAX_FILE_SIZE  	                BIGINT                                   ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MODEL_ID, VERSION )
) IN DSTS32K;

---------------------------------------------------------------NEW: DYNAMIC ALERT
CREATE TABLE @SCHEMA@.ACT_SITUATION_T
(
  ID                                 VARCHAR(384)                      NOT NULL ,
  DISPLAY_NAME                       VARCHAR(1000)                     NOT NULL ,
  DESCRIPTION                        VARCHAR(256)                               ,
  ACTIVE                             BIGINT                            NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  REPEATING                          SMALLINT                          NOT NULL ,
  INTERVAL                           SMALLINT                          NOT NULL ,
  TIME_POINT                         BIGINT                            NOT NULL ,
  TIME_MULTIPLE                      BIGINT                            NOT NULL ,
  TIME_OFFSET                        BIGINT                            NOT NULL ,
  TIME_ZONE                          VARCHAR(60)                       NOT NULL ,
  KPI_ID                             VARCHAR(384)                               ,
  TIME_PROPERTIES                    CLOB(1048576)                              ,
  START_TIME                         TIMESTAMP                         NOT NULL ,
  LAST_EVAL                          TIMESTAMP                                  ,
  NEXT_EVAL                          TIMESTAMP                         NOT NULL ,
  SIT_TRIGGERED                      SMALLINT                          NOT NULL ,
  USER_ID                            VARCHAR(256)                      NOT NULL ,
  VIEW_ACCESS                        SMALLINT                          NOT NULL ,
  CREATE_TIME                        TIMESTAMP                         NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ID )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.ACT_SIT_TRIG_T
(
  ID                                 VARCHAR(384)                      NOT NULL ,
  SITUATION_ID                       VARCHAR(384)                      NOT NULL ,
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  PREDICTION_MODEL_ID                VARCHAR(384)                               ,
  PREDICTION_TYPE                    VARCHAR(20)                                ,
  TYPE                               VARCHAR(256)                      NOT NULL ,
  FIELD_TYPE                         VARCHAR(256)                      NOT NULL ,
  FIELD                              VARCHAR(256)                               ,
  COND_SETUP                         SMALLINT                                   ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ID )
) IN DSTS32K;

------------------------------------------------------------NEW: DIRECT TO DEPLOY

CREATE TABLE @SCHEMA@.D2D_ITEM (
  ID                                    VARCHAR(255)                    NOT NULL , 
  STATE                                 VARCHAR(20)                     NOT NULL ,
  ITEM_LEVEL                            INTEGER                         NOT NULL ,
  MODULE_NAME                           VARCHAR(255)                             ,
  APPLICATION_NAME                      VARCHAR(255)                             ,
  VERSION                               VARCHAR(30)                              , 
  NEW_APP_NAME                          VARCHAR(255)                             ,
  PRIMARY KEY ( ID ) 
) IN DSTS32K;

CREATE TABLE @SCHEMA@.D2D_PROGRESS (
  ITEM_ID                               VARCHAR(255)                    NOT NULL ,
  PROGRESS                              INTEGER                                  ,
  PROGRESS_MSG                          VARCHAR(255)                             ,
  PROGRESS_ERROR_CODE                   VARCHAR(255)                             ,
  PRIMARY KEY (ITEM_ID) ,
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) ON DELETE CASCADE
) IN DSTS32K;

CREATE TABLE @SCHEMA@.D2D_CONTENT (
  ITEM_ID                               VARCHAR(255)                    NOT NULL ,
  PI                                    BLOB(1000M)                                     ,
  PRIMARY KEY (ITEM_ID) ,
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) ON DELETE CASCADE
) IN DSTS32K;

CREATE TABLE @SCHEMA@.D2D_METADATA (
  ITEM_ID                               VARCHAR(255)                    NOT NULL ,
  NAME                                  VARCHAR(255)                    NOT NULL ,
  VALUE                                 VARCHAR(255)                             ,
  PRIMARY KEY ( ITEM_ID, NAME ) ,
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) ON DELETE CASCADE
) IN DSTS32K;

CREATE TABLE @SCHEMA@.D2D_LOCK (
  LOCK_ID                               CHARACTER(2)                    NOT NULL ,
  LASTUPDATE                            TIMESTAMP                                ,
  PRIMARY KEY ( LOCK_ID )
) IN DSTS32K;

INSERT INTO @SCHEMA@.D2D_LOCK VALUES ('N1', NULL);
INSERT INTO @SCHEMA@.D2D_LOCK VALUES ('N2', NULL);

CREATE TABLE @SCHEMA@.D2D_MESSAGE (
  ITEM_ID                               VARCHAR(255)                    NOT NULL ,
  SEQ                                   INTEGER                         NOT NULL ,
  ID                                    VARCHAR(63)                              ,
  DESCRIPTION                           VARCHAR(1024)                            ,
  MSG_RESOURCE                          VARCHAR(255)                             ,
  LOCATION                              VARCHAR(63)                              ,
  FOLDER                                VARCHAR(255)                             ,
  MSG_STR                               VARCHAR(63)                              ,
  TAG	                                VARCHAR(63)                              ,
  SEVERITY                              VARCHAR(15)                              ,
  TIME                                  TIMESTAMP                                ,
  PRIMARY KEY ( ITEM_ID, SEQ ) ,
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) ON DELETE CASCADE
) IN DSTS32K;

------------------------------------------------------------CHANGED: META_MODEL_T
ALTER TABLE @SCHEMA@.META_MODEL_T 
        ADD COLUMN CODE_GEN_VERSION             VARCHAR(8)
        ADD COLUMN BUILD_ID                     VARCHAR(40);

--------------------------------------------------CHANGED: META_MONITOR_CONTEXT_T
ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T 
        ALTER COLUMN CUBE_NAME SET DATA TYPE    VARCHAR(1000);

--------------------------------------------------------CHANGED: META_DIMENSION_T
ALTER TABLE @SCHEMA@.META_DIMENSION_T 
        ADD COLUMN ABX_DISPLAY_NAME             VARCHAR(1000);

---------------------------------------------------------CHANGED: META_DIM_ATTR_T
ALTER TABLE @SCHEMA@.META_DIM_ATTR_T
        ADD COLUMN ABX_DIM_ATTR_NAME            VARCHAR(1000);

----------------------------------------------------------CHANGED: META_MEASURE_T
ALTER TABLE @SCHEMA@.META_MEASURE_T
        ADD COLUMN ABX_DISPLAY_NAME             VARCHAR(1000);

--------------------------------------------------------------CHANGED: META_KPI_T
ALTER TABLE @SCHEMA@.META_KPI_T 
        ADD COLUMN ENABLE_KPI_HISTORY           SMALLINT 
        ADD COLUMN ENABLE_KPI_PREDICTIONS       SMALLINT 
        ADD COLUMN HISTORY_VALID_FROM           TIMESTAMP                                 
        ADD COLUMN HIST_GRANULARITY             SMALLINT                                   
        ADD COLUMN HIST_REPEATING_PERIOD_BASIS  SMALLINT                                   
        ADD COLUMN HIST_REPEATING_PERIOD_DURATION SMALLINT                                   
        ADD COLUMN HIST_REPEATING_PERIOD_QUANTITY INTEGER 
        ADD COLUMN HIST_ROLLING_PERIOD_DURATION SMALLINT                                   
        ADD COLUMN HIST_ROLLING_PERIOD_QUANTITY INTEGER                                    
        ADD COLUMN HIST_TIME_RANGE_START        TIMESTAMP                                  
        ADD COLUMN HIST_TIME_RANGE_END          TIMESTAMP                                  
        ADD COLUMN HIST_TIMEZONE                VARCHAR(30)                                
        ADD COLUMN HIST_INCLUDE_PREDICTIONS     SMALLINT  
        ADD COLUMN HIST_ALL_VERSIONS            SMALLINT  
        ADD COLUMN HIST_TIME_RANGE_METHOD       SMALLINT                                   
        ADD COLUMN HIST_DISPLAY_TARGET          SMALLINT  
        ADD COLUMN HIST_DISPLAY_RANGES          SMALLINT 
        ADD COLUMN HIST_RETRO_ACTIVE_CALC_QTY   INTEGER 
        ADD COLUMN DEFAULT_PREDICTION_MODEL_ID  VARCHAR(384);

       
----------------------------------------------------------------CHANGED: DIM_TIME
ALTER TABLE @SCHEMA@.DIM_TIME 
        ADD COLUMN MONTH_NAME VARCHAR(27) NOT NULL DEFAULT 'unknown';

UPDATE @SCHEMA@.DIM_TIME
   SET MONTH_NAME =
        CASE
                   WHEN MONTH_NUM = 1  THEN 'January'
                   WHEN MONTH_NUM = 2  THEN 'February'
                   WHEN MONTH_NUM = 3  THEN 'March'
                   WHEN MONTH_NUM = 4  THEN 'April'
                   WHEN MONTH_NUM = 5  THEN 'May'
                   WHEN MONTH_NUM = 6  THEN 'June'
                   WHEN MONTH_NUM = 7  THEN 'July'
                   WHEN MONTH_NUM = 8  THEN 'August'
                   WHEN MONTH_NUM = 9  THEN 'September'
                   WHEN MONTH_NUM = 10 THEN 'October'
                   WHEN MONTH_NUM = 11 THEN 'November'
                   WHEN MONTH_NUM = 12 THEN 'December'
                   ELSE 'Error'
        END; 


---------------------------------------------------------CHANGED: RAT_PARTY_ROLES
ALTER TABLE @SCHEMA@.RAT_PARTY_ROLES
        ADD COLUMN MEMBER_TYPE             VARCHAR(20);

----------------------------------------------------------CHANGED: ACT_MGR_ALERTS
ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T
        ALTER COLUMN BUS_SIT_NAME SET DATA TYPE    VARCHAR(384) 
;

---------------------------------------------------CHANGED: ACTION_HANLDER_CTRL_T
ALTER TABLE @SCHEMA@.ACTION_HANDLER_CTRL_T
        ALTER COLUMN ACTION_ID    SET DATA TYPE    VARCHAR(384) 
;

-------------------------------------------------------------CHANGED: ACT_TMPLT_T
ALTER TABLE @SCHEMA@.ACT_TMPLT_T
        ALTER COLUMN ID           SET DATA TYPE    VARCHAR(384) 
	ALTER COLUMN NAME	  SET DATA TYPE    VARCHAR(384) 
;

----------------------------------------------------------------CHANGED: ACTION_T
ALTER TABLE @SCHEMA@.ACTION_T
        ALTER COLUMN ID           SET DATA TYPE    VARCHAR(384) 
	ALTER COLUMN TEMPLATE_ID  SET DATA TYPE    VARCHAR(384)
;

-------------------------------------------------------CHANGED: SUBSCRIBED_USER_T
ALTER TABLE @SCHEMA@.SUBSCRIBED_USER_T
        ALTER COLUMN ETAACTRL_ID  SET DATA TYPE    VARCHAR(384) 
;

--------------------------------------------------------------CHANGED: ETAMATCH_T
ALTER TABLE @SCHEMA@.ETAMATCH_T
        ALTER COLUMN ID           SET DATA TYPE    VARCHAR(384) 
	ALTER COLUMN EXTENSION_NAME SET DATA TYPE  VARCHAR(384) 
;

--------------------------------------------------------------CHANGED: ETAACTRL_T
ALTER TABLE @SCHEMA@.ETAACTRL_T
        ALTER COLUMN ID           SET DATA TYPE    VARCHAR(384) 
	ALTER COLUMN ETAMID	  SET DATA TYPE    VARCHAR(384) 
	ALTER COLUMN ACTION_ID    SET DATA TYPE    VARCHAR(384) 
	ALTER COLUMN NAME         SET DATA TYPE    VARCHAR(1000) 
;

---------- ALPHABLOX TABLES

CREATE TABLE @SCHEMA@.ABX_VERSION 
(
  DESCRIPTION                           VARCHAR(32)       NOT NULL, 
  VALUE                                 VARCHAR(64)       NOT NULL 
) IN DSTS32K; 


CREATE UNIQUE INDEX @SCHEMA@.IVERSIONDESC ON @SCHEMA@.ABX_VERSION
  ("DESCRIPTION" ASC)
  CLUSTER ALLOW REVERSE SCANS;


CREATE TABLE @SCHEMA@.ABX_PROPERTY_MAP
(
  ID                                    INTEGER           NOT NULL, 
  PROPERTY                              VARCHAR(255)      NOT NULL, 
  SEQUENCE                              INTEGER           NOT NULL, 
  VALUE                                 VARCHAR(255) 
)  IN DSTS32K; 


CREATE UNIQUE INDEX @SCHEMA@.IPROPERTYIDPROPSEQ ON @SCHEMA@.ABX_PROPERTY_MAP
  (ID ASC, PROPERTY ASC, SEQUENCE ASC)
  CLUSTER ALLOW REVERSE SCANS;


CREATE INDEX @SCHEMA@.IPROPERTYPROPSEQ ON @SCHEMA@.ABX_PROPERTY_MAP 
  (PROPERTY ASC, SEQUENCE ASC)
  ALLOW REVERSE SCANS;


CREATE TABLE @SCHEMA@.ABX_OBJECTS
(
  ID                                    INTEGER           NOT NULL, 
  SEQUENCE                              INTEGER           NOT NULL, 
  VALUE                                 VARCHAR(3900)     NOT NULL
) IN DSTS32K;


CREATE UNIQUE INDEX @SCHEMA@.IOBJECTIDSEQ ON @SCHEMA@.ABX_OBJECTS
  (ID ASC, SEQUENCE ASC)
  ALLOW REVERSE SCANS;
 

CREATE TABLE @SCHEMA@.ABX_LOOKUP  
(
  ID                                    INTEGER           NOT NULL, 
  CONTEXT                               VARCHAR(255),
  NAME                                  VARCHAR(96)       NOT NULL, 
  TYPE                                  INTEGER           NOT NULL, 
  LAST_MODIFIED                         TIMESTAMP WITH DEFAULT CURRENT TIMESTAMP
) IN DSTS32K;


ALTER TABLE @SCHEMA@.ABX_LOOKUP 
  ADD CONSTRAINT PKABX_LOOKUPID PRIMARY KEY (ID);


CREATE UNIQUE INDEX @SCHEMA@.ILOOKUPCONTEXTNAME ON @SCHEMA@.ABX_LOOKUP
  (CONTEXT ASC, NAME ASC)
  INCLUDE (ID, TYPE)
  ALLOW REVERSE SCANS;


CREATE TABLE @SCHEMA@.ABX_TYPES
(
  ID                                    INTEGER           NOT NULL, 
  DESCRIPTION                           VARCHAR(64)       NOT NULL, 
  INTERNAL_NAME                         VARCHAR(64)       NOT NULL 
) IN DSTS32K;


CREATE UNIQUE INDEX @SCHEMA@.ITYPESID ON @SCHEMA@.ABX_TYPES 
  (ID ASC)
  CLUSTER ALLOW REVERSE SCANS;
 

CREATE TABLE @SCHEMA@.ABX_LOOKUP_VALUES
(
  DESCRIPTION                           VARCHAR(16)       NOT NULL, 
  VALUE                                 INTEGER           NOT NULL 
) IN DSTS32K;


CREATE UNIQUE INDEX @SCHEMA@.ILOOKUPVALUEDESC ON @SCHEMA@.ABX_LOOKUP_VALUES
  (DESCRIPTION ASC)
  CLUSTER ALLOW REVERSE SCANS;

ALTER TABLE @SCHEMA@.ABX_PROPERTY_MAP
  ADD CONSTRAINT FKABX_PROP_MAPID FOREIGN KEY
    (ID)
  REFERENCES @SCHEMA@.ABX_LOOKUP
    (ID)
  ON DELETE NO ACTION
  ON UPDATE NO ACTION
  ENFORCED
  ENABLE QUERY OPTIMIZATION;

ALTER TABLE @SCHEMA@.ABX_OBJECTS
  ADD CONSTRAINT FKABX_OBJECTSID FOREIGN KEY
    (ID)
  REFERENCES @SCHEMA@.ABX_LOOKUP
    (ID)
  ON DELETE NO ACTION
  ON UPDATE NO ACTION
  ENFORCED
  ENABLE QUERY OPTIMIZATION;

INSERT INTO @SCHEMA@.ABX_LOOKUP_VALUES VALUES ('lookup_id', 0);
INSERT INTO @SCHEMA@.ABX_TYPES VALUES (0, 'Unknown', 'Unknown');
INSERT INTO @SCHEMA@.ABX_TYPES VALUES (1, 'Properties (instance of java.util.Map)', 'java.util.Map');
INSERT INTO @SCHEMA@.ABX_TYPES VALUES (2, 'Container (Context)', 'javax.naming.Context');
INSERT INTO @SCHEMA@.ABX_TYPES VALUES (3, 'ASCII Text (TextArrayRef)', 'com.ibm.jndisp.util.TextArrayRef');
INSERT INTO @SCHEMA@.ABX_TYPES VALUES (4, 'Binary (ByteArrayRef)', 'com.ibm.jndisp.util.ByteArrayRef');

CREATE TABLE @SCHEMA@.CEI_SERVER_SOURCE_T
(
  SERVER_ID                          VARCHAR(256)                      NOT NULL ,
  ALIAS                              VARCHAR(128)                               ,
  DESCRIPTION                        VARCHAR(256)                               ,
  DEFAULT_SERVER                     SMALLINT                                   ,
  CELL                               VARCHAR(128)                               ,
  NODE                               VARCHAR(128)                               ,
  SERVER                             VARCHAR(128)                               ,
  CLUSTER_ID                         VARCHAR(128)                               ,
  HOST                               VARCHAR(128)                               ,
  RMI_PORT                           VARCHAR(128)                               ,
  EVENT_GROUP_PROFILE_LIST           VARCHAR(128)                               ,
  AUTH_ALIAS                         VARCHAR(128)                               ,
  QUEUE_BYPASS_CONFIG                SMALLINT                                   ,
  QUEUE_BASED_CONFIG                 SMALLINT                                   ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( SERVER_ID )
) IN DSTS32K;


ALTER TABLE @SCHEMA@.META_MODEL_UNVERSIONED_T ADD 
   COLUMN SERVER_ID VARCHAR (256) ;


CREATE TABLE @SCHEMA@.MM_TO_WPS_PT  (
  MODEL_ID           		     VARCHAR(256)                      NOT NULL,
  VERSION_ID                         BIGINT                            NOT NULL, 
  WPS_PT_ID                          VARCHAR(512)                      NOT NULL,
  WPS_PT_VALID_FROM                  VARCHAR(128)                      NOT NULL,
  PRIMARY KEY (MODEL_ID, VERSION_ID, WPS_PT_ID, WPS_PT_VALID_FROM)
) IN DSTS32K;  

  
DROP VIEW @SCHEMA@.ACT_TMPLT;

DROP VIEW @SCHEMA@.ETAMATCH;

DROP VIEW @SCHEMA@.ACTION;

DROP VIEW @SCHEMA@.ACT_MGR_PROP;

DROP VIEW @SCHEMA@.PLUG_SVC;

DROP VIEW @SCHEMA@.ALERTS;

DROP VIEW @SCHEMA@.EQ_FE_IDS;

-- View: ActTmplt
CREATE VIEW @SCHEMA@.ACT_TMPLT(ID, NAME, TYPE, DESCRIPTION ) AS
 SELECT @SCHEMA@.ACT_TMPLT_T.ID, @SCHEMA@.ACT_TMPLT_T.NAME, @SCHEMA@.ACT_TMPLT_T.TYPE, @SCHEMA@.ACT_TMPLT_T.DESCRIPTION
 FROM @SCHEMA@.ACT_TMPLT_T;

-- View: ETAMatch
CREATE VIEW @SCHEMA@.ETAMATCH(ID, DETERMINER_TYPE, EXTENSION_NAME, DESCRIPTION ) AS
 SELECT @SCHEMA@.ETAMATCH_T.ID, @SCHEMA@.ETAMATCH_T.DETERMINER_TYPE, @SCHEMA@.ETAMATCH_T.EXTENSION_NAME, @SCHEMA@.ETAMATCH_T.DESCRIPTION
 FROM @SCHEMA@.ETAMATCH_T;

-- View: Action
CREATE VIEW @SCHEMA@.ACTION(ID, NAME, TYPE ) AS
 SELECT @SCHEMA@.ACTION_T.ID, @SCHEMA@.ACTION_T.NAME, @SCHEMA@.ACTION_T.TYPE
 FROM @SCHEMA@.ACTION_T;

-- View: ActMgrProp
CREATE VIEW @SCHEMA@.ACT_MGR_PROP(ACTION_PROP_NAME, ACTION_PROP_VALUE ) AS
 SELECT @SCHEMA@.ACTION_MANAGER_PROP_T.ACTION_PROP_NAME, @SCHEMA@.ACTION_MANAGER_PROP_T.ACTION_PROP_VALUE
 FROM @SCHEMA@.ACTION_MANAGER_PROP_T;

-- View: PlugSvc
CREATE VIEW @SCHEMA@.PLUG_SVC(ID, NAME, SERVICE_TYPE, SUB_TYPE, ACTION_HANDLER_ID ) AS
 SELECT @SCHEMA@.PLUG_SVC_T.ID, @SCHEMA@.PLUG_SVC_T.NAME, @SCHEMA@.PLUG_SVC_T.SERVICE_TYPE, @SCHEMA@.PLUG_SVC_T.SUB_TYPE, @SCHEMA@.PLUG_SVC_T.ACTION_HANDLER_ID
 FROM @SCHEMA@.PLUG_SVC_T;

-- View: Alerts
CREATE VIEW @SCHEMA@.ALERTS(ALERT_ID, BUS_SIT_NAME, ALERT_SUBJECT, ALERT_TIMESTAMP ) AS
 SELECT @SCHEMA@.ACT_MGR_ALERTS_T.ALERT_ID, @SCHEMA@.ACT_MGR_ALERTS_T.BUS_SIT_NAME, @SCHEMA@.ACT_MGR_ALERTS_T.ALERT_SUBJECT, @SCHEMA@.ACT_MGR_ALERTS_T.ALERT_TIMESTAMP
 FROM @SCHEMA@.ACT_MGR_ALERTS_T;

-- View: EQ
CREATE view @SCHEMA@.EQ_FE_IDS(DBID, INSTANCE_DBID, EQ_SEQUENCE) AS
 SELECT DBID, INSTANCE_DBID, EQ_SEQUENCE 
 FROM @SCHEMA@.EQ_FAILED_EVENT_T;


CREATE TABLE @SCHEMA@.DMS_TRACE_T
(
  DMS_STORED_PROC                     VARCHAR(128)                              ,
  START_TIME                          TIMESTAMP                                 ,
  END_TIME                            TIMESTAMP                                 ,
  ROWS_MERGED                         INTEGER                                   ,
  ROWS_PRUNED                         INTEGER                                   ,
  START_DCL                           INTEGER                                   ,
  START_DCC                           INTEGER                                   ,
  END_DCL                             INTEGER                                   ,
  END_DCC                             INTEGER                                   ,
  START_MCT                           INTEGER                                   ,
  START_TGT                           INTEGER                                   ,
  END_MCT                             INTEGER                                   ,
  END_TGT                             INTEGER                                   ,
  ROWS_INSERTED                       INTEGER                                   ,
  ROWS_UPDATED                        INTEGER
) IN DSTS32K;


CREATE INDEX @SCHEMA@.DMS_TRACE__I1 ON @SCHEMA@.DMS_TRACE_T (DMS_STORED_PROC, START_TIME);


-- Begin Updates for Monitor 7.5

ALTER TABLE @SCHEMA@.META_MODEL_T 
        ADD COLUMN ROUTING_JARS 	BLOB(1000M);


---------- FINE GRAINED SECURITY TABLES

CREATE TABLE @SCHEMA@.FGS_SECURITY_FILTER_T
(
  CONTEXT_KEY                        VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MCID                               VARCHAR(256)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(256)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  DISPLAY_INDICATION                 SMALLINT                          NOT NULL ,
  FILTER_VALUE                       CLOB(1048576)                              ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( CONTEXT_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.FGS_METRIC_T
(
  METRIC_KEY                         VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MCID                               VARCHAR(256)                      NOT NULL ,
  METRIC_ID                          VARCHAR(256)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(256)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( METRIC_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.FGS_MEASURE_T
(
  MEASURE_KEY                        VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MCID                               VARCHAR(128)                      NOT NULL ,
  CUBE_ID                            VARCHAR(128)                      NOT NULL ,
  MEASURE_ID                         VARCHAR(128)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(128)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MEASURE_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.FGS_DIMENSION_T
(
  DIMENSION_KEY                      VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MCID                               VARCHAR(128)                      NOT NULL ,
  CUBE_ID                            VARCHAR(128)                      NOT NULL ,
  DIMENSION_ID                       VARCHAR(128)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(128)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( DIMENSION_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.FGS_ALERT_TMPLT_T
(
  ALERT_KEY                          VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  TEMPLATE_ID                        VARCHAR(128)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(128)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ALERT_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.FGS_KPI_T
(
  KPI_KEY                            VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  KPIID                              VARCHAR(128)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(128)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;


CREATE TABLE @SCHEMA@.FGS_MONITOR_CONTEXT_T
(
  MC_KEY                             VARCHAR(256)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  MCID                               VARCHAR(256)                      NOT NULL ,
  ENTITY_ID                          VARCHAR(256)                      NOT NULL ,
  ENTITY_TYPE                        VARCHAR(20)                       NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MC_KEY, ENTITY_ID, ENTITY_TYPE )
) IN DSTS32K;


CREATE TABLE @SCHEMA@.MONPROPS_T
(
 CONTEXT	                     VARCHAR(128)                      NOT NULL ,
 PROPERTY	                     VARCHAR(128)                      NOT NULL ,
 CHARVALUE	                     VARCHAR(512),
 INTVALUE	                     INTEGER,
 DECVALUE	                     DOUBLE , 
 TIMEVALUE	                     TIMESTAMP,
 CLOBVALUE 	                     CLOB(1048576),
 BLOBVALUE 	                     BLOB(1000M),
 VERSION_ID                          SMALLINT,
 PRIMARY KEY ( CONTEXT, PROPERTY )
) IN DSTS32K;


---------- AUDIT LOG

CREATE TABLE @SCHEMA@.AUDIT_TRAIL_T
(
  AUDIT_ENTRY_ID                     BIGINT NOT NULL GENERATED ALWAYS AS IDENTITY,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                                     ,
  STEP                               VARCHAR(256)                      NOT NULL ,
  AUDIT_TIMESTAMP                    TIMESTAMP                         NOT NULL ,
  ARRIVAL_TIMESTAMP                  TIMESTAMP                                  ,
  AUDIT_MSG_TYPE                     VARCHAR(1)                        NOT NULL ,
  HOSTNAME                           VARCHAR(256)                               ,
  PORT_NUMBER                        VARCHAR(8)                                 ,
  AUDIT_MESSAGE                      VARCHAR(2048)                              ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( AUDIT_ENTRY_ID )
) IN DSTS32K;



CREATE TABLE @SCHEMA@.META_KPI_PERSONALIZED_T
(
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  USER_ID                            VARCHAR(256)                      NOT NULL ,
  TARGET                             DOUBLE                                     ,
  FGS_FILTER_HASH                    BIGINT                                     ,
  HISTORY_VALID_FROM                 TIMESTAMP                                  ,
  ENABLE_KPI_HISTORY                 SMALLINT                          NOT NULL ,
  ENABLE_KPI_PREDICTIONS             SMALLINT                          NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_ID, VERSION, USER_ID )
) IN DSTS32K;


CREATE TABLE @SCHEMA@.META_KPI_CACHE_T
(
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  FGS_FILTER_HASH                    BIGINT                            NOT NULL ,
  KPI_CACHE_VALUE                    DOUBLE                                     ,
  KPI_LAST_CALCULATION_TIME          TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_ID, VERSION, FGS_FILTER_HASH )
) IN DSTS32K;

CREATE TABLE @SCHEMA@.META_KPI_RANGE_PERSONALIZED_T
(
  KPI_RANGE_ID                       VARCHAR(512)                      NOT NULL ,
  KPI_ID                             VARCHAR(384)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  USER_ID                            VARCHAR(256)                      NOT NULL ,
  DISPLAY_NAME                       VARCHAR(1000)                              ,
  START_VALUE                        DOUBLE                            NOT NULL ,
  END_VALUE                          DOUBLE                            NOT NULL ,
  COLOR                              VARCHAR(7)                                 ,
  ICON                               VARCHAR(256)                               ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( KPI_RANGE_ID, VERSION, USER_ID )
) IN DSTS32K;


ALTER TABLE @SCHEMA@.KPI_HISTORY_T
	ADD COLUMN FGS_FILTER_HASH     BIGINT	NOT NULL WITH DEFAULT 0;

ALTER TABLE @SCHEMA@.KPI_HISTORY_T DROP PRIMARY KEY;

ALTER TABLE @SCHEMA@.KPI_HISTORY_T ADD PRIMARY KEY (KPI_ID, VERSION, KPI_DYNAMIC_FILTER_VALUE, PERIOD_TIMESTAMP, FGS_FILTER_HASH);



ALTER TABLE @SCHEMA@.KPI_TS_PREDICTION_T
	ADD COLUMN FGS_FILTER_HASH     BIGINT	NOT NULL WITH DEFAULT 0;

ALTER TABLE @SCHEMA@.KPI_TS_PREDICTION_T DROP PRIMARY KEY;

ALTER TABLE @SCHEMA@.KPI_TS_PREDICTION_T ADD PRIMARY KEY (KPI_PREDICTION_ID, VERSION, LAST_KPI_TIME, FGS_FILTER_HASH);


ALTER TABLE @SCHEMA@.META_MODEL_UNVERSIONED_T ADD COLUMN FGS_LASTUPDATE_SECFILTER TIMESTAMP;

ALTER TABLE @SCHEMA@.META_MODEL_UNVERSIONED_T ADD COLUMN FGS_LASTUPDATE_OBJSEC TIMESTAMP;

ALTER TABLE @SCHEMA@.META_MODEL_UNVERSIONED_T ADD COLUMN FGS_LASTUPDATE_COGNOS TIMESTAMP;


ALTER TABLE @SCHEMA@.META_MODEL_T 
        ADD COLUMN ROOT_META_INF_CONTENTS 	BLOB(1000M);

--ADD Cognos Changes

ALTER TABLE @SCHEMA@.META_MODEL_T 
        ADD COLUMN COGNOS_PACKAGE               VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T 
        ADD COLUMN COGNOS_NAMESPACE             VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_DIMENSION_T 
        ADD COLUMN COGNOS_NAME                  VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_DIM_ATTR_T 
        ADD COLUMN COGNOS_NAME                  VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_MEASURE_T 
        ADD COLUMN COGNOS_NAME                  VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T 
        ADD COLUMN COGNOS_NAME                  VARCHAR(1000);
        

CREATE SEQUENCE @SCHEMA@.ERROR_Q_SEQ START WITH 1 INCREMENT BY 1 NO MAXVALUE NO CYCLE; 
        

--Begin Monitor 8.0 changes

ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T
        ADD COLUMN PRIORITY                           BIGINT;

CREATE TABLE @SCHEMA@.ACT_ALERT_COMMENTS_T
(
  ALERT_ID                           VARCHAR(32)                       NOT NULL ,
  COMMENT_OWNER                      VARCHAR(32)                       NOT NULL ,
  COMMENT_TIME                       TIMESTAMP                         NOT NULL ,
  COMMENT_TEXT                       VARCHAR(4000)                              ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ALERT_ID, COMMENT_OWNER, COMMENT_TIME )
) IN DSTS32K;        


ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T
        ADD COLUMN STATUS                             VARCHAR(32) ;


ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T
        ADD COLUMN HIDDEN                             SMALLINT  ;

UPDATE @SCHEMA@.META_MONITOR_CONTEXT_T SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T ADD CONSTRAINT META_MONITOR_CONTEXT_C1 CHECK (HIDDEN IS NOT NULL);


ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T
        ADD COLUMN HIDDEN                             SMALLINT  ;

UPDATE @SCHEMA@.META_MONITOR_METRIC_T SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T ADD CONSTRAINT META_MONITOR_METRIC_C1 CHECK (HIDDEN IS NOT NULL);


ALTER TABLE @SCHEMA@.META_KPI_T
        ADD COLUMN HIDDEN                             SMALLINT  ;        

UPDATE @SCHEMA@.META_KPI_T SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_KPI_T ADD CONSTRAINT META_KPI_C1 CHECK (HIDDEN IS NOT NULL);

COMMIT;
CONNECT RESET;
