-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2009,2011. All Rights Reserved.
-- US Government Users Restricted Rights- Use, duplication or disclosu
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- -------------------------------------------------------------------
--
-- Scriptfile to upgrade database from v6.2 to v8.0 for DB2 z/OS
--
----------------------------------------------------------------------
-- Following variables need to be changed for customization before 
-- running this script: 
-- @STOGRP@ = DB2 Storage group name (default is SYSDEFLT)
-- @DB_NAME@ = the database name, eg MONITOR
-- @SCHEMA@ = the schema name, eg MONITOR
-- Note: Tablespaces should be created with LOCKSIZE ROW to avoid 
--              deadlocks
--       Tablespaces should be created with CCSID UNICODE for
--       performance reasons and codepage coverage for user input
--
-- Run the script in the DB2 command line processor.
--
-- USAGE:   db2 -tf upgradeSchema620.sql
--
-- -------------------------------------------------------------------

----------------------------------------------CHANGED:  SCHEMA_VERSION
DELETE FROM @SCHEMA@.SCHEMA_VERSION;
INSERT INTO @SCHEMA@.SCHEMA_VERSION (SCHEMA_VERSION, DATA_MIGRATION) 
  VALUES( 80, 0 );
  
----------------------------------------------------OLD: D2D_CONTENT
DROP TABLE @SCHEMA@.D2D_CONTENT;

----------------------------------------------------NEW: D2D_CONTENT
CREATE TABLE @SCHEMA@.D2D_CONTENT 
(
  ITEM_ID VARCHAR(255) NOT NULL,
  PI      BLOB(1000M),
  PRIMARY KEY (ITEM_ID),
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) 
    ON DELETE CASCADE
) IN @DB_NAME@.WBMON061;

CREATE UNIQUE INDEX @SCHEMA@.D2D_CONTENT_P 
  ON @SCHEMA@.D2D_CONTENT ( ITEM_ID ) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column PI
CREATE AUX TABLE @SCHEMA@.ATLOB31
   IN @DB_NAME@.WBMLOB31
   STORES @SCHEMA@.D2D_CONTENT COLUMN PI;
-- auxiliary index for LOB column PI
CREATE UNIQUE INDEX @SCHEMA@.ATLOB31I
  ON @SCHEMA@.ATLOB31 
  USING STOGROUP @STOGRP@;
     
     
CREATE TABLESPACE WBMON065 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON066 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON067 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON068 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON069 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON070 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
   
-- Alphablox Tables

CREATE TABLE @SCHEMA@.ABX_VERSION 
(
  DESCRIPTION VARCHAR(32) NOT NULL, 
  VALUE VARCHAR(64) NOT NULL
) IN @DB_NAME@.WBMON065;


CREATE TABLE @SCHEMA@.ABX_LOOKUP 
(
  ID INTEGER NOT NULL, 
  CONTEXT VARCHAR(255), 
  NAME VARCHAR(96) NOT NULL, 
  TYPE INTEGER NOT NULL, 
  LAST_MODIFIED TIMESTAMP DEFAULT,
  PRIMARY KEY(ID)
) IN @DB_NAME@.WBMON068;

CREATE UNIQUE INDEX @SCHEMA@.IDX_ABX_LOOKUP
  ON @SCHEMA@.ABX_LOOKUP (ID) 
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ABX_OBJECTS 
(
  ID INTEGER NOT NULL, 
  SEQUENCE INTEGER NOT NULL, 
  VALUE VARCHAR(3900) NOT NULL,
  FOREIGN KEY (ID ) REFERENCES @SCHEMA@.ABX_LOOKUP( ID )
) IN @DB_NAME@.WBMON067;

CREATE TABLE @SCHEMA@.ABX_PROPERTY_MAP 
(
  ID INTEGER NOT NULL, 
  PROPERTY VARCHAR(255) NOT NULL, 
  SEQUENCE INTEGER NOT NULL, 
  VALUE VARCHAR(255),
  FOREIGN KEY(ID) REFERENCES @SCHEMA@.ABX_LOOKUP(ID)
) IN @DB_NAME@.WBMON066;

CREATE TABLE @SCHEMA@.ABX_TYPES 
(
  ID INTEGER NOT NULL, 
  DESCRIPTION VARCHAR(64) NOT NULL, 
  INTERNAL_NAME VARCHAR(64) NOT NULL
) IN @DB_NAME@.WBMON069;

CREATE TABLE @SCHEMA@.ABX_LOOKUP_VALUES 
(
  DESCRIPTION VARCHAR(16) NOT NULL, 
  VALUE INTEGER NOT NULL
) IN @DB_NAME@.WBMON070;

CREATE UNIQUE INDEX @SCHEMA@.IPROPERTYIDPROPSEQ 
  ON @SCHEMA@.ABX_PROPERTY_MAP 
  (ID, PROPERTY, SEQUENCE) 
  CLUSTER 
  USING STOGROUP @STOGRP@;

CREATE INDEX @SCHEMA@.IPROPERTYPROPSEQ 
  ON @SCHEMA@.ABX_PROPERTY_MAP 
  (PROPERTY, SEQUENCE) 
  USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX @SCHEMA@.IPKLOOKUPCONTEXT
  ON @SCHEMA@.ABX_LOOKUP
    (CONTEXT, NAME) 
  USING STOGROUP @STOGRP@;

CREATE INDEX @SCHEMA@.ILOOKUPCONTEXT 
  ON @SCHEMA@.ABX_LOOKUP
    (CONTEXT, NAME, ID, TYPE) 
  USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX @SCHEMA@.IOBJECTIDSEQ 
  ON @SCHEMA@.ABX_OBJECTS
    (ID, SEQUENCE) 
  USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX @SCHEMA@.ILOOKUPVALUEDESC 
  ON @SCHEMA@.ABX_LOOKUP_VALUES
  (DESCRIPTION) 
  CLUSTER 
  USING STOGROUP @STOGRP@;
  
CREATE UNIQUE INDEX @SCHEMA@.IVERSIONDESC 
  ON @SCHEMA@.ABX_VERSION
  (DESCRIPTION) 
  CLUSTER 
  USING STOGROUP @STOGRP@;
  
CREATE UNIQUE INDEX @SCHEMA@.ITYPESID 
  ON @SCHEMA@.ABX_TYPES
  (ID) 
  CLUSTER 
  USING STOGROUP @STOGRP@;
  
  
INSERT INTO @SCHEMA@.ABX_LOOKUP_VALUES 
  VALUES ('lookup_id', 0);
INSERT INTO @SCHEMA@.ABX_TYPES 
  VALUES (0, 'Unknown', 'Unknown');
INSERT INTO @SCHEMA@.ABX_TYPES 
  VALUES (1, 'Properties (instance of java.util.Map)', 
  'java.util.Map');
INSERT INTO @SCHEMA@.ABX_TYPES 
  VALUES (2, 'Container (Context)', 
  'javax.naming.Context');
INSERT INTO @SCHEMA@.ABX_TYPES 
  VALUES (3, 'ASCII Text (TextArrayRef)', 
  'com.ibm.jndisp.util.TextArrayRef');
INSERT INTO @SCHEMA@.ABX_TYPES 
  VALUES (4, 'Binary (ByteArrayRef)', 
  'com.ibm.jndisp.util.ByteArrayRef');

CREATE TABLESPACE WBMON071 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;


CREATE TABLE @SCHEMA@.CEI_SERVER_SOURCE_T
(
  SERVER_ID VARCHAR(256) NOT NULL ,
  ALIAS VARCHAR(128),
  DESCRIPTION VARCHAR(256),
  DEFAULT_SERVER SMALLINT,
  CELL VARCHAR(128),
  NODE VARCHAR(128),
  SERVER VARCHAR(128),
  CLUSTER_ID VARCHAR(128),
  HOST VARCHAR(128),
  RMI_PORT VARCHAR(128),
  EVENT_GROUP_PROFILE_LIST VARCHAR(128),
  AUTH_ALIAS VARCHAR(128),
  QUEUE_BYPASS_CONFIG SMALLINT,
  QUEUE_BASED_CONFIG SMALLINT,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (SERVER_ID)
) IN @DB_NAME@.WBMON071;

CREATE UNIQUE INDEX
  @SCHEMA@.CEI_SERVER_SOURCE_P ON
   @SCHEMA@.CEI_SERVER_SOURCE_T
( SERVER_ID ) 
USING STOGROUP @STOGRP@;
  

ALTER TABLE @SCHEMA@.META_MODEL_UNVERSIONED_T ADD 
   COLUMN SERVER_ID VARCHAR (256) ;     


CREATE TABLESPACE WBMON072 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;

CREATE TABLE @SCHEMA@.MM_TO_WPS_PT  (
  MODEL_ID VARCHAR(256) NOT NULL,
  VERSION_ID DECIMAL(19) NOT NULL, 
  WPS_PT_ID VARCHAR(512) NOT NULL,
  WPS_PT_VALID_FROM VARCHAR(128) NOT NULL,
  PRIMARY KEY (MODEL_ID, VERSION_ID, 
       WPS_PT_ID, WPS_PT_VALID_FROM)
) IN @DB_NAME@.WBMON072;

CREATE UNIQUE INDEX @SCHEMA@.MM_TO_WPS_PT_P 
  ON @SCHEMA@.MM_TO_WPS_PT (MODEL_ID, VERSION_ID, 
       WPS_PT_ID, WPS_PT_VALID_FROM) 
  NOT PADDED
  USING STOGROUP @STOGRP@;
     
CREATE UNIQUE INDEX @SCHEMA@.RECORDED_EVENTS_MV_P 
  ON @SCHEMA@.RECORDED_EVENTS_MODELVERSIONS 
  (EVENT_ID, MODEL_ID, VERSION) 
  USING STOGROUP @STOGRP@;


-- Begin Migrate EQ_FAILED_EVENT_T table defaults

DROP VIEW @SCHEMA@.EQ_FE_IDS;

ALTER TABLE @SCHEMA@.EQ_FAILED_EVENT_T DROP FOREIGN KEY INSTANCE;

CREATE LOB TABLESPACE TEMLOB32 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
CREATE LOB TABLESPACE TEMLOB33 IN @DB_NAME@  
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
CREATE LOB TABLESPACE TEMLOB34 IN @DB_NAME@  
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
   
   
CREATE TABLESPACE TMON073 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;


CREATE TABLE @SCHEMA@.EQ_FAILED_EVENT_T_1
(
  DBID VARCHAR(32) NOT NULL ,
  INSTANCE_DBID VARCHAR(32) NOT NULL ,
  GU_INST_ID VARCHAR(1000) NOT NULL ,
  EQ_SEQUENCE DECIMAL(19) NOT NULL ,
  EVENT_SEQUENCE VARCHAR(512) ,
  F_SUMMARY VARCHAR(256) NOT NULL ,
  F_DETAILS BLOB(1024K) ,
  F_TIME DECIMAL(19) NOT NULL ,
  CREATION_TIME DECIMAL(19) ,
  EXT_NAME VARCHAR(64) NOT NULL ,
  CONSUMPTION_TIME DECIMAL(19) NOT NULL ,
  LAST_SUB_TIME DECIMAL(19) ,
  LAST_SUB_STATUS INTEGER NOT NULL ,
  HISTORY BLOB(20000K) ,
  DATA BLOB(1000M) ,
  VERSION_ID SMALLINT NOT NULL 
) IN @DB_NAME@.TMON073;


-- auxiliary table for LOB column F_DETAILS
CREATE AUX TABLE @SCHEMA@.TTLOB32
   IN @DB_NAME@.TEMLOB32
   STORES @SCHEMA@.EQ_FAILED_EVENT_T_1 COLUMN F_DETAILS;
-- auxiliary index for LOB column F_DETAILS
CREATE UNIQUE INDEX @SCHEMA@.TTLOB32I
  ON @SCHEMA@.TTLOB32 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column HISTORY
CREATE AUX TABLE @SCHEMA@.TTLOB33
   IN @DB_NAME@.TEMLOB33
   STORES @SCHEMA@.EQ_FAILED_EVENT_T_1 COLUMN HISTORY;
-- auxiliary index for LOB column HISTORY
CREATE UNIQUE INDEX @SCHEMA@.TTLOB33I
  ON @SCHEMA@.TTLOB33 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.TTLOB34
   IN @DB_NAME@.TEMLOB34
   STORES @SCHEMA@.EQ_FAILED_EVENT_T_1 COLUMN DATA;
-- auxiliary index for LOB column DATA
CREATE UNIQUE INDEX @SCHEMA@.TTLOB34I
  ON @SCHEMA@.TTLOB34 
  USING STOGROUP @STOGRP@;

INSERT INTO @SCHEMA@.EQ_FAILED_EVENT_T_1 (SELECT DBID,INSTANCE_DBID,GU_INST_ID,EQ_SEQUENCE,EVENT_SEQUENCE,F_SUMMARY,F_DETAILS,F_TIME,CREATION_TIME,EXT_NAME,CONSUMPTION_TIME,LAST_SUB_TIME,LAST_SUB_STATUS,HISTORY,DATA,VERSION_ID FROM @SCHEMA@.EQ_FAILED_EVENT_T);

COMMIT;

DROP TABLE @SCHEMA@.EQ_FAILED_EVENT_T;

CREATE TABLE @SCHEMA@.EQ_FAILED_EVENT_T
(
  DBID VARCHAR(32) NOT NULL ,
  INSTANCE_DBID VARCHAR(32) NOT NULL ,
  GU_INST_ID VARCHAR(1000) ,
  EQ_SEQUENCE DECIMAL(19) NOT NULL ,
  EVENT_SEQUENCE VARCHAR(512) ,
  F_SUMMARY VARCHAR(256) NOT NULL ,
  F_DETAILS BLOB(1024K) ,
  F_TIME DECIMAL(19) NOT NULL ,
  CREATION_TIME DECIMAL(19) ,
  EXT_NAME VARCHAR(64) ,
  CONSUMPTION_TIME DECIMAL(19) NOT NULL ,
  LAST_SUB_TIME DECIMAL(19) ,
  LAST_SUB_STATUS INTEGER NOT NULL ,
  HISTORY BLOB(20000K) ,
  DATA BLOB(1000M) ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( DBID ),
  FOREIGN KEY ( INSTANCE_DBID ) REFERENCES 
    @SCHEMA@.EQ_INSTANCE_T( DBID ) 
    ON DELETE CASCADE
) IN @DB_NAME@.WBMON039;



CREATE UNIQUE INDEX @SCHEMA@.EQ_FAILED_EVENT_P 
  ON @SCHEMA@.EQ_FAILED_EVENT_T (DBID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.EQ_FAILED_EVENT_I1  
  ON @SCHEMA@.EQ_FAILED_EVENT_T (INSTANCE_DBID)
  NOT PADDED
  USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.EQ_FAILED_EVENT_I2  
  ON @SCHEMA@.EQ_FAILED_EVENT_T (INSTANCE_DBID, EQ_SEQUENCE)
  NOT PADDED
  USING STOGROUP @STOGRP@;


-- auxiliary table for LOB column F_DETAILS
CREATE AUX TABLE @SCHEMA@.ATLOB23
   IN @DB_NAME@.WBMLOB23
   STORES @SCHEMA@.EQ_FAILED_EVENT_T COLUMN F_DETAILS;
-- auxiliary index for LOB column F_DETAILS
CREATE UNIQUE INDEX @SCHEMA@.ATLOB23I
  ON @SCHEMA@.ATLOB23 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column HISTORY
CREATE AUX TABLE @SCHEMA@.ATLOB24
   IN @DB_NAME@.WBMLOB24
   STORES @SCHEMA@.EQ_FAILED_EVENT_T COLUMN HISTORY;
-- auxiliary index for LOB column HISTORY
CREATE UNIQUE INDEX @SCHEMA@.ATLOB24I
  ON @SCHEMA@.ATLOB24 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.ATLOB25
   IN @DB_NAME@.WBMLOB25
   STORES @SCHEMA@.EQ_FAILED_EVENT_T COLUMN DATA;
-- auxiliary index for LOB column DATA
CREATE UNIQUE INDEX @SCHEMA@.ATLOB25I
  ON @SCHEMA@.ATLOB25 
  USING STOGROUP @STOGRP@;


INSERT INTO @SCHEMA@.EQ_FAILED_EVENT_T (SELECT DBID,INSTANCE_DBID,GU_INST_ID,EQ_SEQUENCE,EVENT_SEQUENCE,F_SUMMARY,F_DETAILS,F_TIME,CREATION_TIME,EXT_NAME,CONSUMPTION_TIME,LAST_SUB_TIME,LAST_SUB_STATUS,HISTORY,DATA,VERSION_ID FROM @SCHEMA@.EQ_FAILED_EVENT_T_1);


-- View:  EQs
CREATE VIEW @SCHEMA@.EQ_FE_IDS(DBID, INSTANCE_DBID, EQ_SEQUENCE) 
  AS SELECT
  @SCHEMA@.EQ_FAILED_EVENT_T.DBID, 
  @SCHEMA@.EQ_FAILED_EVENT_T.INSTANCE_DBID, 
  @SCHEMA@.EQ_FAILED_EVENT_T.EQ_SEQUENCE 
FROM @SCHEMA@.EQ_FAILED_EVENT_T;


-- End Migrate EQ_FAILED_EVENT_T table defaults


CREATE TABLESPACE WBMON073 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;

CREATE TABLE @SCHEMA@.DMS_TRACE_T
(
  DMS_STORED_PROC VARCHAR(128),
  START_TIME TIMESTAMP,
  END_TIME TIMESTAMP,
  ROWS_MERGED INTEGER,
  ROWS_PRUNED INTEGER,
  START_DCL INTEGER,
  START_DCC INTEGER,
  END_DCL INTEGER,
  END_DCC INTEGER,
  START_MCT INTEGER,
  START_TGT INTEGER,
  END_MCT INTEGER,
  END_TGT INTEGER,
  ROWS_INSERTED INTEGER,
  ROWS_UPDATED INTEGER
) IN @DB_NAME@.WBMON073;

CREATE INDEX @SCHEMA@.DMS_TRACE_I1
  ON @SCHEMA@.DMS_TRACE_T 
  (DMS_STORED_PROC, START_TIME)
  NOT PADDED
  USING STOGROUP @STOGRP@;




--Changes for Monitor 7.5

CREATE TABLESPACE WBMON074 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON075 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON076 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON077 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON078 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON079 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON080 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
   
CREATE LOB TABLESPACE WBMLOB32 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
CREATE LOB TABLESPACE WBMLOB33 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;   


ALTER TABLE @SCHEMA@.META_MODEL_T 
  ADD COLUMN ROUTING_JARS BLOB(1000M);
  
-- auxiliary table for LOB column ROUTING_JARS
CREATE AUX TABLE @SCHEMA@.ATLOB32
   IN @DB_NAME@.WBMLOB32
   STORES @SCHEMA@.META_MODEL_T COLUMN ROUTING_JARS;
-- auxiliary index for LOB column ROUTING_JARS
CREATE UNIQUE INDEX @SCHEMA@.ATLOB32I
  ON @SCHEMA@.ATLOB32
  USING STOGROUP @STOGRP@;
  

CREATE TABLESPACE WBMON084 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE; 
CREATE TABLESPACE WBMON085 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;    
CREATE TABLESPACE WBMON086 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE; 
   
   
CREATE LOB TABLESPACE WBMLOB34 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
CREATE LOB TABLESPACE WBMLOB35 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
   

---------- FINE GRAINED SECURITY TABLES

CREATE TABLE @SCHEMA@.FGS_SECURITY_FILTER_T
(
  CONTEXT_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(256) NOT NULL ,
  ENTITY_ID VARCHAR(256) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  DISPLAY_INDICATION SMALLINT NOT NULL ,
  FILTER_VALUE CLOB(1048576),
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (CONTEXT_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON075;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_SECURITY_FILTER_P ON
  @SCHEMA@.FGS_SECURITY_FILTER_T
( 
  CONTEXT_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column FILTER_VALUE
CREATE AUX TABLE @SCHEMA@.ATLOB33
   IN @DB_NAME@.WBMLOB33
   STORES @SCHEMA@.FGS_SECURITY_FILTER_T 
   COLUMN FILTER_VALUE;
-- auxiliary index for LOB column FILTER_VALUE
CREATE UNIQUE INDEX @SCHEMA@.ATLOB33I
  ON @SCHEMA@.ATLOB33
   USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_METRIC_T
(
  METRIC_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(256) NOT NULL ,
  METRIC_ID VARCHAR(256) NOT NULL ,
  ENTITY_ID VARCHAR(256) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (METRIC_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON076;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_METRIC_P ON
  @SCHEMA@.FGS_METRIC_T
( 
  METRIC_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_MEASURE_T
(
  MEASURE_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(128) NOT NULL ,
  CUBE_ID VARCHAR(128) NOT NULL ,
  MEASURE_ID VARCHAR(128) NOT NULL ,
  ENTITY_ID VARCHAR(128) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (MEASURE_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON077;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_MEASURE_P ON
  @SCHEMA@.FGS_MEASURE_T
( 
  MEASURE_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_DIMENSION_T
(
  DIMENSION_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(128) NOT NULL ,
  CUBE_ID VARCHAR(128) NOT NULL ,
  DIMENSION_ID VARCHAR(128) NOT NULL ,
  ENTITY_ID VARCHAR(128) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (DIMENSION_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON078;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_DIMENSION_P ON
  @SCHEMA@.FGS_DIMENSION_T
( 
  DIMENSION_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_ALERT_TMPLT_T
(
  ALERT_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  TEMPLATE_ID VARCHAR(128) NOT NULL ,
  ENTITY_ID VARCHAR(128) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ALERT_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON079;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_ALERT_TMPLT_P ON
  @SCHEMA@.FGS_ALERT_TMPLT_T
( 
  ALERT_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_KPI_T
(
  KPI_KEY VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  KPIID VARCHAR(128) NOT NULL ,
  ENTITY_ID VARCHAR(128) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_KEY, ENTITY_ID, ENTITY_TYPE)
) IN @DB_NAME@.WBMON080;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_KPI_P ON
  @SCHEMA@.FGS_KPI_T
( 
  KPI_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.FGS_MONITOR_CONTEXT_T
(
  MC_KEY VARCHAR(256) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  MCID VARCHAR(256) NOT NULL ,
  ENTITY_ID VARCHAR(256) NOT NULL ,
  ENTITY_TYPE VARCHAR(20) NOT NULL ,
  VISIBLE SMALLINT NOT NULL ,
  LAST_UPDATED TIMESTAMP                                  ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( MC_KEY, ENTITY_ID, ENTITY_TYPE )
) IN @DB_NAME@.WBMON084;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_MONITOR_CONTEXT_P ON
  @SCHEMA@.FGS_MONITOR_CONTEXT_T
( 
  MC_KEY, 
  ENTITY_ID, 
  ENTITY_TYPE
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.MONPROPS_T
(
 CONTEXT VARCHAR(128) NOT NULL ,
 PROPERTY VARCHAR(128) NOT NULL ,
 CHARVALUE VARCHAR(512),
 INTVALUE INTEGER,
 DECVALUE DOUBLE , 
 TIMEVALUE TIMESTAMP,
 CLOBVALUE CLOB(1048576),
 BLOBVALUE BLOB(1000M),
 VERSION_ID SMALLINT,
 PRIMARY KEY ( CONTEXT, PROPERTY )
) IN @DB_NAME@.WBMON085;

CREATE UNIQUE INDEX
  @SCHEMA@.MONPROPS_P ON
  @SCHEMA@.MONPROPS_T
( 
  CONTEXT, 
  PROPERTY
) 
USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column CLOBVALUE
CREATE AUX TABLE @SCHEMA@.ATLOB34
   IN @DB_NAME@.WBMLOB34
   STORES @SCHEMA@.MONPROPS_T COLUMN CLOBVALUE;
-- auxiliary index for LOB column CLOBVALUE
CREATE UNIQUE INDEX @SCHEMA@.ATLOB34I
  ON @SCHEMA@.ATLOB34 
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column BLOBVALUE
CREATE AUX TABLE @SCHEMA@.ATLOB35
   IN @DB_NAME@.WBMLOB35
   STORES @SCHEMA@.MONPROPS_T COLUMN BLOBVALUE;
-- auxiliary index for LOB column BLOBVALUE
CREATE UNIQUE INDEX @SCHEMA@.ATLOB35I
  ON @SCHEMA@.ATLOB35 
  USING STOGROUP @STOGRP@;


---------- AUDIT LOG

CREATE TABLE @SCHEMA@.AUDIT_TRAIL_T
(
  AUDIT_ENTRY_ID DECIMAL(19) NOT NULL GENERATED ALWAYS AS IDENTITY,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19),
  STEP VARCHAR(256) NOT NULL,
  AUDIT_TIMESTAMP TIMESTAMP NOT NULL,
  ARRIVAL_TIMESTAMP TIMESTAMP,
  AUDIT_MSG_TYPE VARCHAR(1) NOT NULL ,
  HOSTNAME VARCHAR(256),
  PORT_NUMBER VARCHAR(8),
  AUDIT_MESSAGE VARCHAR(2048),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( AUDIT_ENTRY_ID )
) IN @DB_NAME@.WBMON086;

CREATE UNIQUE INDEX
  @SCHEMA@.AUDIT_TRAIL_P ON
  @SCHEMA@.AUDIT_TRAIL_T
( 
  AUDIT_ENTRY_ID
) 
USING STOGROUP @STOGRP@;




CREATE TABLESPACE WBMON081 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;
CREATE TABLESPACE WBMON082 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE;   
CREATE TABLESPACE WBMON083 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ANY
   CCSID UNICODE; 

CREATE TABLE @SCHEMA@.META_KPI_PERSONALIZED_T
(
  KPI_ID VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19)  NOT NULL ,
  USER_ID VARCHAR(256) NOT NULL ,
  TARGET DOUBLE,
  FGS_FILTER_HASH DECIMAL(19),
  ENABLE_KPI_HISTORY SMALLINT NOT NULL ,
  ENABLE_KPI_PREDICTIONS SMALLINT NOT NULL ,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_ID, VERSION, USER_ID)
) IN @DB_NAME@.WBMON081;

CREATE UNIQUE INDEX
  @SCHEMA@.META_KPI_PERSONALIZED_P ON
  @SCHEMA@.META_KPI_PERSONALIZED_T
( 
  KPI_ID, 
  VERSION, 
  USER_ID
) 
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.META_KPI_CACHE_T
(
  KPI_ID VARCHAR(384) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  FGS_FILTER_HASH DECIMAL(19) NOT NULL ,
  KPI_CACHE_VALUE DOUBLE,
  KPI_LAST_CALCULATION_TIME TIMESTAMP,
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_ID, VERSION, FGS_FILTER_HASH)
) IN @DB_NAME@.WBMON082;

CREATE UNIQUE INDEX
  @SCHEMA@.META_KPI_CACHE_P ON
  @SCHEMA@.META_KPI_CACHE_T
( 
  KPI_ID, 
  VERSION, 
  FGS_FILTER_HASH
) 
USING STOGROUP @STOGRP@;  

CREATE TABLE @SCHEMA@.META_KPI_RANGE_PERSONALIZED_T
(
  KPI_RANGE_ID VARCHAR(512) NOT NULL ,
  KPI_ID VARCHAR(384) NOT NULL ,
  VERSION DECIMAL(19) NOT NULL ,
  USER_ID VARCHAR(256) NOT NULL ,
  DISPLAY_NAME VARCHAR(1000),
  START_VALUE DOUBLE NOT NULL ,
  END_VALUE DOUBLE NOT NULL ,
  COLOR VARCHAR(7),
  ICON VARCHAR(256),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (KPI_RANGE_ID, VERSION, USER_ID)
) IN @DB_NAME@.WBMON083;

CREATE UNIQUE INDEX
  @SCHEMA@.META_KPI_RANGE_PERSONALIZED_P ON
  @SCHEMA@.META_KPI_RANGE_PERSONALIZED_T
( 
  KPI_RANGE_ID, 
  VERSION, 
  USER_ID
) 
USING STOGROUP @STOGRP@;  



ALTER TABLE @SCHEMA@.KPI_HISTORY_T
	ADD COLUMN FGS_FILTER_HASH 
	BIGINT	
	NOT NULL WITH DEFAULT 0;

ALTER TABLE @SCHEMA@.KPI_HISTORY_T 
      DROP PRIMARY KEY;
      
DROP INDEX MONCDE.KPI_HISTORY_P;  

CREATE UNIQUE INDEX @SCHEMA@.KPI_HISTORY_P 
  ON @SCHEMA@.KPI_HISTORY_T 
 (KPI_ID, VERSION, KPI_DYNAMIC_FILTER_VALUE, 
  PERIOD_TIMESTAMP, FGS_FILTER_HASH) 
  USING STOGROUP @STOGRP@;
  
ALTER TABLE @SCHEMA@.KPI_HISTORY_T 
   ADD PRIMARY KEY (KPI_ID, VERSION, 
   KPI_DYNAMIC_FILTER_VALUE, PERIOD_TIMESTAMP, 
   FGS_FILTER_HASH);

ALTER TABLE @SCHEMA@.KPI_TS_PREDICTION_T
	ADD COLUMN FGS_FILTER_HASH     
	BIGINT	
	NOT NULL WITH DEFAULT 0;

ALTER TABLE @SCHEMA@.KPI_TS_PREDICTION_T 
        DROP PRIMARY KEY;
        
DROP INDEX MONCDE.KPI_TS_PREDICTION_P;      

CREATE UNIQUE INDEX @SCHEMA@.KPI_TS_PREDICTION_P 
  ON @SCHEMA@.KPI_TS_PREDICTION_T 
 (KPI_PREDICTION_ID, VERSION, 
  LAST_KPI_TIME, FGS_FILTER_HASH) 
  USING STOGROUP @STOGRP@;
        
ALTER TABLE @SCHEMA@.KPI_TS_PREDICTION_T 
   ADD PRIMARY KEY 
   (KPI_PREDICTION_ID, VERSION, 
   LAST_KPI_TIME, FGS_FILTER_HASH);


ALTER TABLE 
  @SCHEMA@.META_MODEL_UNVERSIONED_T 
  ADD COLUMN FGS_LASTUPDATE_SECFILTER TIMESTAMP;

ALTER TABLE 
  @SCHEMA@.META_MODEL_UNVERSIONED_T 
  ADD COLUMN FGS_LASTUPDATE_OBJSEC TIMESTAMP;

ALTER TABLE 
  @SCHEMA@.META_MODEL_UNVERSIONED_T 
  ADD COLUMN FGS_LASTUPDATE_COGNOS TIMESTAMP;
  
  
CREATE LOB TABLESPACE WBMLOB36 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;

ALTER TABLE @SCHEMA@.META_MODEL_T 
  ADD COLUMN ROOT_META_INF_CONTENTS BLOB(1000M);
  
-- auxiliary table for LOB column ROOT_META_INF_CONTENTS
CREATE AUX TABLE @SCHEMA@.ATLOB36
   IN @DB_NAME@.WBMLOB36
   STORES @SCHEMA@.META_MODEL_T COLUMN ROOT_META_INF_CONTENTS;
-- auxiliary index for LOB column ROOT_META_INF_CONTENTS
CREATE UNIQUE INDEX @SCHEMA@.ATLOB36I
  ON @SCHEMA@.ATLOB36
  USING STOGROUP @STOGRP@;
  
--ADD Cognos Changes

ALTER TABLE @SCHEMA@.META_MODEL_T 
        ADD COLUMN COGNOS_PACKAGE VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T 
        ADD COLUMN COGNOS_NAMESPACE VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_DIMENSION_T 
        ADD COLUMN COGNOS_NAME VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_DIM_ATTR_T 
        ADD COLUMN COGNOS_NAME VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_MEASURE_T 
        ADD COLUMN COGNOS_NAME VARCHAR(1000);

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T 
        ADD COLUMN COGNOS_NAME  VARCHAR(1000);
 
CREATE SEQUENCE @SCHEMA@.ERROR_Q_SEQ START WITH 1 INCREMENT BY 1 NO MAXVALUE NO CYCLE; 


-- Begin changes for 8.0

CREATE TABLESPACE WBMON087 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ROW
   CCSID UNICODE;   
   
ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T
        ADD COLUMN PRIORITY NUMERIC(20);   

CREATE TABLE @SCHEMA@.ACT_ALERT_COMMENTS_T
(
  ALERT_ID VARCHAR(32) NOT NULL,
  COMMENT_OWNER VARCHAR(32) NOT NULL,
  COMMENT_TIME TIMESTAMP NOT NULL,
  COMMENT_TEXT VARCHAR(4000),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( ALERT_ID, COMMENT_OWNER, COMMENT_TIME )
) IN @DB_NAME@.WBMON087;

CREATE UNIQUE INDEX @SCHEMA@.ACT_MGR_CMNT_P 
  ON @SCHEMA@.ACT_ALERT_COMMENTS_T 
  (ALERT_ID, COMMENT_OWNER, COMMENT_TIME) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T
ADD COLUMN STATUS VARCHAR(32);

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T
ADD COLUMN HIDDEN SMALLINT ;

UPDATE @SCHEMA@.META_MONITOR_CONTEXT_T 
SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T 
ADD CONSTRAINT META_MONITOR_CONTEXT_C1 
CHECK (HIDDEN IS NOT NULL);

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T
ADD COLUMN HIDDEN SMALLINT ;

UPDATE @SCHEMA@.META_MONITOR_METRIC_T 
SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T 
ADD CONSTRAINT META_MONITOR_METRIC_C1 
CHECK (HIDDEN IS NOT NULL);

ALTER TABLE @SCHEMA@.META_KPI_T
ADD COLUMN HIDDEN SMALLINT;        

UPDATE @SCHEMA@.META_KPI_T 
SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_KPI_T 
ADD CONSTRAINT META_KPI_C1 
CHECK (HIDDEN IS NOT NULL);
   
COMMIT;



