-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2007, 2011. All Rights Reserved.
-- US Government Users Restricted Rights- Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- ------------------------------------------------------------------------------------
--
-- Scriptfile to upgrade database from v6.1 to v8.0 for Oracle
--
---------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script: 
-- @SCHEMA@ = the schema owner, eg MONITOR
--
-- Run the script in SQL*Plus.
--
-- USAGE:  sqlplus system/passw0rd@orcl @upgradeSchema610.sql
--
-- ------------------------------------------------------------------------------------


---------------------------------------------------------CHANGED:  SCHEMA_VERSION
DELETE FROM @SCHEMA@.SCHEMA_VERSION;
INSERT INTO @SCHEMA@.SCHEMA_VERSION (
        SCHEMA_VERSION, DATA_MIGRATION) 
        VALUES( 80, 0 );

---------------------------------------------------------------OLD:  UNIQUE_KEY_T
DROP TABLE @SCHEMA@.UNIQUE_KEY_T PURGE;

---------------------------------------------------------------OLD:  KEY_HELPER_T
DROP TABLE @SCHEMA@.KEY_HELPER_T PURGE;

-----------------------------------------------------------NEW: MODERATOR_NEXT_ID
CREATE TABLE @SCHEMA@.MODERATOR_NEXT_ID  
(
  MODEL_ID                           VARCHAR2(256)       NOT NULL,
  UNIQUE_ID_KEY                      VARCHAR2(256)       NOT NULL , 
  START_ID_OF_NEXT_SET               NUMBER(20,0)        NOT NULL  
) TABLESPACE INSTANCE LOGGING;

ALTER TABLE @SCHEMA@.MODERATOR_NEXT_ID ADD
(
  PRIMARY KEY ( MODEL_ID, UNIQUE_ID_KEY )
  USING INDEX TABLESPACE INDEXTS
);
-------------------------------------------------------------NEW: RECORD/PLAYBACK
CREATE TABLE @SCHEMA@.RECORDED_EVENTS
(
  ID                                 NUMBER(20,0)        NOT NULL ,
  PAYLOAD_BLOB                       BLOB ,
  TIME_RECORDED                      TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
  BACKUP_ID                          VARCHAR2(32)
) TABLESPACE INSTANCE
  LOGGING;

ALTER TABLE @SCHEMA@.RECORDED_EVENTS ADD
(
  PRIMARY KEY ( ID )
  USING INDEX TABLESPACE INDEXTS
);

CREATE SEQUENCE @SCHEMA@.RECORDED_EVENTS_SEQ INCREMENT BY 1 START WITH 1 NOCYCLE ORDER;

CREATE TABLE @SCHEMA@.RECORDED_EVENTS_MODELVERSIONS
(
  EVENT_ID                           NUMBER(20,0)        NOT NULL ,
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  VERSION                            NUMBER(20,0)        NOT NULL ,
  PRIMARY KEY ( EVENT_ID, MODEL_ID, VERSION ) USING INDEX TABLESPACE INDEXTS,
  FOREIGN KEY ( EVENT_ID ) REFERENCES @SCHEMA@.RECORDED_EVENTS( ID ) ON DELETE CASCADE 
) TABLESPACE INSTANCE
  LOGGING;

---------------------------------------------------------------NEW: KPI HISTORY_T
CREATE TABLE @SCHEMA@.KPI_HISTORY_T
(
  KPI_ID                             VARCHAR2(384)       NOT NULL ,
  VERSION                            NUMBER(20,0)        NOT NULL ,
  KPI_DYNAMIC_FILTER_VALUE           VARCHAR2(500)       NOT NULL ,
  PERIOD_TIMESTAMP                   TIMESTAMP           NOT NULL ,
  FGS_FILTER_HASH                    NUMBER(20,0)  DEFAULT 0 NOT NULL ,
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  OBSERVED_TIME                      TIMESTAMP                    ,
  OBSERVED_VALUE                     NUMBER                       ,
  TARGET                             NUMBER                       ,
  HISTORY_UPDATE_TIME                TIMESTAMP                    ,
  HISTORY_VALUE                      NUMBER                       ,
  PREDICTION_BASIS_VALUE             NUMBER                       ,
  PREDICTION_BASIS_TIME              TIMESTAMP                    ,
  VERSION_ID                         NUMBER(5,0)         NOT NULL 
) TABLESPACE INSTANCE LOGGING;

ALTER TABLE @SCHEMA@.KPI_HISTORY_T ADD
(
  PRIMARY KEY ( KPI_ID, VERSION, KPI_DYNAMIC_FILTER_VALUE, PERIOD_TIMESTAMP, FGS_FILTER_HASH )
  USING INDEX TABLESPACE INDEXTS
);

--------------------------------------------------------------NEW: KPI PREDICTION
CREATE TABLE @SCHEMA@.KPI_TS_PREDICTION_T
(
  KPI_PREDICTION_ID                  VARCHAR2(512)       NOT NULL ,
  KPI_ID                             VARCHAR2(384)       NOT NULL ,
  VERSION                            NUMBER(20,0)        NOT NULL ,
  PREDICTION_MODEL_ID                VARCHAR2(384)       NOT NULL ,
  FGS_FILTER_HASH                    NUMBER(20,0)  DEFAULT 0 NOT NULL ,  
  PREDICTED_FOR_TIME                 TIMESTAMP                    ,
  PREDICTED_VALUE                    NUMBER                       ,
  LAST_KPI_TIME                      TIMESTAMP           NOT NULL ,
  STANDARD_DEVIATION                 NUMBER                       ,
  VALUE_PLUS_STDDEV                  NUMBER                       ,
  VALUE_MINUS_STDDEV                 NUMBER                       ,
  VERSION_ID                         NUMBER(5,0)         NOT NULL 
) TABLESPACE INSTANCE LOGGING;

ALTER TABLE @SCHEMA@.KPI_TS_PREDICTION_T ADD
(
  PRIMARY KEY ( KPI_PREDICTION_ID, VERSION, LAST_KPI_TIME, FGS_FILTER_HASH )
  USING INDEX TABLESPACE INDEXTS
);

CREATE TABLE @SCHEMA@.KPI_TS_PREDICTION_MODEL_T
(
  PREDICTION_MODEL_ID                VARCHAR2(384)       NOT NULL ,
  PREDICTION_MODEL_NAME              VARCHAR2(256)       NOT NULL ,
  KPI_ID                             VARCHAR2(384)       NOT NULL ,
  VERSION                            NUMBER(20,0)        NOT NULL ,
  MODEL_ID                           VARCHAR2(128)                ,
  KPI_DYNAMIC_FILTER_VALUE           VARCHAR2(500)                ,
  MODEL_XML                          BLOB                         ,
  PREDICTION_HORIZON                 NUMBER(10,0)                 ,
  PREDICT_TO_PERIOD_END              NUMBER(5,0)         NOT NULL ,
  PREDICTION_INTERVAL_NUM            NUMBER(10,0)                 ,
  PREDICTION_INTERVAL_UNIT           NUMBER(5,0)                  ,
  INTERVALS_PER_CYCLE                NUMBER(10,0)                 ,
  CYCLE_LENGTH_UNIT                  NUMBER(5,0)                  ,
  KPI_BEHAVIOR                       NUMBER(5,0)                  ,
  PREDICTION_SUBMODEL_ID             VARCHAR2(384)                ,
  MODEL_OPTIMIZE_SCHEDULE            NUMBER(5,0)                  ,
  CREATION_USER_ID                   VARCHAR2(256)                ,
  UPDATE_USER_ID                     VARCHAR2(256)                ,
  NEXT_EVAL_TIME                     TIMESTAMP                    ,
  NEXT_OPTIMIZE_TIME                 TIMESTAMP                    ,
  CREATION_TIME                      TIMESTAMP                    ,
  UPDATE_TIME                        TIMESTAMP                    ,
  INITIAL_KPI_TIME                   TIMESTAMP                    ,
  LAST_KPI_TIME                      TIMESTAMP                    ,
  PREDICTION_LAST_RUN                TIMESTAMP                    ,
  TIME_LAST_OPTIMIZED                TIMESTAMP                    ,
  IS_VALID                           NUMBER(5,0)         NOT NULL ,
  VERSION_ID                         NUMBER(5,0)         NOT NULL 
) TABLESPACE INSTANCE LOGGING;

ALTER TABLE @SCHEMA@.KPI_TS_PREDICTION_MODEL_T ADD
(
  PRIMARY KEY ( PREDICTION_MODEL_ID, VERSION )
  USING INDEX TABLESPACE INDEXTS
);

---------------------------------------------------------------NEW: WAS SCHEDULER
CREATE TABLE @SCHEMA@.MONSCHED_TASK
(
  TASKID NUMBER(19) NOT NULL,
  VERSION VARCHAR2(5) NOT NULL,
  ROW_VERSION NUMBER(10) NOT NULL,
  TASKTYPE NUMBER(10) NOT NULL,
  TASKSUSPENDED NUMBER(1) NOT NULL,
  CANCELLED NUMBER(1) NOT NULL,
  NEXTFIRETIME NUMBER(19) NOT NULL,
  STARTBYINTERVAL VARCHAR2(254),
  STARTBYTIME NUMBER(19),
  VALIDFROMTIME NUMBER(19),
  VALIDTOTIME NUMBER(19),
  REPEATINTERVAL VARCHAR2(254),
  MAXREPEATS NUMBER(10) NOT NULL,
  REPEATSLEFT NUMBER(10) NOT NULL,
  TASKINFO BLOB,
  NAME VARCHAR2(254),
  AUTOPURGE NUMBER(10) NOT NULL,
  FAILUREACTION NUMBER(10),
  MAXATTEMPTS NUMBER(10),
  QOS NUMBER(10),
  PARTITIONID NUMBER(10),
  OWNERTOKEN VARCHAR2(200) NOT NULL,
  CREATETIME NUMBER(19) NOT NULL,
  PRIMARY KEY (TASKID) USING INDEX TABLESPACE INDEXTS 
) TABLESPACE INSTANCE LOGGING;

CREATE INDEX @SCHEMA@.MONSCHED_TASK_IDX1 ON @SCHEMA@.MONSCHED_TASK (TASKID, OWNERTOKEN) TABLESPACE INDEXTS;

CREATE INDEX @SCHEMA@.MONSCHED_TASK_IDX2 ON @SCHEMA@.MONSCHED_TASK (NEXTFIRETIME ASC, REPEATSLEFT, PARTITIONID) 
  TABLESPACE INDEXTS ;

CREATE TABLE @SCHEMA@.MONSCHED_TREG 
(
  REGKEY VARCHAR2(254) NOT NULL ,
  REGVALUE VARCHAR2(254) ,
  PRIMARY KEY ( REGKEY ) USING INDEX TABLESPACE INDEXTS
) TABLESPACE INSTANCE LOGGING;

CREATE TABLE @SCHEMA@.MONSCHED_LMGR 
(
  LEASENAME VARCHAR2(254) NOT NULL,
  LEASEOWNER VARCHAR2(254),
  LEASE_EXPIRE_TIME NUMBER(19),
  DISABLED VARCHAR2(254),
  PRIMARY KEY ( LEASENAME ) USING INDEX TABLESPACE INDEXTS
) TABLESPACE INSTANCE LOGGING;

CREATE TABLE @SCHEMA@.MONSCHED_LMPR 
(
  LEASENAME VARCHAR2(254) NOT NULL,
  NAME VARCHAR2(254) NOT NULL,
  VALUE VARCHAR2(254) NOT NULL 
) TABLESPACE INSTANCE LOGGING;

CREATE INDEX @SCHEMA@.MONSCHED_LMPR_IDX1 ON @SCHEMA@.MONSCHED_LMPR (LEASENAME, NAME) TABLESPACE INDEXTS ;

----------------------------------------------------------------NEW: DS SCHEDULER
CREATE TABLE @SCHEMA@.DSS_MODEL_CONFIG_T
(
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  PRIORITY                           NUMBER(20,0)        NOT NULL ,
  STATUS                             NUMBER(20,0)        NOT NULL ,
  LAST_STARTED                       TIMESTAMP                    ,
  LAST_COMPLETED                     TIMESTAMP                    ,
  LAST_RUN_STATUS                    NUMBER(20,0)                 ,
  TASK_ID                            VARCHAR2(128)                ,
  VERSION_ID                         NUMBER(5,0)         NOT NULL ,
  PRIMARY KEY (MODEL_ID) USING INDEX TABLESPACE INDEXTS
) TABLESPACE INSTANCE LOGGING;

CREATE TABLE @SCHEMA@.DSS_MODEL_SERVICE_CONFIG_T
(
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  SERVICE_NAME                       VARCHAR2(128)       NOT NULL ,
  SERVICE_PRIORITY                   NUMBER(20,0)        NOT NULL ,
  SERVICE_INTERVAL                   NUMBER(20,0)        NOT NULL ,
  SERVICE_INT_UNIT                   NUMBER(20,0)        NOT NULL ,
  START_TIME                         TIMESTAMP           NOT NULL ,
  STATUS                             NUMBER(20,0)        NOT NULL ,
  LAST_STARTED                       TIMESTAMP                    ,
  LAST_COMPLETED                     TIMESTAMP                    ,
  LAST_RUN_STATUS                    NUMBER(20,0)                 ,
  NEXT_EVALUATION                    TIMESTAMP                    ,
  VERSION_ID                         NUMBER(5,0)         NOT NULL ,
  PRIMARY KEY(MODEL_ID, SERVICE_NAME) USING INDEX TABLESPACE INDEXTS
) TABLESPACE INSTANCE LOGGING;

CREATE TABLE @SCHEMA@.DSS_MODEL_SERVICE_VER_CONFIG_T
(
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  VERSION                            NUMBER(20,0)        NOT NULL ,
  SERVICE_NAME                       VARCHAR2(128)       NOT NULL ,
  STATUS                             NUMBER(20,0)        NOT NULL ,
  LAST_STARTED                       TIMESTAMP                    ,
  LAST_COMPLETED                     TIMESTAMP                    ,
  LAST_RUN_STATUS                    NUMBER(20,0)                 ,
  MESSAGE                            VARCHAR2(4000)               ,
  VERSION_ID                         NUMBER(5,0)         NOT NULL ,
  PRIMARY KEY ( MODEL_ID, VERSION, SERVICE_NAME) USING INDEX TABLESPACE INDEXTS 
) TABLESPACE INSTANCE LOGGING;

CREATE TABLE @SCHEMA@.DSS_MODEL_CUBE_STATUS_T
(
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  MC_ID                              VARCHAR2(128)       NOT NULL ,
  VERSION                            NUMBER(20,0)        NOT NULL ,
  SERVER                             VARCHAR2(128)       NOT NULL ,
  IS_STALE                           NUMBER(5,0)         NOT NULL ,
  STALE_TIME                         TIMESTAMP                    ,
  FRESH_TIME                         TIMESTAMP                    ,
  VERSION_ID                         NUMBER(5,0)         NOT NULL ,
  PRIMARY KEY ( MODEL_ID, MC_ID, VERSION, SERVER ) USING INDEX TABLESPACE INDEXTS 
) TABLESPACE INSTANCE LOGGING;

CREATE TABLE @SCHEMA@.DSS_MODEL_ARCHIVE_VER_CONFIG_T
(
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  VERSION                            NUMBER(20,0)        NOT NULL ,
  OPERATION_NAME                     VARCHAR2(32)        NOT NULL ,
  TIME_SPAN                          VARCHAR2(128)       NOT NULL ,
  PATH_NAME                          VARCHAR2(1000)               ,
  LAST_TIMESTAMP                     VARCHAR2(32)                 ,
  APPEND_FLAG                        NUMBER(5,0)                  ,
  MAX_FILE_SIZE                      NUMBER(20,0)                 ,
  VERSION_ID                         NUMBER(5,0)         NOT NULL ,
  PRIMARY KEY ( MODEL_ID, VERSION ) USING INDEX TABLESPACE INDEXTS    
) TABLESPACE INSTANCE LOGGING;

--------------------------------------------------------------NEW: DYNAMIC ALERTS
CREATE TABLE @SCHEMA@.ACT_SITUATION_T
(
  ID                                 VARCHAR2(384)       NOT NULL ,
  DISPLAY_NAME                       VARCHAR2(1000)      NOT NULL ,
  DESCRIPTION                        VARCHAR2(256)                ,
  ACTIVE                             NUMBER(20,0)        NOT NULL ,
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  VERSION                            NUMBER(20,0)        NOT NULL ,
  REPEATING                          NUMBER(5,0)         NOT NULL ,
  INTERVAL                           NUMBER(5,0)         NOT NULL ,
  TIME_POINT                         NUMBER(20,0)        NOT NULL ,
  TIME_MULTIPLE                      NUMBER(20,0)        NOT NULL ,
  TIME_OFFSET                        NUMBER(20,0)        NOT NULL ,
  TIME_ZONE                          VARCHAR2(60)        NOT NULL ,
  KPI_ID                             VARCHAR2(384)                ,
  TIME_PROPERTIES                    CLOB                         ,
  START_TIME                         TIMESTAMP           NOT NULL ,
  LAST_EVAL                          TIMESTAMP                    ,
  NEXT_EVAL                          TIMESTAMP           NOT NULL ,
  SIT_TRIGGERED                      NUMBER(5,0)         NOT NULL ,
  USER_ID                            VARCHAR2(256)       NOT NULL ,
  VIEW_ACCESS                        NUMBER(5,0)         NOT NULL ,
  CREATE_TIME                        TIMESTAMP           NOT NULL ,
  VERSION_ID                         NUMBER(5,0)         NOT NULL 
) TABLESPACE INSTANCE LOGGING;

ALTER TABLE @SCHEMA@.ACT_SITUATION_T ADD
(
  PRIMARY KEY ( ID )
  USING INDEX TABLESPACE INDEXTS
);

CREATE TABLE @SCHEMA@.ACT_SIT_TRIG_T
(
  ID                                 VARCHAR2(384)       NOT NULL ,
  SITUATION_ID                       VARCHAR2(384)       NOT NULL ,
  KPI_ID                             VARCHAR2(384)       NOT NULL ,
  PREDICTION_MODEL_ID                VARCHAR2(384)                ,
  PREDICTION_TYPE                    VARCHAR2(20)                 ,
  TYPE                               VARCHAR2(256)       NOT NULL ,
  FIELD_TYPE                         VARCHAR2(256)       NOT NULL ,
  FIELD                              VARCHAR2(256)                ,
  COND_SETUP                         NUMBER(5,0)                  ,
  VERSION_ID                         NUMBER(5,0)         NOT NULL 
) TABLESPACE INSTANCE LOGGING;

ALTER TABLE @SCHEMA@.ACT_SIT_TRIG_T ADD
(
  PRIMARY KEY ( ID )
  USING INDEX TABLESPACE INDEXTS
);

------------------------------------------------------------NEW: DIRECT TO DEPLOY
CREATE TABLE @SCHEMA@.D2D_ITEM (
  ID                                 VARCHAR2(255)       NOT NULL , 
  STATE                              VARCHAR2(20)        NOT NULL ,
  ITEM_LEVEL                         NUMBER(10,0)        NOT NULL ,
  MODULE_NAME                        VARCHAR2(255)                ,
  APPLICATION_NAME                   VARCHAR2(255)                ,
  VERSION                            VARCHAR2(30)                 , 
  NEW_APP_NAME                       VARCHAR2(255)                ,
  PRIMARY KEY ( ID ) USING INDEX TABLESPACE INDEXTS
) TABLESPACE INSTANCE
  LOGGING;

CREATE TABLE @SCHEMA@.D2D_PROGRESS (
  ITEM_ID                            VARCHAR2(255)       NOT NULL ,
  PROGRESS                           NUMBER(10,0)                 ,
  PROGRESS_MSG                       VARCHAR2(255)                ,
  PROGRESS_ERROR_CODE                VARCHAR2(255)                ,
  PRIMARY KEY ( ITEM_ID ) USING INDEX TABLESPACE INDEXTS ,
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) ON DELETE CASCADE 
) TABLESPACE INSTANCE
  LOGGING;

CREATE TABLE @SCHEMA@.D2D_CONTENT (
  ITEM_ID                            VARCHAR2(255)       NOT NULL ,
  PI                                 BLOB                         ,
  PRIMARY KEY ( ITEM_ID ) USING INDEX TABLESPACE INDEXTS ,
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) ON DELETE CASCADE 
) TABLESPACE INSTANCE
  LOGGING;

CREATE TABLE @SCHEMA@.D2D_METADATA(
  ITEM_ID                            VARCHAR2(255)       NOT NULL ,
  NAME                               VARCHAR2(255)       NOT NULL ,
  VALUE                              VARCHAR2(255)                ,
  PRIMARY KEY ( ITEM_ID, NAME ) USING INDEX TABLESPACE INDEXTS    ,
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) ON DELETE CASCADE 
) TABLESPACE INSTANCE
  LOGGING;

CREATE TABLE @SCHEMA@.D2D_LOCK ( 
  LOCK_ID                            CHARACTER(2)       NOT NULL  ,
  LASTUPDATE                         TIMESTAMP                    ,
  PRIMARY KEY ( LOCK_ID ) USING INDEX TABLESPACE INDEXTS 
) TABLESPACE INSTANCE
  LOGGING;

INSERT INTO @SCHEMA@.D2D_LOCK VALUES ('N1', NULL);
INSERT INTO @SCHEMA@.D2D_LOCK VALUES ('N2', NULL);

CREATE TABLE @SCHEMA@.D2D_MESSAGE (
  ITEM_ID                            VARCHAR2(255)       NOT NULL ,
  SEQ                                NUMBER(10,0)        NOT NULL ,
  ID                                 VARCHAR2(63)                 ,
  DESCRIPTION                        VARCHAR2(1024)               ,
  MSG_RESOURCE                       VARCHAR2(255)                ,
  LOCATION                           VARCHAR2(63)                 ,
  FOLDER                             VARCHAR2(255)                ,
  MSG_STR                            VARCHAR2(63)                 ,
  TAG	                             VARCHAR(263)                 ,
  SEVERITY                           VARCHAR2(15)                 ,
  TIME                               TIMESTAMP                    ,
  PRIMARY KEY ( ITEM_ID, SEQ ) USING INDEX TABLESPACE INDEXTS     ,
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) ON DELETE CASCADE 
) TABLESPACE INSTANCE
  LOGGING;

------------------------------------------------------------CHANGED: META_MODEL_T
ALTER TABLE @SCHEMA@.META_MODEL_T 
  ADD(  CODE_GEN_VERSION                VARCHAR2(8),
        BUILD_ID                        VARCHAR2(40)
     );

--------------------------------------------------CHANGED: META_MONITOR_CONTEXT_T
ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T 
  MODIFY CUBE_NAME                      VARCHAR2(1000);

--------------------------------------------------------CHANGED: META_DIMENSION_T
ALTER TABLE @SCHEMA@.META_DIMENSION_T 
  ADD(  ABX_DISPLAY_NAME                VARCHAR2(1000));

---------------------------------------------------------CHANGED: META_DIM_ATTR_T
ALTER TABLE @SCHEMA@.META_DIM_ATTR_T
  ADD(  ABX_DIM_ATTR_NAME               VARCHAR2(1000));

----------------------------------------------------------CHANGED: META_MEASURE_T
ALTER TABLE @SCHEMA@.META_MEASURE_T
  ADD(  ABX_DISPLAY_NAME                VARCHAR2(1000));

--------------------------------------------------------------CHANGED: META_KPI_T
ALTER TABLE @SCHEMA@.META_KPI_T
  ADD(  ENABLE_KPI_HISTORY                 NUMBER(5,0)                  ,
        ENABLE_KPI_PREDICTIONS             NUMBER(5,0)                  ,
        HISTORY_VALID_FROM                 TIMESTAMP                    ,
        HIST_GRANULARITY                   NUMBER(5,0)                  ,
        HIST_REPEATING_PERIOD_BASIS        NUMBER(5,0)                  ,
        HIST_REPEATING_PERIOD_DURATION     NUMBER(5,0)                  ,
        HIST_REPEATING_PERIOD_QUANTITY     NUMBER(10,0)                 ,
        HIST_ROLLING_PERIOD_DURATION       NUMBER(5,0)                  ,
        HIST_ROLLING_PERIOD_QUANTITY       NUMBER(10,0)                 ,
        HIST_TIME_RANGE_START              TIMESTAMP                    ,
        HIST_TIME_RANGE_END                TIMESTAMP                    ,
        HIST_TIMEZONE                      VARCHAR2(30)                 ,
        HIST_INCLUDE_PREDICTIONS           NUMBER(5,0)                  ,
        HIST_ALL_VERSIONS                  NUMBER(5,0)                  ,
        HIST_TIME_RANGE_METHOD             NUMBER(5,0)                  ,
        HIST_DISPLAY_TARGET                NUMBER(5,0)                  ,
        HIST_DISPLAY_RANGES                NUMBER(5,0)                  ,
        HIST_RETRO_ACTIVE_CALC_QTY         NUMBER(10,0)                 ,
        DEFAULT_PREDICTION_MODEL_ID        VARCHAR2(384)                
     );

----------------------------------------------------------------CHANGED: DIM_TIME
ALTER TABLE @SCHEMA@.DIM_TIME
  ADD MONTH_NAME  VARCHAR2(27) DEFAULT 'Unknown' NOT NULL;

UPDATE @SCHEMA@.DIM_TIME
   SET MONTH_NAME =
        CASE
                   WHEN MONTH_NUM = 1  THEN 'January'
                   WHEN MONTH_NUM = 2  THEN 'February'
                   WHEN MONTH_NUM = 3  THEN 'March'
                   WHEN MONTH_NUM = 4  THEN 'April'
                   WHEN MONTH_NUM = 5  THEN 'May'
                   WHEN MONTH_NUM = 6  THEN 'June'
                   WHEN MONTH_NUM = 7  THEN 'July'
                   WHEN MONTH_NUM = 8  THEN 'August'
                   WHEN MONTH_NUM = 9  THEN 'September'
                   WHEN MONTH_NUM = 10 THEN 'October'
                   WHEN MONTH_NUM = 11 THEN 'November'
                   WHEN MONTH_NUM = 12 THEN 'December'
                   ELSE 'Error'
         END; 

--------------------------------------------------CHANGED: META_MONITOR_CONTEXT_T
ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T
  MODIFY CUBE_NAME NULL;

---------------------------------------------------------CHANGED: RAT_PARTY_ROLES
ALTER TABLE @SCHEMA@.RAT_PARTY_ROLES
  ADD(  MEMBER_TYPE                VARCHAR2(20));

----------------------------------------------------------CHANGED: ACT_MGR_ALERTS
ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T
  MODIFY BUS_SIT_NAME   VARCHAR2(384);

---------------------------------------------------CHANGED: ACTION_HANLDER_CTRL_T
ALTER TABLE @SCHEMA@.ACTION_HANDLER_CTRL_T
  MODIFY ACTION_ID      VARCHAR2(384);

-------------------------------------------------------------CHANGED: ACT_TMPLT_T
ALTER TABLE @SCHEMA@.ACT_TMPLT_T
  MODIFY  (ID              VARCHAR2(384),
           NAME	           VARCHAR2(384)
          );

----------------------------------------------------------------CHANGED: ACTION_T
ALTER TABLE @SCHEMA@.ACTION_T
  MODIFY (ID              VARCHAR2(384),
          TEMPLATE_ID     VARCHAR2(384)
         );

-------------------------------------------------------CHANGED: SUBSCRIBED_USER_T
ALTER TABLE @SCHEMA@.SUBSCRIBED_USER_T
   MODIFY ETAACTRL_ID     VARCHAR2(384);

--------------------------------------------------------------CHANGED: ETAMATCH_T
ALTER TABLE @SCHEMA@.ETAMATCH_T
  MODIFY (ID              VARCHAR2(384),
	  EXTENSION_NAME  VARCHAR2(384)
         );

--------------------------------------------------------------CHANGED: ETAACTRL_T
ALTER TABLE @SCHEMA@.ETAACTRL_T
  MODIFY (ID              VARCHAR2(384),
	  ETAMID	  VARCHAR2(384),
	  ACTION_ID       VARCHAR2(384),
	  NAME            VARCHAR2(1000)
         );

--  Delete orphan records from the ACTION_HANDLER_CTRL_T table
DELETE FROM @SCHEMA@.ACTION_HANDLER_CTRL_T C WHERE 
NOT EXISTS (select 1 from @SCHEMA@.ACTION_T A WHERE A.ID = C.ACTION_ID);

ALTER TABLE @SCHEMA@.ACTION_HANDLER_CTRL_T
  ADD CONSTRAINT D_ACTION_ID FOREIGN KEY (ACTION_ID)
  REFERENCES @SCHEMA@.ACTION_T(ID) ON DELETE CASCADE;

---------- ALPHABLOX TABLES

CREATE TABLE @SCHEMA@.ABX_VERSION 
(
  DESCRIPTION                        VARCHAR2(32)        NOT NULL, 
  VALUE                              VARCHAR2(64)        NOT NULL
) TABLESPACE INSTANCE
  LOGGING;


CREATE TABLE @SCHEMA@.ABX_PROPERTY_MAP 
(
  ID                                 NUMBER(32, 0)       NOT NULL, 
  PROPERTY                           VARCHAR2(255)       NOT NULL, 
  SEQUENCE                           NUMBER(4, 0)        NOT NULL, 
  VALUE                              VARCHAR2(255)
) TABLESPACE INSTANCE
  LOGGING;

CREATE TABLE @SCHEMA@.ABX_OBJECTS 
(
  ID                                 NUMBER(32, 0)       NOT NULL, 
  SEQUENCE                           NUMBER(4, 0)        NOT NULL, 
  VALUE                              VARCHAR2(4000)      NOT NULL
) TABLESPACE INSTANCE
  LOGGING;


CREATE TABLE @SCHEMA@.ABX_LOOKUP 
(
  ID                                 NUMBER(32, 0)       NOT NULL, 
  CONTEXT                            VARCHAR2(255), 
  NAME                               VARCHAR2(96)        NOT NULL, 
  TYPE                               NUMBER(1, 0)        NOT NULL, 
  LAST_MODIFIED                      DATE DEFAULT SYSDATE
) TABLESPACE INSTANCE
  LOGGING;


CREATE TABLE @SCHEMA@.ABX_TYPES 
(
  ID                                 NUMBER(2, 0)        NOT NULL, 
  DESCRIPTION                        VARCHAR2(64)        NOT NULL, 
  INTERNAL_NAME                      VARCHAR2(64)        NOT NULL
) TABLESPACE INSTANCE
  LOGGING;


CREATE TABLE @SCHEMA@.ABX_LOOKUP_VALUES
(
  DESCRIPTION                        VARCHAR2(16)        NOT NULL, 
  VALUE                              NUMBER(32, 0)       NOT NULL
) TABLESPACE INSTANCE
  LOGGING;

CREATE UNIQUE INDEX @SCHEMA@.IPROPERTYIDPROPSEQ ON @SCHEMA@.ABX_PROPERTY_MAP 
  (ID, PROPERTY, SEQUENCE) TABLESPACE INDEXTS;

CREATE INDEX @SCHEMA@.IPROPERTYPROPSEQ ON @SCHEMA@.ABX_PROPERTY_MAP 
  (PROPERTY, SEQUENCE) TABLESPACE INDEXTS;

CREATE UNIQUE INDEX @SCHEMA@.ILOOKUPCONTEXTNAME ON @SCHEMA@.ABX_LOOKUP 
  (CONTEXT, NAME) TABLESPACE INDEXTS;
  
CREATE INDEX @SCHEMA@.ILOOKUPCNIT ON @SCHEMA@.ABX_LOOKUP 
  (CONTEXT, NAME, ID, TYPE) TABLESPACE INDEXTS;

CREATE UNIQUE INDEX @SCHEMA@.IOBJECTIDSEQ ON @SCHEMA@.ABX_OBJECTS 
  (ID, SEQUENCE) TABLESPACE INDEXTS;

CREATE UNIQUE INDEX @SCHEMA@.ILOOKUPVALUEDESC ON @SCHEMA@.ABX_LOOKUP_VALUES 
  (DESCRIPTION) TABLESPACE INDEXTS;

CREATE UNIQUE INDEX @SCHEMA@.IVERSIONDESC ON @SCHEMA@.ABX_VERSION 
  (DESCRIPTION) TABLESPACE INDEXTS;

CREATE UNIQUE INDEX @SCHEMA@.ITYPESID ON @SCHEMA@.ABX_TYPES 
  (ID) TABLESPACE INDEXTS;


ALTER TABLE @SCHEMA@.ABX_LOOKUP ADD CONSTRAINT PKABX_LOOKUPID PRIMARY KEY (ID);

ALTER TABLE @SCHEMA@.ABX_OBJECTS ADD CONSTRAINT FKABX_OBJECTSID FOREIGN KEY (ID) REFERENCES @SCHEMA@.ABX_LOOKUP (ID);

ALTER TABLE @SCHEMA@.ABX_PROPERTY_MAP ADD CONSTRAINT FKABX_PROPERTY_MAPID FOREIGN KEY (ID) REFERENCES @SCHEMA@.ABX_LOOKUP (ID);


INSERT INTO @SCHEMA@.ABX_LOOKUP_VALUES VALUES ('lookup_id', 0);
INSERT INTO @SCHEMA@.ABX_TYPES VALUES (0, 'Unknown', 'Unknown');
INSERT INTO @SCHEMA@.ABX_TYPES VALUES (1, 'Properties (instance of java.util.Map)', 'java.util.Map');
INSERT INTO @SCHEMA@.ABX_TYPES VALUES (2, 'Container (Context)', 'javax.naming.Context');
INSERT INTO @SCHEMA@.ABX_TYPES VALUES (3, 'ASCII Text (TextArrayRef)', 'com.ibm.jndisp.util.TextArrayRef');
INSERT INTO @SCHEMA@.ABX_TYPES VALUES (4, 'Binary (ByteArrayRef)', 'com.ibm.jndisp.util.ByteArrayRef');

CREATE TABLE @SCHEMA@.CEI_SERVER_SOURCE_T
(
  SERVER_ID                          VARCHAR2(256)       NOT NULL ,
  ALIAS                              VARCHAR2(128)                ,
  DESCRIPTION                        VARCHAR2(256)                ,
  DEFAULT_SERVER                     NUMBER(5,0)                  ,
  CELL                               VARCHAR2(128)                ,
  NODE                               VARCHAR2(128)                ,
  SERVER                             VARCHAR2(128)                ,
  CLUSTER_ID                         VARCHAR2(128)                ,
  HOST                               VARCHAR2(128)                ,
  RMI_PORT                           VARCHAR2(128)                ,
  EVENT_GROUP_PROFILE_LIST           VARCHAR2(128)                ,
  AUTH_ALIAS                         VARCHAR2(128)                ,
  QUEUE_BYPASS_CONFIG                NUMBER(5,0)                  ,
  QUEUE_BASED_CONFIG                 NUMBER(5,0)                  ,
  VERSION_ID                         NUMBER(5,0)         NOT NULL 
) TABLESPACE INSTANCE
  LOGGING;

ALTER TABLE @SCHEMA@.CEI_SERVER_SOURCE_T ADD
(
  PRIMARY KEY ( SERVER_ID )
  USING INDEX TABLESPACE INDEXTS
);

ALTER TABLE @SCHEMA@.META_MODEL_UNVERSIONED_T ADD
(
  SERVER_ID                          VARCHAR2(256)
);


CREATE TABLE @SCHEMA@.MM_TO_WPS_PT  (
  MODEL_ID           		     VARCHAR2(256)       NOT NULL,
  VERSION_ID                         NUMBER(20,0)        NOT NULL, 
  WPS_PT_ID                          VARCHAR2(512)       NOT NULL,
  WPS_PT_VALID_FROM                  VARCHAR2(128)       NOT NULL,
  PRIMARY KEY (MODEL_ID, VERSION_ID, WPS_PT_ID, WPS_PT_VALID_FROM)
      USING INDEX TABLESPACE INDEXTS
) TABLESPACE INSTANCE
  LOGGING;
  
  
-- View: ActTmplt
CREATE OR REPLACE FORCE VIEW @SCHEMA@.ACT_TMPLT(ID, NAME, TYPE, DESCRIPTION ) AS 
 SELECT ACT_TMPLT_T.ID, ACT_TMPLT_T.NAME, ACT_TMPLT_T.TYPE, ACT_TMPLT_T.DESCRIPTION 
 FROM @SCHEMA@.ACT_TMPLT_T;
 
-- View: ETAMatch
CREATE OR REPLACE FORCE VIEW @SCHEMA@.ETAMATCH(ID, DETERMINER_TYPE, EXTENSION_NAME, DESCRIPTION ) AS 
 SELECT ETAMATCH_T.ID, ETAMATCH_T.DETERMINER_TYPE, ETAMATCH_T.EXTENSION_NAME, ETAMATCH_T.DESCRIPTION 
 FROM @SCHEMA@.ETAMATCH_T;
 
-- View: Action
CREATE OR REPLACE FORCE VIEW @SCHEMA@.ACTION(ID, NAME, TYPE ) AS 
 SELECT ACTION_T.ID, ACTION_T.NAME, ACTION_T.TYPE 
 FROM @SCHEMA@.ACTION_T;

-- View: ActMgrProp
CREATE OR REPLACE FORCE VIEW @SCHEMA@.ACT_MGR_PROP(ACTION_PROP_NAME, ACTION_PROP_VALUE ) AS 
 SELECT ACTION_MANAGER_PROP_T.ACTION_PROP_NAME, ACTION_MANAGER_PROP_T.ACTION_PROP_VALUE 
 FROM @SCHEMA@.ACTION_MANAGER_PROP_T; 

-- View: PlugSvc
CREATE OR REPLACE FORCE VIEW @SCHEMA@.PLUG_SVC(ID, NAME, SERVICE_TYPE, SUB_TYPE, ACTION_HANDLER_ID ) AS 
 SELECT PLUG_SVC_T.ID, PLUG_SVC_T.NAME, PLUG_SVC_T.SERVICE_TYPE, PLUG_SVC_T.SUB_TYPE, PLUG_SVC_T.ACTION_HANDLER_ID 
 FROM @SCHEMA@.PLUG_SVC_T; 

-- View: Alerts
CREATE OR REPLACE FORCE VIEW @SCHEMA@.ALERTS(ALERT_ID, BUS_SIT_NAME, ALERT_SUBJECT, ALERT_TIMESTAMP ) AS 
 SELECT ACT_MGR_ALERTS_T.ALERT_ID, ACT_MGR_ALERTS_T.BUS_SIT_NAME, ACT_MGR_ALERTS_T.ALERT_SUBJECT, ACT_MGR_ALERTS_T.ALERT_TIMESTAMP 
 FROM @SCHEMA@.ACT_MGR_ALERTS_T; 

-- View: EQ
CREATE OR REPLACE FORCE view @SCHEMA@.EQ_FE_IDS
(
  DBID,
  INSTANCE_DBID,
  EQ_SEQUENCE
)
AS SELECT DBID, INSTANCE_DBID, EQ_SEQUENCE FROM @SCHEMA@.EQ_FAILED_EVENT_T;


CREATE TABLE @SCHEMA@.DMS_TRACE_T
(
DMS_STORED_PROC                      VARCHAR2(128)                ,
START_TIME                           TIMESTAMP                    ,
END_TIME                             TIMESTAMP                    ,
ROWS_MERGED                          NUMBER(10,0)                 ,
ROWS_PRUNED                          NUMBER(10,0)                 ,
START_DCL                            NUMBER(10,0)                 ,
START_DCC                            NUMBER(10,0)                 ,
END_DCL                              NUMBER(10,0)                 ,
END_DCC                              NUMBER(10,0)                 ,
START_MCT                            NUMBER(10,0)                 ,
START_TGT                            NUMBER(10,0)                 ,
END_MCT                              NUMBER(10,0)                 ,
END_TGT                              NUMBER(10,0)                 ,
ROWS_INSERTED                        NUMBER(10,0)                 ,
ROWS_UPDATED                         NUMBER(10,0) 
) TABLESPACE INSTANCE
  LOGGING;


CREATE INDEX @SCHEMA@.DMS_TRACE_I1 ON @SCHEMA@.DMS_TRACE_T (DMS_STORED_PROC, START_TIME) TABLESPACE INDEXTS;        
        

-- Changes for Monitor 7.5

ALTER TABLE @SCHEMA@.META_MODEL_T 
  ADD(  ROUTING_JARS    BLOB);

---------- FINE GRAINED SECURITY TABLES

CREATE TABLE @SCHEMA@.FGS_SECURITY_FILTER_T
(
  CONTEXT_KEY                        VARCHAR2(384)       NOT NULL ,
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  MCID                               VARCHAR2(256)       NOT NULL ,
  ENTITY_ID                          VARCHAR2(256)       NOT NULL ,
  ENTITY_TYPE                        VARCHAR2(20)        NOT NULL ,
  DISPLAY_INDICATION                 NUMBER(5,0)                  ,
  FILTER_VALUE                       CLOB                         ,
  LAST_UPDATED                       TIMESTAMP                    ,  
  VERSION_ID                         NUMBER(5,0)         NOT NULL 
) TABLESPACE INSTANCE
  LOGGING;

ALTER TABLE @SCHEMA@.FGS_SECURITY_FILTER_T ADD
(
  PRIMARY KEY ( CONTEXT_KEY, ENTITY_ID, ENTITY_TYPE )
  USING INDEX TABLESPACE MONIDXTS
);

CREATE TABLE @SCHEMA@.FGS_METRIC_T
(
  METRIC_KEY                         VARCHAR2(384)       NOT NULL ,
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  MCID                               VARCHAR2(256)       NOT NULL ,
  METRIC_ID                          VARCHAR2(256)       NOT NULL ,
  ENTITY_ID                          VARCHAR2(256)       NOT NULL ,
  ENTITY_TYPE                        VARCHAR2(20)        NOT NULL ,
  VISIBLE                            NUMBER(5,0)         NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                    ,  
  VERSION_ID                         NUMBER(5,0)         NOT NULL 
) TABLESPACE INSTANCE
  LOGGING;

ALTER TABLE @SCHEMA@.FGS_METRIC_T ADD
(
  PRIMARY KEY ( METRIC_KEY, ENTITY_ID, ENTITY_TYPE )
  USING INDEX TABLESPACE INDEXTS
);

CREATE TABLE @SCHEMA@.FGS_MEASURE_T
(
  MEASURE_KEY                        VARCHAR2(384)       NOT NULL ,
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  MCID                               VARCHAR2(128)       NOT NULL ,
  CUBE_ID                            VARCHAR2(128)       NOT NULL ,
  MEASURE_ID                         VARCHAR2(128)       NOT NULL ,
  ENTITY_ID                          VARCHAR2(128)       NOT NULL ,
  ENTITY_TYPE                        VARCHAR2(20)        NOT NULL ,
  VISIBLE                            NUMBER(5,0)         NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                    ,  
  VERSION_ID                         NUMBER(5,0)         NOT NULL 
) TABLESPACE INSTANCE
  LOGGING;

ALTER TABLE @SCHEMA@.FGS_MEASURE_T ADD
(
  PRIMARY KEY ( MEASURE_KEY, ENTITY_ID, ENTITY_TYPE )
  USING INDEX TABLESPACE INDEXTS
);

CREATE TABLE @SCHEMA@.FGS_DIMENSION_T
(
  DIMENSION_KEY                      VARCHAR2(384)       NOT NULL ,
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  MCID                               VARCHAR2(128)       NOT NULL ,
  CUBE_ID                            VARCHAR2(128)       NOT NULL ,
  DIMENSION_ID                       VARCHAR2(128)       NOT NULL ,
  ENTITY_ID                          VARCHAR2(128)       NOT NULL ,
  ENTITY_TYPE                        VARCHAR2(20)        NOT NULL ,
  VISIBLE                            NUMBER(5,0)         NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                    ,  
  VERSION_ID                         NUMBER(5,0)         NOT NULL 
) TABLESPACE INSTANCE
  LOGGING;

ALTER TABLE @SCHEMA@.FGS_DIMENSION_T ADD
(
  PRIMARY KEY ( DIMENSION_KEY, ENTITY_ID, ENTITY_TYPE )
  USING INDEX TABLESPACE INDEXTS
);

CREATE TABLE @SCHEMA@.FGS_ALERT_TMPLT_T
(
  ALERT_KEY                          VARCHAR2(384)       NOT NULL ,
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  TEMPLATE_ID                        VARCHAR2(128)       NOT NULL ,
  ENTITY_ID                          VARCHAR2(128)       NOT NULL ,
  ENTITY_TYPE                        VARCHAR2(20)        NOT NULL ,
  VISIBLE                            NUMBER(5,0)         NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                    ,  
  VERSION_ID                         NUMBER(5,0)         NOT NULL 
) TABLESPACE INSTANCE
  LOGGING;

ALTER TABLE @SCHEMA@.FGS_ALERT_TMPLT_T ADD
(
  PRIMARY KEY ( ALERT_KEY, ENTITY_ID, ENTITY_TYPE )
  USING INDEX TABLESPACE INDEXTS
);

CREATE TABLE @SCHEMA@.FGS_KPI_T
(
  KPI_KEY                            VARCHAR2(384)       NOT NULL ,
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  KPIID                              VARCHAR2(128)       NOT NULL ,
  ENTITY_ID                          VARCHAR2(128)       NOT NULL ,
  ENTITY_TYPE                        VARCHAR2(20)        NOT NULL ,
  VISIBLE                            NUMBER(5,0)         NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                    ,  
  VERSION_ID                         NUMBER(5,0)         NOT NULL 
) TABLESPACE INSTANCE
  LOGGING;

ALTER TABLE @SCHEMA@.FGS_KPI_T ADD
(
  PRIMARY KEY ( KPI_KEY, ENTITY_ID, ENTITY_TYPE )
  USING INDEX TABLESPACE INDEXTS
);

CREATE TABLE @SCHEMA@.FGS_MONITOR_CONTEXT_T
(
  MC_KEY                             VARCHAR2(256)       NOT NULL ,
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  MCID                               VARCHAR2(256)       NOT NULL ,
  ENTITY_ID                          VARCHAR2(256)       NOT NULL ,
  ENTITY_TYPE                        VARCHAR2(20)        NOT NULL ,
  VISIBLE                            NUMBER(5,0)         NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                    ,
  VERSION_ID                         NUMBER(5,0)         NOT NULL 
) TABLESPACE INSTANCE
  LOGGING;

ALTER TABLE @SCHEMA@.FGS_MONITOR_CONTEXT_T ADD
(
  PRIMARY KEY ( MC_KEY, ENTITY_ID, ENTITY_TYPE )
  USING INDEX TABLESPACE INDEXTS
);

CREATE TABLE @SCHEMA@.MONPROPS_T
(
 CONTEXT	                     VARCHAR2(128)       NOT NULL ,
 PROPERTY	                     VARCHAR2(128)       NOT NULL ,
 CHARVALUE	                     VARCHAR2(512)                ,
 INTVALUE	                     NUMBER(10,0)                 ,
 DECVALUE	                     NUMBER                       , 
 TIMEVALUE	                     TIMESTAMP                    ,
 CLOBVALUE 	                     CLOB,
 BLOBVALUE 	                     BLOB,
 VERSION_ID                          NUMBER(5,0)
) TABLESPACE INSTANCE
  LOGGING;
  
ALTER TABLE @SCHEMA@.MONPROPS_T ADD
(
  PRIMARY KEY ( CONTEXT, PROPERTY )
  USING INDEX TABLESPACE INDEXTS
);


---------- AUDIT LOG

CREATE TABLE @SCHEMA@.AUDIT_TRAIL_T
(
  AUDIT_ENTRY_ID                     NUMBER              NOT NULL ,
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  VERSION                            NUMBER                       ,
  STEP                               VARCHAR(256)        NOT NULL ,
  AUDIT_TIMESTAMP                    TIMESTAMP           NOT NULL ,
  ARRIVAL_TIMESTAMP                  TIMESTAMP                    ,
  AUDIT_MSG_TYPE                     VARCHAR2(1)         NOT NULL ,
  HOSTNAME                           VARCHAR2(256)                ,
  PORT_NUMBER                        VARCHAR2(8)                  ,
  AUDIT_MESSAGE                      VARCHAR2(2048)               ,
  VERSION_ID                         NUMBER(5,0)         NOT NULL
)  TABLESPACE INSTANCE
  LOGGING;
  
ALTER TABLE @SCHEMA@.AUDIT_TRAIL_T ADD
(
  PRIMARY KEY ( AUDIT_ENTRY_ID  )
  USING INDEX TABLESPACE INDEXTS
);


CREATE SEQUENCE @SCHEMA@.AUDIT_TRAIL_SEQ INCREMENT BY 1 START WITH 1 NOCYCLE ORDER;


CREATE OR REPLACE TRIGGER @SCHEMA@.AUDIT_TRAIL_AUTONUM BEFORE INSERT ON @SCHEMA@.AUDIT_TRAIL_T FOR EACH ROW
BEGIN
   SELECT @SCHEMA@.AUDIT_TRAIL_SEQ.NEXTVAL
   INTO :NEW.AUDIT_ENTRY_ID
   FROM DUAL;
END;
/


CREATE TABLE @SCHEMA@.META_KPI_PERSONALIZED_T
(
  KPI_ID                             VARCHAR2(384)       NOT NULL ,
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  VERSION                            NUMBER(20,0)        NOT NULL ,
  USER_ID                            VARCHAR2(256)       NOT NULL ,
  TARGET                             NUMBER                       ,
  FGS_FILTER_HASH                    NUMBER(20,0)                 ,
  ENABLE_KPI_HISTORY                 NUMBER(5,0)         NOT NULL ,
  ENABLE_KPI_PREDICTIONS             NUMBER(5,0)         NOT NULL ,
  VERSION_ID                         NUMBER(5,0)         NOT NULL 
) TABLESPACE INSTANCE
  LOGGING;

ALTER TABLE @SCHEMA@.META_KPI_PERSONALIZED_T ADD
(
  PRIMARY KEY ( KPI_ID, VERSION, USER_ID )
  USING INDEX TABLESPACE INDEXTS
);

CREATE TABLE @SCHEMA@.META_KPI_CACHE_T
(
  KPI_ID                             VARCHAR2(384)       NOT NULL ,
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  VERSION                            NUMBER(20,0)        NOT NULL ,
  FGS_FILTER_HASH                    NUMBER(20,0)        NOT NULL ,
  KPI_CACHE_VALUE                    NUMBER                       ,
  KPI_LAST_CALCULATION_TIME          TIMESTAMP                    ,
  VERSION_ID                         NUMBER(5,0)         NOT NULL 
) TABLESPACE INSTANCE
  LOGGING;

ALTER TABLE @SCHEMA@.META_KPI_CACHE_T ADD
(
  PRIMARY KEY ( KPI_ID, VERSION, FGS_FILTER_HASH )
  USING INDEX TABLESPACE INDEXTS
);

CREATE TABLE @SCHEMA@.META_KPI_RANGE_PERSONALIZED_T
(
  KPI_RANGE_ID                       VARCHAR2(512)       NOT NULL ,
  KPI_ID                             VARCHAR2(384)       NOT NULL ,
  VERSION                            NUMBER(20,0)        NOT NULL ,
  USER_ID                            VARCHAR2(256)       NOT NULL ,
  DISPLAY_NAME                       VARCHAR2(1000)               ,
  START_VALUE                        NUMBER              NOT NULL ,
  END_VALUE                          NUMBER              NOT NULL ,
  COLOR                              VARCHAR2(7)                  ,
  ICON                               VARCHAR2(256)                ,
  VERSION_ID                         NUMBER(5,0)         NOT NULL 
) TABLESPACE INSTANCE
  LOGGING;

ALTER TABLE @SCHEMA@.META_KPI_RANGE_PERSONALIZED_T ADD
(
  PRIMARY KEY ( KPI_RANGE_ID, VERSION, USER_ID )
  USING INDEX TABLESPACE INDEXTS
);


ALTER TABLE @SCHEMA@.META_MODEL_UNVERSIONED_T ADD
(
  FGS_LASTUPDATE_SECFILTER TIMESTAMP,
  FGS_LASTUPDATE_OBJSEC TIMESTAMP,
  FGS_LASTUPDATE_COGNOS TIMESTAMP
);


ALTER TABLE @SCHEMA@.META_MODEL_T 
  ADD(  ROOT_META_INF_CONTENTS    BLOB);

--ADD Cognos Changes

ALTER TABLE @SCHEMA@.META_MODEL_T 
        ADD (COGNOS_PACKAGE VARCHAR(1000));

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T 
        ADD (COGNOS_NAMESPACE VARCHAR(1000));

ALTER TABLE @SCHEMA@.META_DIMENSION_T 
        ADD (COGNOS_NAME VARCHAR(1000));

ALTER TABLE @SCHEMA@.META_DIM_ATTR_T 
        ADD (COGNOS_NAME VARCHAR(1000));

ALTER TABLE @SCHEMA@.META_MEASURE_T 
        ADD (COGNOS_NAME VARCHAR(1000));

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T 
        ADD (COGNOS_NAME  VARCHAR(1000));
  

CREATE SEQUENCE @SCHEMA@.ERROR_Q_SEQ INCREMENT BY 1 START WITH 1 NOCYCLE ORDER;

--Changes for 8.0

ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T 
        ADD (PRIORITY NUMBER(20,0));

CREATE TABLE @SCHEMA@.ACT_ALERT_COMMENTS_T
(
  ALERT_ID                           VARCHAR2(32)        NOT NULL ,
  COMMENT_OWNER                      VARCHAR2(32)        NOT NULL ,
  COMMENT_TIME                       TIMESTAMP           NOT NULL ,
  COMMENT_TEXT                       VARCHAR2(4000)               ,
  VERSION_ID                         NUMBER(5,0)         NOT NULL 
) TABLESPACE MONDSTS
  LOGGING;

ALTER TABLE @SCHEMA@.ACT_ALERT_COMMENTS_T ADD
(
  PRIMARY KEY ( ALERT_ID, COMMENT_OWNER, COMMENT_TIME )
  USING INDEX TABLESPACE MONIDXTS
);

ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T 
        ADD (STATUS VARCHAR2(32));


ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T 
        ADD (HIDDEN NUMBER(5,0));        

UPDATE @SCHEMA@.META_MONITOR_CONTEXT_T SET HIDDEN = 0;

ALTER TABLE  @SCHEMA@.META_MONITOR_CONTEXT_T 
MODIFY	     HIDDEN
CONSTRAINT   META_MONITOR_CONTEXT_C1  NOT NULL;


ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T 
        ADD (HIDDEN NUMBER(5,0));        

UPDATE @SCHEMA@.META_MONITOR_METRIC_T SET HIDDEN = 0;

ALTER TABLE  @SCHEMA@.META_MONITOR_METRIC_T 
MODIFY	     HIDDEN
CONSTRAINT   META_MONITOR_METRIC_C1  NOT NULL;


ALTER TABLE @SCHEMA@.META_KPI_T
        ADD (HIDDEN NUMBER(5,0));        

UPDATE @SCHEMA@.META_KPI_T SET HIDDEN = 0;

ALTER TABLE  @SCHEMA@.META_KPI_T 
MODIFY	     HIDDEN
CONSTRAINT   META_KPI_C1  NOT NULL; 


COMMIT;
QUIT

