-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2010, 2012.  All Rights Reserved.
-- US Government Users Restricted Rights - Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- ------------------------------------------------------------------------------------
--
-- Script file to create database and tablespaces for SQL Server UDB 
--
-- ------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script:
-- @DB_NAME@ = the database name, eg MONITOR
-- @SCHEMA@  = the schema name, eg MONITOR
--
--    For a database install with enhanced security:
--    Scroll to the bottom of the file and un-comment the series of GRANT statements 
--    by replacing the string "--GRANT STMT--" with ""
--
-- @DB_USER@ = database user for the monitor schema, only needed for GRANT statements
--    for database installation with enhanced security
--
-- Run the script in the sqlcmd command line processor
--
-- USAGE:  sqlcmd -U <userid> -P <password> -e -i createTables.sql
--
-- ------------------------------------------------------------------------------------
use @DB_NAME@
checkpoint
GO

-------------------
-- Create tables --
-------------------

CREATE TABLE @SCHEMA@.SCHEMA_VERSION
(
  SCHEMA_VERSION                     INTEGER                           NOT NULL ,
  DATA_MIGRATION                     SMALLINT                          NOT NULL ,
  PRIMARY KEY NONCLUSTERED ( SCHEMA_VERSION )
)
GO

CREATE TABLE @SCHEMA@.MODERATOR_NEXT_ID  
(
  MODEL_ID                           NVARCHAR(128)                     NOT NULL ,
  UNIQUE_ID_KEY                      NVARCHAR(128)                     NOT NULL , 
  START_ID_OF_NEXT_SET               BIGINT                            NOT NULL , 
  PRIMARY KEY ( MODEL_ID, UNIQUE_ID_KEY )
)
GO

CREATE TABLE @SCHEMA@.MM_TO_WPS_PT  (
  MODEL_ID           		     NVARCHAR(128)                     NOT NULL,
  VERSION_ID                         BIGINT                            NOT NULL, 
  WPS_PT_ID                          NVARCHAR(190)                     NOT NULL,
  WPS_PT_VALID_FROM                  NVARCHAR(128)                     NOT NULL,
  PRIMARY KEY (MODEL_ID, VERSION_ID, WPS_PT_ID, WPS_PT_VALID_FROM)
) 
GO

CREATE TABLE @SCHEMA@.RECORDED_EVENTS
(
  ID                                 BIGINT IDENTITY(1,1) NOT NULL,
  PAYLOAD_VARCHAR                    VARBINARY,
  PAYLOAD_BLOB                       VARBINARY(MAX),
  TIME_RECORDED                      DATETIME,
  BACKUP_ID                          NVARCHAR(32),
  PRIMARY KEY ( ID )
)
GO

CREATE TABLE @SCHEMA@.RECORDED_EVENTS_MODELVERSIONS
(
  EVENT_ID                           BIGINT NOT NULL, 
  MODEL_ID                           NVARCHAR(128) NOT NULL,
  VERSION                            BIGINT NOT NULL,
  PRIMARY KEY ( EVENT_ID, MODEL_ID, VERSION ),
  FOREIGN KEY ( EVENT_ID ) REFERENCES @SCHEMA@.RECORDED_EVENTS( ID ) ON DELETE CASCADE
)
GO


CREATE TABLE @SCHEMA@.META_MODEL_UNVERSIONED_T
(
    MODEL_ID                           NVARCHAR(128)                       NOT NULL ,
    GENERAL_PROPERTIES                 VARBINARY(MAX)                         NULL ,
    INTEGRATION_STATUS                 NVARCHAR(32)                           NULL ,
    INTEGRATION_TYPE                   NVARCHAR(32)                           NULL ,
    CEICELL                            NVARCHAR(128)                          NULL ,
    CEINODE                            NVARCHAR(128)                          NULL ,
    CEISERVER                          NVARCHAR(128)                          NULL ,
    CEICLUSTER                         NVARCHAR(128)                          NULL ,
    CEIHOST                            NVARCHAR(128)                          NULL ,
    CEIPORT                            NVARCHAR(128)                          NULL ,
    CEIUSER_ID                         NVARCHAR(128)                          NULL ,
    CEIPASSWORD                        NVARCHAR(128)                          NULL ,
    CEIEVENT_GROUP_PROFILE_LIST        NVARCHAR(128)                          NULL ,
    MEGA_NAME_MAPPER                   VARBINARY(MAX)                         NULL ,
    SERVER_ID                          NVARCHAR(256)                          NULL ,
    FGS_LASTUPDATE_SECFILTER           DATETIME                                    ,
    FGS_LASTUPDATE_OBJSEC              DATETIME                                    ,
    FGS_LASTUPDATE_COGNOS              DATETIME                                    ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( MODEL_ID )
)
GO

CREATE NONCLUSTERED INDEX META_MODEL_UNVERSIONED_I1 ON @SCHEMA@.META_MODEL_UNVERSIONED_T 
(
	MODEL_ID ASC
) INCLUDE (FGS_LASTUPDATE_COGNOS, FGS_LASTUPDATE_OBJSEC, FGS_LASTUPDATE_SECFILTER, VERSION_ID,
   CEIEVENT_GROUP_PROFILE_LIST, CEIPASSWORD, CEIUSER_ID, CEIPORT, CEIHOST, CEICLUSTER,
   CEISERVER, CEINODE, CEICELL, INTEGRATION_STATUS)
GO

CREATE TABLE @SCHEMA@.CEI_SERVER_SOURCE_T
(
    SERVER_ID                          NVARCHAR(256)                      NOT NULL ,
    ALIAS                              NVARCHAR(128)                          NULL ,
    DESCRIPTION                        NVARCHAR(256)                          NULL ,
    DEFAULT_SERVER                     SMALLINT                               NULL ,
    CELL                               NVARCHAR(128)                          NULL ,
    NODE                               NVARCHAR(128)                          NULL ,
    SERVER                             NVARCHAR(128)                          NULL ,
    CLUSTER_ID                         NVARCHAR(128)                          NULL ,
    HOST                               NVARCHAR(128)                          NULL ,
    RMI_PORT                           NVARCHAR(128)                          NULL ,
    EVENT_GROUP_PROFILE_LIST           NVARCHAR(128)                          NULL ,
    AUTH_ALIAS                         NVARCHAR(128)                          NULL ,
    QUEUE_BYPASS_CONFIG                SMALLINT                               NULL ,
    QUEUE_BASED_CONFIG                 SMALLINT                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( SERVER_ID )
)
GO


CREATE TABLE @SCHEMA@.META_MODEL_T
(
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    SCHEMA_NAME                        NVARCHAR(128)                          NULL ,
    DISPLAY_NAME                       NVARCHAR(1000)                         NULL ,
    CURRENT_STATE                      NVARCHAR(32)                           NULL ,
    INITIAL_STATE                      NVARCHAR(32)                           NULL ,
    TARGET_STATE                       NVARCHAR(32)                           NULL ,
    APPLICATION                        NVARCHAR(64)                           NULL ,
    MODEL                              VARBINARY(MAX)                         NULL ,
    CUBES                              VARBINARY(MAX)                         NULL ,
    DIAGRAMS                           VARBINARY(MAX)                         NULL ,
    SCHEMA_DDLS                        VARBINARY(MAX)                         NULL ,
    DMS_DDLS                           VARBINARY(MAX)                         NULL ,
    GENERAL_PROPERTIES                 VARBINARY(MAX)                         NULL ,
    DEPLOYMENT_OPTIONS                 VARBINARY(MAX)                         NULL ,
    NAME_MAPPER                        VARBINARY(MAX)                         NULL ,
    UDF_JARS                           VARBINARY(MAX)                         NULL ,
    ROUTING_JARS                       VARBINARY(MAX)                         NULL ,
    ROOT_META_INF_CONTENTS             VARBINARY(MAX)                         NULL ,
    ABXHOST                            NVARCHAR(128)                          NULL ,
    ABXPORT                            INTEGER                                NULL ,
    ABXUSER_ID                         NVARCHAR(128)                          NULL ,
    ABXPASSWORD                        NVARCHAR(128)                          NULL ,
    INTEGRATION_STATUS                 NVARCHAR(32)                           NULL ,
    REPLACEMENT_VERSION_DATE           BIGINT                                 NULL ,
    IS_STOP_REQUESTED                  SMALLINT                               NULL ,
    APPLICATION_UPDATE                 SMALLINT                               NULL ,
    KPI_CACHE_REFRESH_INTERVAL         SMALLINT                               NULL ,
    CODE_GEN_VERSION                   NVARCHAR(8)                            NULL ,
    BUILD_ID                           NVARCHAR(40)                           NULL ,
    COGNOS_PACKAGE                     NVARCHAR(1000)                         NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( MODEL_ID, VERSION )
)
GO


CREATE TABLE @SCHEMA@.META_MODEL_STEP_T
(
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    STEP_NAME                          NVARCHAR(32)                       NOT NULL ,
    LAST_SUCCESS_RUN_TIME              DATETIME                               NULL ,
    LAST_FAIL_RUN_TIME                 DATETIME                               NULL ,
    IS_COMPLETE                        SMALLINT                               NULL ,
    MONITOR_VERSION                    NVARCHAR(32)                           NULL ,
    MESSAGE                            VARBINARY(MAX)                         NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( MODEL_ID, VERSION, STEP_NAME )
)
GO

CREATE NONCLUSTERED INDEX META_MODEL_STEP_I1 ON @SCHEMA@.META_MODEL_STEP_T
(
	MODEL_ID ASC,
	VERSION ASC,
	STEP_NAME ASC,
	LAST_SUCCESS_RUN_TIME ASC,
	LAST_FAIL_RUN_TIME ASC,
	IS_COMPLETE ASC,
	MONITOR_VERSION ASC,
	VERSION_ID ASC
)
GO

CREATE NONCLUSTERED INDEX META_MODEL_STEP_I2 ON @SCHEMA@.META_MODEL_STEP_T 
(
	MODEL_ID ASC,
	STEP_NAME ASC,
	IS_COMPLETE ASC
)
GO

CREATE TABLE @SCHEMA@.META_MONITOR_CONTEXT_T
(
    MCID                               NVARCHAR(256)                      NOT NULL ,
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    MCPARENT_ID                        NVARCHAR(256)                          NULL ,
    DIAGRAM                            VARBINARY(MAX)                         NULL ,
    DISPLAY_NAME                       NVARCHAR(1000)                     NOT NULL ,
    CUBE_NAME                          NVARCHAR(1000)                         NULL ,
    TABLE_NAME                         NVARCHAR(128)                      NOT NULL ,
    VIEW_NAME                          NVARCHAR(128)                      NOT NULL ,
    DMS_TABLE_NAME                     NVARCHAR(128)                      NOT NULL ,
    DMS_CHG_LOG_TABLE                  NVARCHAR(128)                      NOT NULL ,
    COGNOS_NAMESPACE                   NVARCHAR(1000)                         NULL ,
    HIDDEN                             SMALLINT                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( MCID, VERSION )
)
GO

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T 
    ADD CONSTRAINT META_MONITOR_CONTEXT_C1 CHECK (HIDDEN IS NOT NULL)
GO    

CREATE TABLE @SCHEMA@.META_MONITOR_METRIC_T
(
    METRIC_ID                          NVARCHAR(384)                      NOT NULL ,
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    MCID                               NVARCHAR(256)                      NOT NULL ,
    METRIC_TYPE                        NVARCHAR(14)                       NOT NULL ,
    IS_SORTABLE                        SMALLINT                               NULL ,
    COLUMN_NAME                        NVARCHAR(128)                      NOT NULL ,
    DISPLAY_NAME                       NVARCHAR(1000)                     NOT NULL ,
    COGNOS_NAME                        NVARCHAR(1000)                         NULL ,
    HIDDEN                             SMALLINT                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( METRIC_ID, VERSION )
)
GO

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T
    ADD CONSTRAINT META_MONITOR_METRIC_C1 CHECK (HIDDEN IS NOT NULL)
GO    

CREATE TABLE @SCHEMA@.META_DIMENSION_T
(
    DIMENSION_ID                       NVARCHAR(384)                      NOT NULL ,
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    MCID                               NVARCHAR(256)                      NOT NULL ,
    TABLE_NAME                         NVARCHAR(128)                          NULL ,
    DISPLAY_NAME                       NVARCHAR(1000)                     NOT NULL ,
    ABX_DISPLAY_NAME                   NVARCHAR(1000)                     NOT NULL ,
    COGNOS_NAME                        NVARCHAR(1000)                         NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( DIMENSION_ID, VERSION )
)
GO


CREATE TABLE @SCHEMA@.META_DIM_ATTR_T
(
    DIM_ATTRIBUTE_ID                   NVARCHAR(440)                      NOT NULL ,
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    DIMENSION_ID                       NVARCHAR(384)                      NOT NULL ,
    ABX_DIM_ATTR_NAME                  NVARCHAR(1000)                     NOT NULL ,
    DIM_LEVEL                          INTEGER                            NOT NULL ,
    IS_PART_OF_DIM_KEY                 INTEGER                            NOT NULL ,
    METRIC_ID                          NVARCHAR(384)                      NOT NULL ,
    DISPLAY_NAME                       NVARCHAR(1000)                     NOT NULL ,
    COGNOS_NAME                        NVARCHAR(1000)                         NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( DIM_ATTRIBUTE_ID, VERSION )
)
GO


CREATE TABLE @SCHEMA@.META_MEASURE_T
(
    MEASURE_ID                         NVARCHAR(384)                      NOT NULL ,
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    MCID                               NVARCHAR(256)                      NOT NULL ,
    DISPLAY_NAME                       NVARCHAR(1000)                     NOT NULL ,
    ABX_DISPLAY_NAME                   NVARCHAR(1000)                     NOT NULL ,
    AGGREGATION_TYPE                   NVARCHAR(14)                       NOT NULL ,
    TRACKING_KEY                       NVARCHAR(256)                           NULL ,
    MEASURE_DATA_TYPE                  NVARCHAR(14)                            NULL ,
    SOURCE_METRIC_ID                   NVARCHAR(384)                           NULL ,
    COGNOS_NAME                        NVARCHAR(1000)                         NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( MEASURE_ID, VERSION )
)
GO


CREATE TABLE @SCHEMA@.META_KPI_CONTEXT_T
(
    KPI_CONTEXT_ID                     NVARCHAR(384)                      NOT NULL ,
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    DISPLAY_NAME                       NVARCHAR(1000)                         NULL ,
    DIAGRAM                            VARBINARY(MAX)                         NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( KPI_CONTEXT_ID, VERSION )
)
GO


CREATE TABLE @SCHEMA@.META_KPI_T
(
    KPI_ID                             NVARCHAR(384)                      NOT NULL ,
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    KPI_CONTEXT_ID                     NVARCHAR(256)                          NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    DISPLAY_NAME                       NVARCHAR(1000)                         NULL ,
    DESCRIPTION                        NVARCHAR(256)                          NULL ,
    KPI_ORIGIN                         SMALLINT                           NOT NULL ,
    KPI_DATA_TYPE                      SMALLINT                           NOT NULL ,
    TARGET                             FLOAT(53)                              NULL ,
    KPI_RANGE_TYPE                     SMALLINT                           NOT NULL ,
    KPI_CALC_METHOD                    SMALLINT                           NOT NULL ,
    AGGREGATED_MEASURE_ID              NVARCHAR(384)                          NULL ,
    AGGREGATED_METRIC_ID               NVARCHAR(384)                          NULL ,
    AGGREGATION_FUNCTION               NVARCHAR(10)                           NULL ,
    VERSION_AGGREGATION                SMALLINT                               NULL ,
    TIME_PERIOD_METRIC_ID              NVARCHAR(384)                          NULL ,
    TIME_PERIOD_METHOD                 SMALLINT                               NULL ,
    REPEATING_PERIOD_DURATION          SMALLINT                               NULL ,
    REPEATING_PERIOD_BASIS             SMALLINT                               NULL ,
    REPEATING_PERIOD_TIMEZONE          NVARCHAR(30)                           NULL ,
    ROLLING_PERIOD_DURATION            SMALLINT                               NULL ,
    ROLLING_PERIOD_QUANTITY            INTEGER                                NULL ,
    FIXED_PERIOD_START                 DATETIME                               NULL ,
    FIXED_PERIOD_END                   DATETIME                               NULL ,
    FIXED_PERIOD_TIMEZONE              NVARCHAR(30)                           NULL ,
    CALCULATED_KPI_EXPRESSION          TEXT                                   NULL ,
    USER_ID                            NVARCHAR(256)                          NULL ,
    VIEW_ACCESS                        SMALLINT                           NOT NULL ,
    FORMAT_DECIMAL_PRECISION           SMALLINT                               NULL ,
    FORMAT_CURRENCY                    NVARCHAR(3)                            NULL ,
    FORMAT_PERCENTAGE                  SMALLINT                           NOT NULL ,
    ENABLE_KPI_HISTORY                 SMALLINT                           NOT NULL ,
    ENABLE_KPI_PREDICTIONS             SMALLINT                           NOT NULL ,
    HISTORY_VALID_FROM                 DATETIME                               NULL ,
    KPI_CACHE_VALUE                    FLOAT(53)                              NULL ,
    KPI_LAST_CALCULATION_TIME          DATETIME                               NULL ,
    KPI_CACHE_OVERRIDE_INTERVAL        SMALLINT                               NULL ,
    HIST_GRANULARITY                   SMALLINT                               NULL ,
    HIST_REPEATING_PERIOD_BASIS        SMALLINT                               NULL ,
    HIST_REPEATING_PERIOD_DURATION     SMALLINT                               NULL ,
    HIST_REPEATING_PERIOD_QUANTITY     INTEGER                                NULL ,
    HIST_ROLLING_PERIOD_DURATION       SMALLINT                               NULL ,
    HIST_ROLLING_PERIOD_QUANTITY       INTEGER                                NULL ,
    HIST_TIME_RANGE_START              DATETIME                               NULL ,
    HIST_TIME_RANGE_END                DATETIME                               NULL ,
    HIST_TIMEZONE                      NVARCHAR(30)                           NULL ,
    HIST_INCLUDE_PREDICTIONS           SMALLINT                           NOT NULL ,
    HIST_ALL_VERSIONS                  SMALLINT                           NOT NULL ,
    HIST_TIME_RANGE_METHOD             SMALLINT                               NULL ,
    HIST_DISPLAY_TARGET                SMALLINT                           NOT NULL ,
    HIST_DISPLAY_RANGES                SMALLINT                           NOT NULL ,
    HIST_RETRO_ACTIVE_CALC_QTY         INTEGER                                NULL ,
    DEFAULT_PREDICTION_MODEL_ID        NVARCHAR(384)                          NULL ,
    HIDDEN                             SMALLINT                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( KPI_ID, VERSION )
)
GO

ALTER TABLE @SCHEMA@.META_KPI_T
    ADD CONSTRAINT META_KPI_C1 CHECK (HIDDEN IS NOT NULL)
GO    

CREATE TABLE @SCHEMA@.META_KPI_PERSONALIZED_T
(
    KPI_ID                             VARCHAR(384)                       NOT NULL ,
    MODEL_ID                           VARCHAR(128)                       NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    USER_ID                            VARCHAR(256)                       NOT NULL ,
    TARGET                             FLOAT(53)                              NULL ,
    FGS_FILTER_HASH                    BIGINT                                 NULL ,
    ENABLE_KPI_HISTORY                 SMALLINT                           NOT NULL ,
    ENABLE_KPI_PREDICTIONS             SMALLINT                           NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( KPI_ID, VERSION, USER_ID )
)
GO

CREATE TABLE @SCHEMA@.META_KPI_CACHE_T
(
    KPI_ID                             VARCHAR(384)                       NOT NULL ,
    MODEL_ID                           VARCHAR(128)                       NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    FGS_FILTER_HASH                    BIGINT                             NOT NULL ,
    KPI_CACHE_VALUE                    FLOAT(53)                              NULL ,
    KPI_LAST_CALCULATION_TIME          DATETIME                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( KPI_ID, VERSION, FGS_FILTER_HASH )
)
GO

CREATE TABLE @SCHEMA@.META_KPI_METRIC_FILTER_T
(
    KPI_METRIC_FILTER_ID               NVARCHAR(256)                      NOT NULL ,
    KPI_ID                             NVARCHAR(384)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    FILTER_METRIC_ID                   NVARCHAR(512)                      NOT NULL ,
    FILTER_OPERATOR                    SMALLINT                           NOT NULL ,
    FILTER_OPERATOR_CASE_SENSITIVE     SMALLINT                           NOT NULL ,
    FILTER_VALUE                       TEXT                                   NULL ,
    VALUE_INDEX                        INTEGER                            NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( KPI_METRIC_FILTER_ID, VERSION, VALUE_INDEX )
)
GO


CREATE TABLE @SCHEMA@.META_KPI_RANGE_T
(
    KPI_RANGE_ID                       NVARCHAR(256)                      NOT NULL ,
    KPI_ID                             NVARCHAR(384)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    DISPLAY_NAME                       NVARCHAR(1000)                         NULL ,
    START_VALUE                        FLOAT(53)                          NOT NULL ,
    END_VALUE                          FLOAT(53)                          NOT NULL ,
    COLOR                              NVARCHAR(7)                            NULL ,
    ICON                               NVARCHAR(256)                          NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( KPI_RANGE_ID, VERSION )
)
GO

CREATE TABLE @SCHEMA@.META_KPI_RANGE_PERSONALIZED_T
(
    KPI_RANGE_ID                       VARCHAR(512)                       NOT NULL ,
    KPI_ID                             VARCHAR(384)                       NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    USER_ID                            VARCHAR(256)                       NOT NULL ,
    DISPLAY_NAME                       VARCHAR(1000)                          NULL ,
    START_VALUE                        FLOAT(53)                          NOT NULL ,
    END_VALUE                          FLOAT(53)                          NOT NULL ,
    COLOR                              VARCHAR(7)                             NULL ,
    ICON                               VARCHAR(256)                           NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( KPI_RANGE_ID, VERSION, USER_ID )
)
GO


CREATE TABLE @SCHEMA@.META_KPI_DEPENDENCY_T
(
    PARENT_KPI_ID                      NVARCHAR(220)                      NOT NULL ,
    PARENT_KPI_VERSION                 BIGINT                             NOT NULL ,
    CHILD_KPI_ID                       NVARCHAR(220)                      NOT NULL ,
    CHILD_KPI_VERSION                  BIGINT                             NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PARENT_KPI_ID, PARENT_KPI_VERSION, CHILD_KPI_ID, CHILD_KPI_VERSION )
)
GO


CREATE TABLE @SCHEMA@.KPI_HISTORY_T
(
    KPI_ID                             NVARCHAR(215)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    KPI_DYNAMIC_FILTER_VALUE           NVARCHAR(215)                      NOT NULL ,
    PERIOD_TIMESTAMP                   DATETIME                           NOT NULL ,
    FGS_FILTER_HASH                    BIGINT                             NOT NULL DEFAULT 0 ,
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    OBSERVED_TIME                      DATETIME                               NULL ,
    OBSERVED_VALUE                     FLOAT(53)                              NULL ,
    TARGET                             FLOAT(53)                              NULL ,
    HISTORY_UPDATE_TIME                DATETIME                               NULL ,
    HISTORY_VALUE                      FLOAT(53)                              NULL ,
    PREDICTION_BASIS_VALUE             FLOAT(53)                              NULL ,
    PREDICTION_BASIS_TIME              DATETIME                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( KPI_ID, VERSION, KPI_DYNAMIC_FILTER_VALUE, PERIOD_TIMESTAMP, FGS_FILTER_HASH )
)
GO


CREATE TABLE @SCHEMA@.KPI_TS_PREDICTION_T
(
    KPI_PREDICTION_ID                  NVARCHAR(256)                      NOT NULL ,
    KPI_ID                             NVARCHAR(384)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    PREDICTION_MODEL_ID                NVARCHAR(384)                      NOT NULL ,
    FGS_FILTER_HASH                    BIGINT                             NOT NULL DEFAULT 0,
    PREDICTED_FOR_TIME                 DATETIME                               NULL ,
    PREDICTED_VALUE                    FLOAT(53)                              NULL ,
    LAST_KPI_TIME                      DATETIME                           NOT NULL ,
    STANDARD_DEVIATION                 FLOAT(53)                              NULL ,
    VALUE_PLUS_STDDEV                  FLOAT(53)                              NULL ,
    VALUE_MINUS_STDDEV                 FLOAT(53)                              NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( KPI_PREDICTION_ID, VERSION, LAST_KPI_TIME, FGS_FILTER_HASH )
)
GO


CREATE TABLE @SCHEMA@.KPI_TS_PREDICTION_MODEL_T
(
    PREDICTION_MODEL_ID                NVARCHAR(384)                      NOT NULL ,
    PREDICTION_MODEL_NAME              NVARCHAR(256)                      NOT NULL ,
    KPI_ID                             NVARCHAR(384)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    MODEL_ID                           NVARCHAR(128)                          NULL ,
    KPI_DYNAMIC_FILTER_VALUE           NVARCHAR(500)                          NULL ,
    MODEL_XML                          VARBINARY(MAX)                         NULL ,
    PREDICTION_HORIZON                 INTEGER                                NULL ,
    PREDICT_TO_PERIOD_END              SMALLINT                           NOT NULL ,
    PREDICTION_INTERVAL_NUM            INTEGER                                NULL ,
    PREDICTION_INTERVAL_UNIT           SMALLINT                               NULL ,
    INTERVALS_PER_CYCLE                INTEGER                                NULL ,
    CYCLE_LENGTH_UNIT                  SMALLINT                               NULL ,
    KPI_BEHAVIOR                       SMALLINT                               NULL ,
    PREDICTION_SUBMODEL_ID             NVARCHAR(384)                          NULL ,
    MODEL_OPTIMIZE_SCHEDULE            SMALLINT                               NULL ,
    CREATION_USER_ID                   NVARCHAR(256)                          NULL ,
    UPDATE_USER_ID                     NVARCHAR(256)                          NULL ,
    NEXT_EVAL_TIME                     DATETIME                               NULL ,
    NEXT_OPTIMIZE_TIME                 DATETIME                               NULL ,
    CREATION_TIME                      DATETIME                               NULL ,
    UPDATE_TIME                        DATETIME                               NULL ,
    INITIAL_KPI_TIME                   DATETIME                               NULL ,
    LAST_KPI_TIME                      DATETIME                               NULL ,
    PREDICTION_LAST_RUN                DATETIME                               NULL ,
    TIME_LAST_OPTIMIZED                DATETIME                               NULL ,
    IS_VALID                           SMALLINT                           NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PREDICTION_MODEL_ID, VERSION )
)
GO


CREATE TABLE @SCHEMA@.DMS_METADATA_T
(
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    MCID                               NVARCHAR(256)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    DMS_COPY_PROC                      NVARCHAR(128)                          NULL ,
    TARGET_TABLE                       NVARCHAR(128)                          NULL ,
    LAST_TIME_STARTED                  BIGINT                                 NULL ,
    LAST_TIME_CMPLTD                   BIGINT                                 NULL ,
    DMS_INTERVAL                       BIGINT                                 NULL ,
    PROGRESS_FLAG                      SMALLINT                               NULL ,
    IS_NEW_FLAG                        SMALLINT                               NULL ,
    SUSPENDED_FLAG                     SMALLINT                               NULL ,
    IS_DELETED_FLAG                    SMALLINT                               NULL ,
    INVOKE_NOW                         SMALLINT                               NULL ,
    ROWS_COPIED                        INTEGER                                NULL ,
    ROWS_PRUNED                        INTEGER                                NULL ,
    DMS_COPY_PROC_MESG                 NVARCHAR(4000)                         NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( MODEL_ID, MCID, VERSION )
)
GO


CREATE TABLE @SCHEMA@.DMS_HISTORY_T
(
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    MCID                               NVARCHAR(256)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    TIME_STARTED                       BIGINT                             NOT NULL ,
    TIME_COMPLETED                     BIGINT                                 NULL ,
    DMS_INTERVAL                       BIGINT                                 NULL ,
    ROWS_COPIED                        INTEGER                                NULL ,
    ROWS_PRUNED                        INTEGER                                NULL ,
    DMS_COPY_PROC_MESG                 NVARCHAR(4000)                         NULL ,
    IS_DELETED_FLAG                    SMALLINT                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( MODEL_ID, MCID, VERSION, TIME_STARTED )
)
GO


CREATE TABLE @SCHEMA@.DMS_TRACE_T
(
  DMS_STORED_PROC                     NVARCHAR(128)                             ,
  START_TIME                          DATETIME                                  ,
  END_TIME                            DATETIME                                  ,
  ROWS_MERGED                         INTEGER                                   ,
  ROWS_PRUNED                         INTEGER                                   ,
  START_DCL                           INTEGER                                   ,
  START_DCC                           INTEGER                                   ,
  END_DCL                             INTEGER                                   ,
  END_DCC                             INTEGER                                   ,
  START_MCT                           INTEGER                                   ,
  START_TGT                           INTEGER                                   ,
  END_MCT                             INTEGER                                   ,
  END_TGT                             INTEGER                                   ,
  ROWS_INSERTED                       INTEGER                                   ,
  ROWS_UPDATED                        INTEGER
)
GO


CREATE INDEX DMS_TRACE_I1 ON @SCHEMA@.DMS_TRACE_T (DMS_STORED_PROC, START_TIME)
GO


CREATE TABLE @SCHEMA@.META_OUTBOUND_EVENT_T
(
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    EVENT_ID                           NVARCHAR(384)                      NOT NULL ,
    CONTEXT_ID                         NVARCHAR(256)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    DISPLAY_NAME                       NVARCHAR(1000)                         NULL ,
    EXTENSION_NAME                     NVARCHAR(1000)                         NULL ,
    CONTEXT_TYPE                       NVARCHAR(100)                          NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( EVENT_ID, VERSION )
)
GO


CREATE TABLE @SCHEMA@.ACT_MGR_ALERTS_T
(
    ALERT_ID                           NVARCHAR(32)                       NOT NULL ,
    CONTEXT_DEF                        NVARCHAR(300)                          NULL ,
    CONTEXT_INST_ID                    NVARCHAR(32)                           NULL ,
    MODEL_NAME                         NVARCHAR(300)                          NULL ,
    MODEL_ID                           NVARCHAR(128)                          NULL ,
    CONTEXT_NAME                       NVARCHAR(300)                          NULL ,
    CONTEXT_ID                         NVARCHAR(256)                          NULL ,
    MODEL_VERSION                      NVARCHAR(128)                          NULL ,
    BUS_SIT_NAME                       NVARCHAR(384)                      NOT NULL ,
    CBE_XML                            VARBINARY(MAX)                         NULL ,
    ALERT_SUBJECT                      NVARCHAR(240)                      NOT NULL ,
    ALERT_BODY                         TEXT                               NOT NULL ,
    ALERT_TIMESTAMP                    DATETIME                               NULL ,
    PRIORITY                           BIGINT                                 NULL ,
    STATUS                             NVARCHAR(32)                           NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ALERT_ID )
)
GO

CREATE TABLE @SCHEMA@.ACT_ALERT_COMMENTS_T
(
    ALERT_ID                           NVARCHAR(32)                        NOT NULL ,
    COMMENT_OWNER                      NVARCHAR(32)                        NOT NULL ,
    COMMENT_TIME                       DATETIME                            NOT NULL ,
    COMMENT_TEXT                       NVARCHAR(4000)                          NULL ,
    VERSION_ID                         SMALLINT                            NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ALERT_ID, COMMENT_OWNER, COMMENT_TIME )
)
GO


CREATE TABLE @SCHEMA@.DASHBOARD_ALERT_T
(
    USER_ID                            NVARCHAR(32)                       NOT NULL ,
    ALERT_ID                           NVARCHAR(32)                       NOT NULL ,
    ACKNOWLEDGED                       SMALLINT                           NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( USER_ID, ALERT_ID )
)
GO

CREATE INDEX DASHBOARD_ALERT_I1 ON @SCHEMA@.DASHBOARD_ALERT_T (USER_ID)
GO

CREATE TABLE @SCHEMA@.ACT_HNDLR_T
(
    ID                                 NVARCHAR(32)                       NOT NULL ,
    NAME                               NVARCHAR(64)                       NOT NULL ,
    TYPE                               NVARCHAR(64)                       NOT NULL ,
    INVOCATION_TYPE                    NVARCHAR(20)                           NULL ,
    INVOCATION_PROFILE                 NVARCHAR(1024)                         NULL ,
    DESCRIPTION                        NVARCHAR(1024)                         NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ID )
)
GO


CREATE TABLE @SCHEMA@.ACTION_HANDLER_CTRL_T
(
    ACTION_ID                          NVARCHAR(384)                      NOT NULL ,
    HANDLER_ID                         NVARCHAR(32)                       NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ACTION_ID, HANDLER_ID )
)
GO


CREATE INDEX ACTN_HNDLR_CTRL_I1 ON @SCHEMA@.ACTION_HANDLER_CTRL_T (ACTION_ID)
GO


CREATE TABLE @SCHEMA@.PLUG_SVC_T
(
    ID                                 NVARCHAR(32)                       NOT NULL ,
    NAME                               NVARCHAR(64)                       NOT NULL ,
    SERVICE_TYPE                       NVARCHAR(20)                       NOT NULL ,
    SUB_TYPE                           NVARCHAR(20)                       NOT NULL ,
    ACTION_HANDLER_ID                  NVARCHAR(32)                       NOT NULL ,
    DESCRIPTION                        NVARCHAR(1024)                         NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ID )
)
GO


CREATE TABLE @SCHEMA@.ACT_TMPLT_T
(
    ID                                 NVARCHAR(384)                      NOT NULL ,
    NAME                               NVARCHAR(384)                      NOT NULL ,
    TYPE                               NVARCHAR(20)                       NOT NULL ,
    CONTENT                            VARBINARY(MAX)                     NOT NULL ,
    DESCRIPTION                        NVARCHAR(1024)                         NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ID )
)
GO

CREATE INDEX ACT_TMPLT_I1 ON @SCHEMA@.ACT_TMPLT_T (NAME)
GO
CREATE INDEX ACT_TMPLT_I2 ON @SCHEMA@.ACT_TMPLT_T (TYPE)
GO

CREATE TABLE @SCHEMA@.ACTION_T
(
    ID                                 NVARCHAR(384)                      NOT NULL ,
    NAME                               NVARCHAR(64)                       NOT NULL ,
    TYPE                               NVARCHAR(64)                       NOT NULL ,
    PARAMETER_SET                      VARBINARY(MAX)                         NULL ,
    STATE                              NVARCHAR(20)                           NULL ,
    ALIAS_NAME                         NVARCHAR(64)                           NULL ,
    TEMPLATE_ID                        NVARCHAR(384)                          NULL ,
    HANDLER_ID                         NVARCHAR(32)                           NULL ,
    DESCRIPTION                        NVARCHAR(1024)                         NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ID )
)
GO

ALTER TABLE @SCHEMA@.ACTION_HANDLER_CTRL_T
    ADD CONSTRAINT D_ACTION_ID  FOREIGN KEY (ACTION_ID)
    REFERENCES @SCHEMA@.ACTION_T(ID) ON DELETE CASCADE;
GO


CREATE TABLE @SCHEMA@.SUBSCRIBED_USER_T
(
    USER_ID                            NVARCHAR(32)                       NOT NULL ,
    ETAACTRL_ID                        NVARCHAR(384)                      NOT NULL ,
    DASHBOARD                          SMALLINT                           NOT NULL ,
    EMAIL                              SMALLINT                           NOT NULL ,
    CELL                               SMALLINT                           NOT NULL ,
    PAGER                              SMALLINT                           NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( USER_ID, ETAACTRL_ID )
)
GO


CREATE INDEX SUBSCRIBED_USER_I1 ON @SCHEMA@.SUBSCRIBED_USER_T (USER_ID)
GO
CREATE INDEX SUBSCRIBED_USER_I2 ON @SCHEMA@.SUBSCRIBED_USER_T (ETAACTRL_ID)
GO


CREATE TABLE @SCHEMA@.ETAMATCH_T
(
    ID                                 NVARCHAR(384)                      NOT NULL ,
    DETERMINER_TYPE                    NVARCHAR(20)                       NOT NULL ,
    EXTENSION_NAME                     NVARCHAR(384)                      NOT NULL ,
    DESCRIPTION                        NVARCHAR(1024)                         NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ID )
)
GO

CREATE INDEX ETAMATCH_I1 ON @SCHEMA@.ETAMATCH_T (EXTENSION_NAME)
GO


CREATE TABLE @SCHEMA@.ATAMATCH_T
(
    ID                                 NVARCHAR(32)                       NOT NULL ,
    DETERMINER_TYPE                    NVARCHAR(20)                       NOT NULL ,
    PARENT_ACTION_ID                   NVARCHAR(32)                       NOT NULL ,
    CHILD_ACTION_ID                    NVARCHAR(32)                       NOT NULL ,
    DESCRIPTION                        NVARCHAR(1024)                         NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ID )
)
GO


CREATE TABLE @SCHEMA@.ETAACTRL_T
(
    ID                                 NVARCHAR(220)                      NOT NULL ,
    ETAMID                             NVARCHAR(220)                      NOT NULL ,
    ACTION_ID                          NVARCHAR(220)                      NOT NULL ,
    NAME                               NVARCHAR(1000)                     NOT NULL ,
    DESCRIPTION                        NVARCHAR(1024)                         NULL ,
    BINDING_TIMESTAMP                  DATETIME                               NULL ,
    CATEGORY                           NVARCHAR(64)                           NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ID )
)
GO

CREATE INDEX ETAACTRL_I1 ON @SCHEMA@.ETAACTRL_T (ETAMID)
GO
CREATE INDEX ETAACTRL_I2 ON @SCHEMA@.ETAACTRL_T (ACTION_ID)
GO
CREATE INDEX ETAACTRL_I3 ON @SCHEMA@.ETAACTRL_T (ETAMID, ACTION_ID)
GO

CREATE TABLE @SCHEMA@.ACTION_MANAGER_PROP_T
(
    ACTION_PROP_NAME                   NVARCHAR(100)                      NOT NULL ,
    ACTION_PROP_VALUE                  NVARCHAR(240)                      NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ACTION_PROP_NAME )
)
GO

CREATE TABLE @SCHEMA@.EQ_MODEL_VERSION_T
(
  DBID                               NVARCHAR(32)                      NOT NULL ,
  MODEL                              NVARCHAR(1000)                    NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  FAIL_TIME                          BIGINT                                     ,
  LAST_SUB_INST                      NVARCHAR(32)                               ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( DBID )
)
GO

CREATE INDEX EQ_MODEL_VER_I1 ON @SCHEMA@.EQ_MODEL_VERSION_T (DBID) INCLUDE (MODEL, VERSION)
GO

CREATE UNIQUE NONCLUSTERED INDEX EQ_MODEL_VER_I2 ON @SCHEMA@.EQ_MODEL_VERSION_T 
(
	DBID ASC
) INCLUDE (VERSION, MODEL)
GO


CREATE TABLE @SCHEMA@.DQ_MODEL_VERSION_T
(
  DBID                               NVARCHAR(32)                      NOT NULL ,
  MODEL                              NVARCHAR(1000)                    NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  FAIL_TIME                          BIGINT                                     ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( DBID )
) 
GO

CREATE INDEX DQ_MODEL_VER_I1 ON @SCHEMA@.DQ_MODEL_VERSION_T (DBID) INCLUDE (MODEL, VERSION)
GO

CREATE TABLE @SCHEMA@.EQ_INSTANCE_T
(
  DBID                               NVARCHAR(32)                      NOT NULL ,
  MV_DBID                            NVARCHAR(32)                      NOT NULL ,
  ROOT_INST_ID                       NVARCHAR(1000)                    NOT NULL ,
  FAIL_TIME                          BIGINT                                     ,
  LAST_SUB_TIME                      BIGINT                                     ,
  LAST_SUB_STATUS                    INTEGER                           NOT NULL ,
  LAST_SEQUENCE_NUM                  BIGINT                            NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( DBID ),
  FOREIGN KEY ( MV_DBID ) REFERENCES @SCHEMA@.EQ_MODEL_VERSION_T( DBID ) ON DELETE CASCADE
)
GO

CREATE TABLE @SCHEMA@.EQ_FAILED_EVENT_T
(
  DBID                               NVARCHAR(32)                      NOT NULL ,
  INSTANCE_DBID                      NVARCHAR(32)                      NOT NULL ,
  GU_INST_ID                         NVARCHAR(1000)                             ,
  EQ_SEQUENCE                        BIGINT                            NOT NULL ,
  EVENT_SEQUENCE                     NVARCHAR(512)                              ,
  F_SUMMARY                          NVARCHAR(256)                     NOT NULL ,
  F_DETAILS                          VARBINARY(MAX)                                ,
  F_TIME                             BIGINT                            NOT NULL ,
  CREATION_TIME                      BIGINT                                     ,
  EXT_NAME                           NVARCHAR(64)                               ,
  CONSUMPTION_TIME                   BIGINT                            NOT NULL ,
  LAST_SUB_TIME                      BIGINT                                     ,
  LAST_SUB_STATUS                    INTEGER                           NOT NULL ,
  HISTORY                            VARBINARY(MAX)                               ,
  DATA                               VARBINARY(MAX)                               ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( DBID ),
  FOREIGN KEY ( INSTANCE_DBID ) REFERENCES @SCHEMA@.EQ_INSTANCE_T( DBID ) ON DELETE CASCADE
)
GO

CREATE INDEX EQ_FAILED_EVENT_I1 ON @SCHEMA@.EQ_FAILED_EVENT_T (INSTANCE_DBID)
GO

CREATE INDEX EQ_FAILED_EVENT_I2 ON @SCHEMA@.EQ_FAILED_EVENT_T (INSTANCE_DBID, EQ_SEQUENCE)
GO

CREATE TABLE @SCHEMA@.DQ_DEAD_EVENT_T
(
  DBID                               NVARCHAR(32)                      NOT NULL ,
  MV_DBID                            NVARCHAR(32)                      NOT NULL ,
  F_SUMMARY                          NVARCHAR(256)                     NOT NULL ,
  F_DETAILS                          VARBINARY(MAX)                                ,
  F_TIME                             BIGINT                            NOT NULL ,
  DATA                               VARBINARY(MAX)                                      ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( DBID ),
  FOREIGN KEY ( MV_DBID ) REFERENCES @SCHEMA@.DQ_MODEL_VERSION_T( DBID ) ON DELETE CASCADE
)
GO

CREATE INDEX DQ_DEAD_EVENT_I1 ON @SCHEMA@.DQ_DEAD_EVENT_T (MV_DBID)
GO


CREATE TABLE @SCHEMA@.ACT_SITUATION_T
(
    ID                                 NVARCHAR(384)                      NOT NULL ,
    DISPLAY_NAME                       NVARCHAR(1000)                     NOT NULL ,
    DESCRIPTION                        NVARCHAR(256)                          NULL ,
    ACTIVE                             BIGINT                             NOT NULL ,
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    REPEATING                          SMALLINT                           NOT NULL ,
    INTERVAL                           SMALLINT                           NOT NULL ,
    TIME_POINT                         BIGINT                             NOT NULL ,
    TIME_MULTIPLE                      BIGINT                             NOT NULL ,
    TIME_OFFSET                        BIGINT                             NOT NULL ,
    TIME_ZONE                          NVARCHAR(60)                       NOT NULL ,
    KPI_ID                             NVARCHAR(384)                          NULL ,
    TIME_PROPERTIES                    TEXT                                   NULL ,
    START_TIME                         DATETIME                           NOT NULL ,
    LAST_EVAL                          DATETIME                               NULL ,
    NEXT_EVAL                          DATETIME                           NOT NULL ,
    SIT_TRIGGERED                      SMALLINT                           NOT NULL ,
    USER_ID                            NVARCHAR(256)                      NOT NULL ,
    VIEW_ACCESS                        SMALLINT                           NOT NULL ,
    CREATE_TIME                        DATETIME                           NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ID )
)
GO

-- index for primary key is not generated by default ...
CREATE INDEX ACT_SITUATION_P ON @SCHEMA@.ACT_SITUATION_T
( 
    ID
)
GO


CREATE TABLE @SCHEMA@.ACT_SIT_TRIG_T
(
    ID                                 NVARCHAR(384)                      NOT NULL ,
    SITUATION_ID                       NVARCHAR(384)                      NOT NULL ,
    KPI_ID                             NVARCHAR(384)                      NOT NULL ,
    PREDICTION_MODEL_ID                NVARCHAR(384)                          NULL ,
    PREDICTION_TYPE                    NVARCHAR(20)                           NULL ,
    TYPE                               NVARCHAR(256)                      NOT NULL ,
    FIELD_TYPE                         NVARCHAR(256)                      NOT NULL ,
    FIELD                              NVARCHAR(256)                          NULL ,
    COND_SETUP                         SMALLINT                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ID )
)
GO

-- index for primary key is not generated by default ...
CREATE INDEX ACT_SIT_TRIG_P ON @SCHEMA@.ACT_SIT_TRIG_T
( 
    ID
)
GO


--
-- dim time
--

CREATE TABLE @SCHEMA@.DIM_TIME
(
    SURROGATE_KEY                     DATETIME                           NOT NULL ,
    DAY_NUM                           SMALLINT                           NOT NULL ,
    MONTH_NUM                         SMALLINT                           NOT NULL ,
    YEAR_NUM                          INTEGER                            NOT NULL ,
    MONTH_NAME                        NVARCHAR(27)                       NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( SURROGATE_KEY )
)
GO

-- populate DIM_TIME 

BEGIN

SET DATEFORMAT ymd;

DECLARE @START_DATE DATETIME;
DECLARE @END_DATE DATETIME;

SET @START_DATE = '2008-01-01';
SET @END_DATE = '2022-12-31';

WHILE (@START_DATE <= @END_DATE)
	BEGIN

		INSERT INTO @SCHEMA@.DIM_TIME (SURROGATE_KEY, DAY_NUM, MONTH_NUM, 
						YEAR_NUM, MONTH_NAME)
		VALUES (@START_DATE, DAY(@START_DATE), MONTH(@START_DATE),
			YEAR(@START_DATE), DATENAME(m, @START_DATE));

		SET @START_DATE = DATEADD(day, 1, @START_DATE);

	END;
END;
GO

INSERT into @SCHEMA@.DIM_TIME(SURROGATE_KEY,YEAR_NUM,MONTH_NUM,DAY_NUM,MONTH_NAME) VALUES ('9999-01-01',9999,1,1,DATENAME(m,'9999-01-01'));
GO


-- index for primary key is not generated by default ...
CREATE INDEX DIM_TIMEP ON @SCHEMA@.DIM_TIME
( 
    SURROGATE_KEY
)
GO



-- The following UPDATE command can be used to override the default month names that are set 
-- above with DATENAME.
-- This UPDATE command can be edited with any location preference for month names (for example,
-- mixed case month names, 3-letter abbreviated month names, French month names, etc).  
-- This UPDATE command can be uncommented here or it can be run separately in SQLCMD.
--
-- UPDATE @SCHEMA@.DIM_TIME
--   SET MONTH_NAME =
--        CASE
--                   WHEN MONTH_NUM = 1  THEN 'January'
--                   WHEN MONTH_NUM = 2  THEN 'February'
--                   WHEN MONTH_NUM = 3  THEN 'March'
--                   WHEN MONTH_NUM = 4  THEN 'April'
--                   WHEN MONTH_NUM = 5  THEN 'May'
--                   WHEN MONTH_NUM = 6  THEN 'June'
--                   WHEN MONTH_NUM = 7  THEN 'July'
--                   WHEN MONTH_NUM = 8  THEN 'August'
--                   WHEN MONTH_NUM = 9  THEN 'September'
--                   WHEN MONTH_NUM = 10 THEN 'October'
--                   WHEN MONTH_NUM = 11 THEN 'November'
--                   WHEN MONTH_NUM = 12 THEN 'December'
--                   ELSE 'Error'
--                 END;
-- GO

-- set schema version to: 7.5
INSERT INTO @SCHEMA@.SCHEMA_VERSION (SCHEMA_VERSION, DATA_MIGRATION) VALUES( 75, 0 )
GO


-- View: ActTmplt
CREATE VIEW @SCHEMA@.ACT_TMPLT(ID, NAME, TYPE, DESCRIPTION ) AS
 SELECT ACT_TMPLT_T.ID, ACT_TMPLT_T.NAME, ACT_TMPLT_T.TYPE, ACT_TMPLT_T.DESCRIPTION
 FROM @SCHEMA@.ACT_TMPLT_T
GO

-- View: ETAMatch
CREATE VIEW @SCHEMA@.ETAMATCH(ID, DETERMINER_TYPE, EXTENSION_NAME, DESCRIPTION ) AS
 SELECT ETAMATCH_T.ID, ETAMATCH_T.DETERMINER_TYPE, ETAMATCH_T.EXTENSION_NAME, ETAMATCH_T.DESCRIPTION
 FROM @SCHEMA@.ETAMATCH_T
GO

-- View: Action
CREATE VIEW @SCHEMA@.ACTION(ID, NAME, TYPE ) AS
 SELECT ACTION_T.ID, ACTION_T.NAME, ACTION_T.TYPE
 FROM @SCHEMA@.ACTION_T
GO

-- View: ActMgrProp
CREATE VIEW @SCHEMA@.ACT_MGR_PROP(ACTION_PROP_NAME, ACTION_PROP_VALUE ) AS
 SELECT ACTION_MANAGER_PROP_T.ACTION_PROP_NAME, ACTION_MANAGER_PROP_T.ACTION_PROP_VALUE
 FROM @SCHEMA@.ACTION_MANAGER_PROP_T
GO

-- View: PlugSvc
CREATE VIEW @SCHEMA@.PLUG_SVC(ID, NAME, SERVICE_TYPE, SUB_TYPE, ACTION_HANDLER_ID ) AS
 SELECT PLUG_SVC_T.ID, PLUG_SVC_T.NAME, PLUG_SVC_T.SERVICE_TYPE, PLUG_SVC_T.SUB_TYPE, PLUG_SVC_T.ACTION_HANDLER_ID
 FROM @SCHEMA@.PLUG_SVC_T
GO

-- View: Alerts
CREATE VIEW @SCHEMA@.ALERTS(ALERT_ID, BUS_SIT_NAME, ALERT_SUBJECT, ALERT_TIMESTAMP ) AS
 SELECT ACT_MGR_ALERTS_T.ALERT_ID, ACT_MGR_ALERTS_T.BUS_SIT_NAME, ACT_MGR_ALERTS_T.ALERT_SUBJECT, ACT_MGR_ALERTS_T.ALERT_TIMESTAMP
 FROM @SCHEMA@.ACT_MGR_ALERTS_T
GO

-- View: SubscribedAction
CREATE VIEW @SCHEMA@.SUBSCRIBED_ACTION(ID, NAME, TYPE ) AS
 SELECT ACTION_T.ID, ACTION_T.NAME, ACTION_T.TYPE
 FROM @SCHEMA@.ACTION_T
GO

-- View: SubscribedBinding
CREATE VIEW @SCHEMA@.SUBSCRIBED_BINDING(USER_ID, BINDING_ID, NAME, DESCRIPTION, BINDING_TIMESTAMP, CATEGORY, DASHBOARD, EMAIL, CELL, PAGER ) AS
 SELECT SUBSCRIBED_USER_T.USER_ID, ETAACTRL_T.ID, ETAACTRL_T.NAME, ETAACTRL_T.DESCRIPTION, ETAACTRL_T.BINDING_TIMESTAMP, ETAACTRL_T.CATEGORY, SUBSCRIBED_USER_T.DASHBOARD, SUBSCRIBED_USER_T.EMAIL, SUBSCRIBED_USER_T.CELL, SUBSCRIBED_USER_T.PAGER
 FROM @SCHEMA@.ETAACTRL_T, @SCHEMA@.SUBSCRIBED_USER_T
 WHERE SUBSCRIBED_USER_T.ETAACTRL_ID=ETAACTRL_T.ID
GO

-- View: ETAACtrl
CREATE VIEW @SCHEMA@.ETAACTRL(ID, NAME, DESCRIPTION, BINDING_TIMESTAMP, CATEGORY ) AS
 SELECT ETAACTRL_T.ID, ETAACTRL_T.NAME, ETAACTRL_T.DESCRIPTION, ETAACTRL_T.BINDING_TIMESTAMP, ETAACTRL_T.CATEGORY
 FROM @SCHEMA@.ETAACTRL_T
GO

-- View: EQ
CREATE VIEW @SCHEMA@.EQ_FE_IDS(DBID, INSTANCE_DBID, EQ_SEQUENCE) AS
 SELECT DBID, INSTANCE_DBID, EQ_SEQUENCE 
 FROM @SCHEMA@.EQ_FAILED_EVENT_T
GO


--
-- Populate Action Mgr Tables
--
INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.SMTP.Host','localhost', 0)

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.SMTP.Port','25', 0)

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.SMTP.Sender','default@127.0.0.1', 0)

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Ldap.UID.Field','uid', 0)

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Ldap.Email.Field','mail', 0)

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Ldap.CellEmail.Field','mobile', 0)

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Ldap.PagerEmail.Field','pager', 0)

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.CEI_Logging','no', 0)

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Ldap.URL','ldap://localhost:389', 0)

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Ldap.UserName','cn=root', 0)

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Ldap.Password','', 0) 

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Mqwf.Hostname','localhost', 0)

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Mqwf.Port','1414', 0);

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.Mqwf.Channel','FMCQM.CL.TCP', 0)  

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.VMM.UID.Field','uid', 0)

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.VMM.Email.Field','mail', 0)

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.VMM.CellEmail.Field','mobile', 0)

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.VMM.PagerEmail.Field','pager', 0)

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.VMM.Provider','$VMM_HOST$:$VMM_PORT$', 0)

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID) 
  VALUES ('ActionManager.VMM.Entity.Type','PersonAccount', 0)

INSERT INTO @SCHEMA@.ACTION_MANAGER_PROP_T(ACTION_PROP_NAME, ACTION_PROP_VALUE, VERSION_ID)    
  VALUES ('ActionManager.VMM.Group.Type','Group', 0)

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) 
VALUES ('1001','EmailHandler','AAM_6.0_EMAIL_HNDLR','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.handling.EmailActionHandler','Email Action Service Handler', 0)

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) 
VALUES ('1002','AlertHandler','AAM_6.0_ALERT_HNDLR','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.handling.AlertActionHandler','Alert Action Service Handler', 0)

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) 
VALUES ('1003','WebServiceHandler','AAM_6.0_WEBSERVICES_HNDLR','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.handling.WebServicesHandler','WebService Action Service Handler', 0)

--To reactivate MQWF handlers uncomment these lines
--INSERT INTO @SCHEMA@.ACT_HNDLR_T
--(ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) values
--('1004','MQWF34Handler','AAM_6.0_MQWF34_HNDLR','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.handling.MQWFXMLAgent','MQWF 3.4 Action Service Handler', 0);
--INSERT INTO @SCHEMA@.ACT_HNDLR_T
--(ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) values
--('1005','MQWF35Handler','AAM_6.0_MQWF35PLUS_HNDLR','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.handling.MQWFwa0cAgent','MQWF 3.5+ Action Service Handler', 0);

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) 
VALUES ('1006','CellHandler','AAM_6.0_CELL_HNDLR','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.handling.CellEmailHandler','Cell Email Action Service Handler', 0)

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) 
VALUES ('1007','PagerHandler','AAM_6.0_PAGER_HNDLR','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.handling.PagerEmailHandler','Pager Email Action Service Handler', 0)

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) 
VALUES ('1008','SCAHandler','AAM_6.0_SCA','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.handling.ScaHandler','SCA Action Service Handler', 0)

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) 
VALUES ('2001','IBMSimpleE2ADeterminerHandler','AAM_6.0_PLUGSVC','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.determination.SimpleEventToActionDeterminer','Pluggable Service Handler', 0)

INSERT INTO @SCHEMA@.ACT_HNDLR_T
  (ID,NAME,TYPE,INVOCATION_TYPE,INVOCATION_PROFILE,DESCRIPTION, VERSION_ID) 
VALUES ('2002','IBMSimpleA2ADeterminerHandler','AAM_6.0_PLUGSVC','INVTYPE_LOCALJAVA','com.ibm.wbimonitor.actionmgr.determination.SimpleActionToActionDeterminer','Pluggable Service Handler', 0)

INSERT INTO @SCHEMA@.PLUG_SVC_T
  (ID,NAME,SERVICE_TYPE,SUB_TYPE,ACTION_HANDLER_ID,DESCRIPTION, VERSION_ID) 
VALUES ('1001','IBMSimpleE2ADeterminer','DETERMINER','E2A.IBM_SIMPLE','2001','Simple E2A Determiner', 0)

INSERT INTO @SCHEMA@.PLUG_SVC_T
  (ID,NAME,SERVICE_TYPE,SUB_TYPE,ACTION_HANDLER_ID,DESCRIPTION, VERSION_ID) 
VALUES ('1002','IBMSimpleA2ADeterminer','DETERMINER','A2A.IBM_SIMPLE','2002','Simple A2A Determiner', 0)

GO


----------- REST DATA SERVICES SECURITY & AUTHORIZATION TABLES
----------- TABLES
CREATE TABLE @SCHEMA@.RAT_RESOURCE_GROUPS  
(
  ID NVARCHAR(128) NOT NULL ,
  PARENT_ID NVARCHAR(128) ,
  DESCRIPTION NVARCHAR(256) 
)
GO

ALTER TABLE @SCHEMA@.RAT_RESOURCE_GROUPS
    ADD CONSTRAINT MON_AUTH_PK2 PRIMARY KEY (ID)
GO
                      
CREATE TABLE @SCHEMA@.RAT_AUTH_DOMAIN  
(
  RESOURCE1 NVARCHAR(256) NOT NULL ,
  VERSION  BIGINT NOT NULL ,
  RESOURCE_GROUP NVARCHAR(128) NOT NULL ,
  DESCRIPTION NVARCHAR(256) 
) 
GO

ALTER TABLE @SCHEMA@.RAT_AUTH_DOMAIN
    ADD CONSTRAINT MON_AUTH_PK1 PRIMARY KEY (RESOURCE1, VERSION)
GO    

CREATE TABLE @SCHEMA@.RAT_SUPERUSERS  
(
  USERID NVARCHAR(256) NOT NULL ,
  ASSIGNED_BY NVARCHAR(256) 
) 
GO

-- COMMENT ON TABLE @SCHEMA@.RAT_SUPERUSERS IS 'ANY USER/GROUP ENTERED HERE WILL HAVE ALL ACCESS.'


ALTER TABLE @SCHEMA@.RAT_SUPERUSERS
   ADD CONSTRAINT MON_AUTH_PK4 PRIMARY KEY (USERID)
GO   

CREATE TABLE @SCHEMA@.RAT_PARTY_ROLES  
(
  USERID NVARCHAR(128) NOT NULL ,
  ROLE NVARCHAR(128) NOT NULL ,
  RESOURCE_GROUP NVARCHAR(128) NOT NULL,
  MEMBER_TYPE NVARCHAR(20)  
) 
GO
 
-- COMMENT ON TABLE @SCHEMA@.RAT_PARTY_ROLES IS 'member roles in a resource group';

ALTER TABLE @SCHEMA@.RAT_PARTY_ROLES
   ADD CONSTRAINT MON_AUTH_PK5 PRIMARY KEY (USERID, ROLE, RESOURCE_GROUP)
GO   

CREATE TABLE @SCHEMA@.RAT_UPDATE_MONITOR  
(
  TABLE_NAME NVARCHAR(40) NOT NULL ,
  MARKER NVARCHAR(4) NOT NULL 
) 
GO

-- COMMENT ON COLUMN @SCHEMA@.RAT_UPDATE_MONITOR.MARKER IS 'OLD or NEW';

-- COMMENT ON COLUMN @SCHEMA@.RAT_UPDATE_MONITOR.TABLE_NAME IS 'stores table names RAT_AUTH_ADMIN, RAT_PARTY_ROLES and RAT_RESOURCE_GROUPS';

ALTER TABLE @SCHEMA@.RAT_UPDATE_MONITOR
   ADD CONSTRAINT MON_AUTH_PK3 PRIMARY KEY (TABLE_NAME)
GO   

INSERT INTO @SCHEMA@.RAT_UPDATE_MONITOR VALUES ('RAT_AUTH_DOMAIN','OLD')
GO

INSERT INTO @SCHEMA@.RAT_UPDATE_MONITOR VALUES ('RAT_RESOURCE_GROUPS','OLD')
GO

INSERT INTO @SCHEMA@.RAT_UPDATE_MONITOR VALUES ('RAT_PARTY_ROLES','OLD')
GO

INSERT INTO @SCHEMA@.RAT_RESOURCE_GROUPS  VALUES('root','root','The default resource group')

GO


----------- TRIGGERS
----------- REST DATA SERVICES SECURITY & AUTHORIZATION TRIGGERS
-----------

CREATE TRIGGER @SCHEMA@.MON_DELETE1
  ON @SCHEMA@.RAT_PARTY_ROLES AFTER DELETE AS
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_PARTY_ROLES'
  GO
    
CREATE TRIGGER @SCHEMA@.MON_DELETE2
  ON @SCHEMA@.RAT_AUTH_DOMAIN AFTER DELETE AS
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_AUTH_DOMAIN'
  GO
  
CREATE TRIGGER @SCHEMA@.MON_DELETE3
  ON @SCHEMA@.RAT_RESOURCE_GROUPS AFTER DELETE AS
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_RESOURCE_GROUPS'
  GO

CREATE TRIGGER @SCHEMA@.MON_DELETE4
  ON @SCHEMA@.RAT_RESOURCE_GROUPS AFTER DELETE AS
  DELETE FROM @SCHEMA@.RAT_PARTY_ROLES WHERE RESOURCE_GROUP=(SELECT ID FROM DELETED) 
  GO
  
CREATE TRIGGER @SCHEMA@.MON_INSERT1
  ON @SCHEMA@.RAT_PARTY_ROLES AFTER INSERT AS
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_PARTY_ROLES'
  GO
  
CREATE TRIGGER @SCHEMA@.MON_INSERT2
  ON @SCHEMA@.RAT_AUTH_DOMAIN AFTER INSERT AS
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_AUTH_DOMAIN'
  GO
    
CREATE TRIGGER @SCHEMA@.MON_INSERT3
  ON @SCHEMA@.RAT_RESOURCE_GROUPS AFTER INSERT AS
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_RESOURCE_GROUPS'
  GO
    
CREATE TRIGGER @SCHEMA@.MON_SU
  ON @SCHEMA@.RAT_SUPERUSERS AFTER INSERT AS
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_PARTY_ROLES'
  GO
  
CREATE TRIGGER @SCHEMA@.MON_SU2
  ON @SCHEMA@.RAT_SUPERUSERS AFTER DELETE AS
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_PARTY_ROLES'
  GO
  
CREATE TRIGGER @SCHEMA@.MON_SU3
  ON @SCHEMA@.RAT_SUPERUSERS AFTER UPDATE AS
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_PARTY_ROLES'
  GO
  
CREATE TRIGGER @SCHEMA@.MON_UPDATE1
  ON @SCHEMA@.RAT_PARTY_ROLES AFTER UPDATE AS
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_PARTY_ROLES'
  GO
  
CREATE TRIGGER @SCHEMA@.MON_UPDATE2
  ON @SCHEMA@.RAT_AUTH_DOMAIN AFTER UPDATE AS
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_AUTH_DOMAIN'
  GO
  
CREATE TRIGGER @SCHEMA@.MON_UPDATE3
  ON @SCHEMA@.RAT_RESOURCE_GROUPS AFTER UPDATE AS
  UPDATE @SCHEMA@.RAT_UPDATE_MONITOR SET MARKER ='NEW' WHERE TABLE_NAME ='RAT_RESOURCE_GROUPS'
  GO
  
CREATE TRIGGER @SCHEMA@.MODEL_DEPLOY
  ON @SCHEMA@.META_MODEL_T AFTER INSERT AS
  DECLARE @new_model VARCHAR(256);
  DECLARE @new_version BIGINT;
  SELECT @new_model = substring(MODEL_ID,2,128), @new_version = VERSION from inserted;
  print @new_model;
  IF NOT EXISTS (SELECT 1 FROM @SCHEMA@.RAT_AUTH_DOMAIN where @SCHEMA@.RAT_AUTH_DOMAIN.RESOURCE1 = @new_model ) 
  BEGIN
     insert into @SCHEMA@.RAT_AUTH_DOMAIN values(@new_model, @new_version,'root','');
  END
  GO

CREATE TRIGGER @SCHEMA@.MON_ON_DELETE
  ON @SCHEMA@.RAT_UPDATE_MONITOR AFTER DELETE AS
  DECLARE @old_table_name VARCHAR(256);
  select @old_table_name = TABLE_NAME from deleted;
  insert into @SCHEMA@.RAT_UPDATE_MONITOR values(@old_table_name ,'NEW');
  GO


-----------DASHBOARD DATA TABLE

CREATE TABLE @SCHEMA@.DASHBOARD_DATA_T
(
  DASHBOARD_CONFIG                   VARBINARY(MAX)                     NOT NULL ,
  DASHBOARD_ID                       NVARCHAR(128)                      NOT NULL ,
  DASHBOARD_OWNER                    NVARCHAR(128)                      NOT NULL ,
  DASHBOARD_NAME                     NVARCHAR(128)                      NOT NULL ,
  DASHBOARD_SHARED_USERS             NVARCHAR(512)                               ,
  PRIMARY KEY ( DASHBOARD_ID )
) 
GO


-----------WAS SCHEDULER

CREATE TABLE @SCHEMA@.MONSCHED_TASK ( TASKID BIGINT NOT NULL ,
               VERSION NVARCHAR(5) NOT NULL ,
               ROW_VERSION INT NOT NULL ,
               TASKTYPE INT NOT NULL ,
               TASKSUSPENDED TINYINT NOT NULL ,
               CANCELLED TINYINT NOT NULL ,
               NEXTFIRETIME BIGINT NOT NULL ,
               STARTBYINTERVAL NVARCHAR(254) NULL ,
               STARTBYTIME BIGINT NULL ,
               VALIDFROMTIME BIGINT NULL ,
               VALIDTOTIME BIGINT NULL ,
               REPEATINTERVAL NVARCHAR(254) NULL ,
               MAXREPEATS INT NOT NULL ,
               REPEATSLEFT INT NOT NULL ,
               TASKINFO VARBINARY(MAX) NULL ,
               NAME NVARCHAR(254) NOT NULL ,
               AUTOPURGE INT NOT NULL ,
               FAILUREACTION INT NULL ,
               MAXATTEMPTS INT NULL ,
               QOS INT NULL ,
               PARTITIONID INT NULL ,
               OWNERTOKEN NVARCHAR(200) NOT NULL ,
               CREATETIME BIGINT NOT NULL )
GO               

ALTER TABLE @SCHEMA@.MONSCHED_TASK WITH NOCHECK ADD CONSTRAINT MONSCHED_TASK_PK PRIMARY KEY  NONCLUSTERED ( TASKID );
GO

CREATE INDEX MONSCHED_TASK_IDX1 ON @SCHEMA@.MONSCHED_TASK ( TASKID,
               OWNERTOKEN )
GO               

CREATE CLUSTERED INDEX MONSCHED_TASK_IDX2 ON @SCHEMA@.MONSCHED_TASK ( NEXTFIRETIME ASC,
               REPEATSLEFT,
               PARTITIONID )
GO               

CREATE TABLE @SCHEMA@.MONSCHED_TREG ( REGKEY VARCHAR(254) NOT NULL ,
               REGVALUE VARCHAR(254) NULL ,
               PRIMARY KEY ( REGKEY ) )
GO               

CREATE TABLE @SCHEMA@.MONSCHED_LMGR ( LEASENAME VARCHAR(254) NOT NULL,
               LEASEOWNER VARCHAR(254) NOT NULL,
               LEASE_EXPIRE_TIME BIGINT,
               DISABLED VARCHAR(5) )
GO               

ALTER TABLE @SCHEMA@.MONSCHED_LMGR WITH NOCHECK ADD CONSTRAINT MONSCHED_LMGR_PK PRIMARY KEY  NONCLUSTERED ( LEASENAME )
GO

CREATE TABLE @SCHEMA@.MONSCHED_LMPR ( LEASENAME VARCHAR(254) NOT NULL,
               NAME VARCHAR(254) NOT NULL,
               VALUE VARCHAR(254) NOT NULL )
GO               

CREATE INDEX MONSCHED_LMPR_IDX1 ON @SCHEMA@.MONSCHED_LMPR ( LEASENAME,
               NAME )
GO               


---------- DATASERVICES SCHEDULER TABLES

CREATE TABLE @SCHEMA@.DSS_MODEL_CONFIG_T
(
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    PRIORITY                           BIGINT                             NOT NULL ,
    STATUS                             BIGINT                             NOT NULL ,
    LAST_STARTED                       DATETIME                               NULL ,
    LAST_COMPLETED                     DATETIME                               NULL ,
    LAST_RUN_STATUS                    BIGINT                                 NULL ,
    TASK_ID                            NVARCHAR(128)                          NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( MODEL_ID )
)
GO

-- index for primary key is not generated by default ...
CREATE INDEX DSS_MODEL_CONFIG_P ON @SCHEMA@.DSS_MODEL_CONFIG_T
( 
    MODEL_ID
)
GO


CREATE TABLE @SCHEMA@.DSS_MODEL_SERVICE_CONFIG_T
(
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    SERVICE_NAME                       NVARCHAR(128)                      NOT NULL ,
    SERVICE_PRIORITY                   BIGINT                             NOT NULL ,
    SERVICE_INTERVAL                   BIGINT                             NOT NULL ,
    SERVICE_INT_UNIT                   BIGINT                             NOT NULL ,
    START_TIME                         DATETIME                           NOT NULL ,
    STATUS                             BIGINT                             NOT NULL ,
    LAST_STARTED                       DATETIME                               NULL ,
    LAST_COMPLETED                     DATETIME                               NULL ,
    LAST_RUN_STATUS                    BIGINT                                 NULL ,
    NEXT_EVALUATION                    DATETIME                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( MODEL_ID, SERVICE_NAME )
)
GO

-- index for primary key is not generated by default ...
CREATE INDEX DSS_MODEL_SERVICE_CONFIG_P ON @SCHEMA@.DSS_MODEL_SERVICE_CONFIG_T
( 
    MODEL_ID, SERVICE_NAME
)
GO


CREATE TABLE @SCHEMA@.DSS_MODEL_SERVICE_VER_CONFIG_T
(
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    SERVICE_NAME                       NVARCHAR(128)                      NOT NULL ,
    STATUS                             BIGINT                             NOT NULL ,
    LAST_STARTED                       DATETIME                               NULL ,
    LAST_COMPLETED                     DATETIME                               NULL ,
    LAST_RUN_STATUS                    BIGINT                                 NULL ,
    MESSAGE                            NVARCHAR(4000)                         NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( MODEL_ID, VERSION, SERVICE_NAME )
)
GO

-- index for primary key is not generated by default ...
CREATE INDEX DSS_MODEL_SERVICE_VER_CONFIG_P ON @SCHEMA@.DSS_MODEL_SERVICE_VER_CONFIG_T
( 
    MODEL_ID, VERSION, SERVICE_NAME
)
GO


CREATE TABLE @SCHEMA@.DSS_MODEL_CUBE_STATUS_T
(
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    MC_ID                              NVARCHAR(128)                      NOT NULL ,
    VERSION                            BIGINT                             NOT NULL ,
    SERVER                             NVARCHAR(128)                      NOT NULL ,
    IS_STALE                           SMALLINT                           NOT NULL ,
    STALE_TIME                         DATETIME                               NULL ,
    FRESH_TIME                         DATETIME                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( MODEL_ID, MC_ID, VERSION, SERVER )
)
GO

-- index for primary key is not generated by default ...
CREATE INDEX DSS_MODEL_CUBE_STATUS_P ON @SCHEMA@.DSS_MODEL_CUBE_STATUS_T
( 
    MODEL_ID, MC_ID, VERSION, SERVER
)
GO


CREATE TABLE @SCHEMA@.DSS_MODEL_ARCHIVE_VER_CONFIG_T
(
  MODEL_ID		                NVARCHAR(128)                   NOT NULL ,
  VERSION             	                BIGINT   	                NOT NULL ,	
  OPERATION_NAME 	                NVARCHAR(32)	                NOT NULL ,  	
  TIME_SPAN                      	VARCHAR(128)            	NOT NULL ,
  PATH_NAME           	                NVARCHAR(1000)                           ,		
  LAST_TIMESTAMP  	                NVARCHAR(32)                             ,	    		
  APPEND_FLAG     	                SMALLINT                                 ,	
  MAX_FILE_SIZE  	                BIGINT                                   ,
  VERSION_ID                            SMALLINT                        NOT NULL ,
  PRIMARY KEY ( MODEL_ID, VERSION )
) 
GO

---------- FINE GRAINED SECURITY TABLES


CREATE TABLE @SCHEMA@.FGS_SECURITY_FILTER_T
(
    CONTEXT_KEY                        NVARCHAR(256)                      NOT NULL ,
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    MCID                               NVARCHAR(256)                      NOT NULL ,
    ENTITY_ID                          NVARCHAR(128)                      NOT NULL ,
    ENTITY_TYPE                        NVARCHAR(20)                       NOT NULL ,
    DISPLAY_INDICATION                 SMALLINT                           NOT NULL ,
    FILTER_VALUE                       TEXT                                   NULL ,
    LAST_UPDATED                       DATETIME                                    ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( CONTEXT_KEY, ENTITY_ID, ENTITY_TYPE )
)
GO


CREATE TABLE @SCHEMA@.FGS_METRIC_T
(
    METRIC_KEY                         NVARCHAR(256)                      NOT NULL ,
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    MCID                               NVARCHAR(256)                      NOT NULL ,
    METRIC_ID                          NVARCHAR(256)                      NOT NULL ,
    ENTITY_ID                          NVARCHAR(128)                      NOT NULL ,
    ENTITY_TYPE                        NVARCHAR(20)                       NOT NULL ,
    VISIBLE                            SMALLINT                           NOT NULL ,
    LAST_UPDATED                       DATETIME                                    ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( METRIC_KEY, ENTITY_ID, ENTITY_TYPE )
)
GO


CREATE TABLE @SCHEMA@.FGS_MEASURE_T
(
    MEASURE_KEY                        NVARCHAR(256)                      NOT NULL ,
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    MCID                               NVARCHAR(128)                      NOT NULL ,
    CUBE_ID                            NVARCHAR(128)                      NOT NULL ,
    MEASURE_ID                         NVARCHAR(128)                      NOT NULL ,
    ENTITY_ID                          NVARCHAR(128)                      NOT NULL ,
    ENTITY_TYPE                        NVARCHAR(20)                       NOT NULL ,
    VISIBLE                            SMALLINT                           NOT NULL ,
    LAST_UPDATED                       DATETIME                                    ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( MEASURE_KEY, ENTITY_ID, ENTITY_TYPE )
)
GO


CREATE TABLE @SCHEMA@.FGS_DIMENSION_T
(
    DIMENSION_KEY                      NVARCHAR(256)                      NOT NULL ,
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    MCID                               NVARCHAR(128)                      NOT NULL ,
    CUBE_ID                            NVARCHAR(128)                      NOT NULL ,
    DIMENSION_ID                       NVARCHAR(128)                      NOT NULL ,
    ENTITY_ID                          NVARCHAR(128)                      NOT NULL ,
    ENTITY_TYPE                        NVARCHAR(20)                       NOT NULL ,
    VISIBLE                            SMALLINT                           NOT NULL ,
    LAST_UPDATED                       DATETIME                                    ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( DIMENSION_KEY, ENTITY_ID, ENTITY_TYPE )
)
GO


CREATE TABLE @SCHEMA@.FGS_ALERT_TMPLT_T
(
    ALERT_KEY                          NVARCHAR(256)                      NOT NULL ,
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    TEMPLATE_ID                        NVARCHAR(128)                      NOT NULL ,
    ENTITY_ID                          NVARCHAR(128)                      NOT NULL ,
    ENTITY_TYPE                        NVARCHAR(20)                       NOT NULL ,
    VISIBLE                            SMALLINT                           NOT NULL ,
    LAST_UPDATED                       DATETIME                                    ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ALERT_KEY, ENTITY_ID, ENTITY_TYPE )
)
GO


CREATE TABLE @SCHEMA@.FGS_KPI_T
(
    KPI_KEY                            NVARCHAR(256)                      NOT NULL ,
    MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
    KPIID                              NVARCHAR(128)                      NOT NULL ,
    ENTITY_ID                          NVARCHAR(128)                      NOT NULL ,
    ENTITY_TYPE                        NVARCHAR(20)                       NOT NULL ,
    VISIBLE                            SMALLINT                           NOT NULL ,
    LAST_UPDATED                       DATETIME                                    ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( KPI_KEY, ENTITY_ID, ENTITY_TYPE )
)
GO


CREATE TABLE @SCHEMA@.FGS_MONITOR_CONTEXT_T
(
  MC_KEY                             NVARCHAR(256)                     NOT NULL ,
  MODEL_ID                           NVARCHAR(128)                     NOT NULL ,
  MCID                               NVARCHAR(256)                     NOT NULL ,
  ENTITY_ID                          NVARCHAR(128)                     NOT NULL ,
  ENTITY_TYPE                        NVARCHAR(20)                      NOT NULL ,
  VISIBLE                            SMALLINT                          NOT NULL ,
  LAST_UPDATED                       DATETIME                                   ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( MC_KEY, ENTITY_ID, ENTITY_TYPE )
) 
GO


CREATE TABLE @SCHEMA@.MONPROPS_T
(
 CONTEXT	                     NVARCHAR(128)                      NOT NULL ,
 PROPERTY	                     NVARCHAR(128)                      NOT NULL ,
 CHARVALUE	                     NVARCHAR(512)                               ,
 INTVALUE	                     INTEGER                                     ,
 DECVALUE	                     FLOAT(53)                                   , 
 TIMEVALUE	                     DATETIME                                    ,
 CLOBVALUE 	                     TEXT                                        , 
 BLOBVALUE 	                     VARBINARY(MAX)                              ,
 VERSION_ID                          SMALLINT                                    ,
 PRIMARY KEY ( CONTEXT, PROPERTY )
)
GO

---------- AUDIT LOG

CREATE TABLE @SCHEMA@.AUDIT_TRAIL_T
(
  AUDIT_ENTRY_ID                     BIGINT IDENTITY(1,1)               NOT NULL ,
  MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                                      ,
  STEP                               NVARCHAR(256)                      NOT NULL ,
  AUDIT_TIMESTAMP                    DATETIME                           NOT NULL ,
  ARRIVAL_TIMESTAMP                  DATETIME                                    ,
  AUDIT_MSG_TYPE                     NVARCHAR(1)                        NOT NULL ,
  HOSTNAME                           NVARCHAR(256)                               ,
  PORT_NUMBER                        NVARCHAR(8)                                 ,
  AUDIT_MESSAGE                      NVARCHAR(2048)                              ,
  VERSION_ID                         SMALLINT                           NOT NULL ,
  PRIMARY KEY ( AUDIT_ENTRY_ID )
)
GO



---------- DIRECT TO DEPLOY TABLES

CREATE TABLE @SCHEMA@.D2D_ITEM (
  ID                                    NVARCHAR(128)                   NOT NULL , 
  STATE                                 NVARCHAR(20)                    NOT NULL ,
  ITEM_LEVEL                            INTEGER                         NOT NULL ,
  MODULE_NAME                           NVARCHAR(255)                            ,
  APPLICATION_NAME                      NVARCHAR(255)                            ,
  VERSION                               NVARCHAR(30)                             , 
  NEW_APP_NAME                          NVARCHAR(255)                            ,
  PRIMARY KEY ( ID ) 
) 
GO

CREATE TABLE @SCHEMA@.D2D_PROGRESS (
  ITEM_ID                               NVARCHAR(128)                   NOT NULL ,
  PROGRESS                              INTEGER                                  ,
  PROGRESS_MSG                          NVARCHAR(255)                            ,
  PROGRESS_ERROR_CODE                   NVARCHAR(255)                            ,
  PRIMARY KEY (ITEM_ID) ,
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) ON DELETE CASCADE
)
GO

CREATE TABLE @SCHEMA@.D2D_CONTENT (
  ITEM_ID                               NVARCHAR(128)                   NOT NULL ,
  PI                                    VARBINARY(MAX)                                     ,
  PRIMARY KEY (ITEM_ID) ,
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) ON DELETE CASCADE
)
GO

CREATE TABLE @SCHEMA@.D2D_METADATA (
  ITEM_ID                               NVARCHAR(128)                   NOT NULL ,
  NAME                                  NVARCHAR(128)                   NOT NULL ,
  VALUE                                 NVARCHAR(255)                            ,
  PRIMARY KEY ( ITEM_ID, NAME ) ,
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) ON DELETE CASCADE
)
GO

CREATE TABLE @SCHEMA@.D2D_LOCK (
  LOCK_ID                               CHAR(2)                    NOT NULL ,
  LASTUPDATE                            DATETIME                                ,
  PRIMARY KEY ( LOCK_ID )
)
GO

INSERT INTO @SCHEMA@.D2D_LOCK VALUES ('N1', NULL)
GO

INSERT INTO @SCHEMA@.D2D_LOCK VALUES ('N2', NULL)
GO

CREATE TABLE @SCHEMA@.D2D_MESSAGE (
  ITEM_ID                               NVARCHAR(128)                   NOT NULL ,
  SEQ                                   INTEGER                         NOT NULL ,
  ID                                    NVARCHAR(63)                             ,
  DESCRIPTION                           NVARCHAR(1024)                           ,
  MSG_RESOURCE                          NVARCHAR(255)                            ,
  LOCATION                              NVARCHAR(63)                             ,
  FOLDER                                NVARCHAR(255)                            ,
  MSG_STR                               NVARCHAR(63)                             ,
  TAG	                                NVARCHAR(63)                             ,
  SEVERITY                              NVARCHAR(15)                             ,
  TIME                                  DATETIME                                 ,
  PRIMARY KEY ( ITEM_ID, SEQ ) ,
  FOREIGN KEY ( ITEM_ID ) REFERENCES @SCHEMA@.D2D_ITEM( ID ) ON DELETE CASCADE
)
GO


CREATE FUNCTION @SCHEMA@.DAYS (@TIME2 DATETIME)
RETURNS BIGINT
AS
BEGIN
	DECLARE @numdays int;
	--693596 is the number of days from Jan 1 0001 00:00:00 to Jan 1 1900 00:00:00
	--SQLServer cannot use datediff that far in the past
	set @numdays = datediff(dd, 'Jan 1 1900 00:00:00', @TIME2 );
	
	RETURN (@numdays);
END;

GO

CREATE FUNCTION @SCHEMA@.MIDNIGHT_SECONDS (@TIME2 DATETIME)
RETURNS BIGINT
AS
BEGIN
	DECLARE @midnight_sec int;
	SET @midnight_sec = (datepart(hh, @TIME2) * 3600 ) + 
		(datepart(mi, @TIME2) * 60) + datepart(ss, @TIME2);
	RETURN(@midnight_sec);
END;

GO

--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.SCHEMA_VERSION TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.MODERATOR_NEXT_ID TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.MM_TO_WPS_PT TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.RECORDED_EVENTS TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.RECORDED_EVENTS_MODELVERSIONS TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_MODEL_UNVERSIONED_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.CEI_SERVER_SOURCE_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_MODEL_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_MODEL_STEP_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_MONITOR_CONTEXT_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_MONITOR_METRIC_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_DIMENSION_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_DIM_ATTR_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_MEASURE_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_KPI_CONTEXT_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_KPI_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_KPI_PERSONALIZED_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_KPI_CACHE_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_KPI_METRIC_FILTER_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_KPI_RANGE_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_KPI_RANGE_PERSONALIZED_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_KPI_DEPENDENCY_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.KPI_HISTORY_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.KPI_TS_PREDICTION_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.KPI_TS_PREDICTION_MODEL_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DMS_METADATA_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DMS_HISTORY_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DMS_TRACE_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.META_OUTBOUND_EVENT_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ACT_MGR_ALERTS_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ACT_ALERT_COMMENTS_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DASHBOARD_ALERT_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ACT_HNDLR_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ACTION_HANDLER_CTRL_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.PLUG_SVC_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ACT_TMPLT_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ACTION_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.SUBSCRIBED_USER_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ETAMATCH_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ATAMATCH_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ETAACTRL_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ACTION_MANAGER_PROP_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.EQ_MODEL_VERSION_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DQ_MODEL_VERSION_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.EQ_INSTANCE_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.EQ_FAILED_EVENT_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DQ_DEAD_EVENT_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ACT_SITUATION_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ACT_SIT_TRIG_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DIM_TIME TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.RAT_RESOURCE_GROUPS TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.RAT_AUTH_DOMAIN TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.RAT_SUPERUSERS TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.RAT_PARTY_ROLES TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.RAT_UPDATE_MONITOR TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DASHBOARD_DATA_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.MONSCHED_TASK TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.MONSCHED_TREG TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.MONSCHED_LMGR TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.MONSCHED_LMPR TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DSS_MODEL_CONFIG_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DSS_MODEL_SERVICE_CONFIG_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DSS_MODEL_SERVICE_VER_CONFIG_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DSS_MODEL_CUBE_STATUS_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.DSS_MODEL_ARCHIVE_VER_CONFIG_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.FGS_SECURITY_FILTER_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.FGS_METRIC_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.FGS_MEASURE_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.FGS_DIMENSION_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.FGS_ALERT_TMPLT_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.FGS_KPI_T TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ABX_VERSION TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ABX_PROPERTY_MAP TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ABX_OBJECTS TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ABX_LOOKUP TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ABX_TYPES TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.ABX_LOOKUP_VALUES TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.D2D_ITEM TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.D2D_PROGRESS TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.D2D_CONTENT TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.D2D_METADATA TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.D2D_LOCK TO @DB_USER@;
--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.D2D_MESSAGE TO @DB_USER@;

--GRANT STMT-- GRANT SELECT ON @SCHEMA@.ACT_TMPLT TO @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.ETAMATCH TO @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.ACTION TO @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.ACT_MGR_PROP TO @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.PLUG_SVC TO @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.ALERTS TO @DB_USER@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.EQ_FE_IDS TO @DB_USER@;

GO
