#!/bin/sh

#############################################################################
#  Licensed Materials - Property of IBM
#  5724-M24
#  Copyright IBM Corporation 2007,2012. All Rights Reserved.
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#############################################################################

#echo ""
#echo "Start Monitor Verification Test"
#echo ""

#######################################################
#                                                     #
# Subroutine: Usage                                   #
#                                                     #
#######################################################

usage () {
  echo ""
  echo "showcase.sh -w <profile directory> "
  echo ""
  echo "where:  "
  echo ""
  echo "  -w <profile directory> :"
  echo "     WAS profile directory. If not provided will assume ../.. "
  echo ""
  exit
  
}

#######################################################
#                                                     #
# Variables                                           #
#                                                     #
#######################################################
runDir="."
runFile="NULL"
showcaseHome=""
testMode=5
modelDir="showcase"
profileDir=""
serverName="server1"
xmlFileName="NULL"
userId=""
password=""
keep="false"
tmpFile=showcase_$$
profileType=1
portChanged=0

#######################################################
#                                                     #
# Read command line options                           #
#                                                     #
#######################################################

while getopts ":c:d:f:k:m:o:p:s:t:u:w:" opt
do
  case $opt in
    c) runDir=$OPTARG;;
    d) showcaseHome=$OPTARG;;
    f) runFile=$OPTARG;;
    k) keep="true";;
    m) testMode=$OPTARG;;
    n) modelMode=$OPTARG;;
    o) xmlFileName=$OPTARG;;
    p) password=$OPTARG;;
    s) serverName=$OPTARG;;
    t) profileType=$OPTARG;;
    u) userId=$OPTARG;;
    w) profileDir=$OPTARG;;
    ?) usage
  esac
done


#######################################################
#                                                     #
# If runFile provide check the testMode               #
#                                                     #
#######################################################
if [ "$runFile" != "NULL" ]; then
  testMode=9
  #testMode=`echo $runFile | sed 's/^.*\([0-9]\)\.[^\.]\+$/\1/g'`
  #if [ -z $testMode ]; then
  #  echo "Can't parse $runFile to get testMode"
  #  exit
  #fi
fi



#######################################################
#                                                     #
# Determine profile home directory                    #
# Go to monitor firststep directory                   #
# Set WAS environment                                 #
#                                                     #
#######################################################


if [ -z "$profileDir" ]; then
  curDir=`dirname ${0}`
  cd $curDir/../..
  profileDir=`pwd`
fi

#for noprofile case
if [ $profileType -eq  3 ]; then
  WAS_HOME=$profileDir
  #Only run IVU for noprofile
  testMode=0
else 
  . $profileDir/bin/setupCmdLine.sh 
fi

#######################################################
#                                                     #
# Go to showcase home                                      #
#                                                     #
#######################################################
if [ -z "$showcaseHome" ]; then
  cd ${WAS_HOME}
  cd installableApps.wbm/showcase/scripts
else
  cd ${showcaseHome}
fi

#echo ""
./jython.sh -w ${WAS_HOME}  message.jy "start.monitor.verification.test" 1>/dev/null 2>/dev/null
#echo ""
cp -f $WAS_HOME/installableApps.wbm/showcase/dashboards/showcase_dashboard.zip $profileDir/BusinessSpace/mm.runtime.prof/spaces/showcase_dashboard.zip 1>/dev/null 2>/dev/null
cp -f $WAS_HOME/installableApps.wbm/showcase/dashboards/showcase_dashboard.zip $profileDir/BusinessSpace/qnode/server1/mm.runtime.prof/spaces/showcase_dashboard.zip 1>/dev/null 2>/dev/null
#cp -f $WAS_HOME/installableApps.wbm/showcase/scripts/importSpaces.txt $profileDir/BusinessSpace/mm.runtime.prof/spaces/importSpaces.txt 1>/dev/null 2>/dev/null

#######################################################
#                                                     #
# Security                                            #
#                                                     #
#######################################################

#work around JVM bug on AIX
LIBPATH=
export LIBPATH

security="false"
if [ $testMode -gt 2 ]; then
  security=`./jython.sh -w $WAS_HOME lib/security.py $profileDir $WAS_CELL`

  #echo "security: $security"
  if [ "$security" = "true" ]; then
    if [ -z "$userId" ]; then
      CP=${WAS_HOME}/lib/wbminstall_util.jar
      userpwd=`${JAVA_HOME}/bin/java -cp $CP com.ibm.wbm.install.util.gui.UserPassword` 
      userId=`echo $userpwd | awk 'BEGIN {FS=":"}{print $1}'`
      password=`echo $userpwd | awk 'BEGIN {FS=":"}{print $2}'`
    fi
    [ -z "$userId" ] && testMode=2 
    [ -z "$password" ] && testMode=2 
  fi
fi

wsadminPropFile=${profileDir}/firststeps.wbm/ivt/wsadmin.properties.tmp
./jython.sh -w $WAS_HOME lib/wsadminproperties.py "disableEchoParams" $profileDir $wsadminPropFile


#######################################################
#                                                     #
# If testMode equals or is greater than 3 showcase need    #
# application server or deployment manager started    #
#                                                     #
#######################################################
wasStarted=1
initServerStatus="stop"
if [ $testMode -gt 2 ]; then


  if [ $profileType -ne 2 ]; then
    if [ $testMode -gt 4 ]; then
      if [ "$security" = "true" ]; then
        $profileDir/bin/stopServer.sh $serverName -username $userId -password $password  > /dev/null 2>&1
      else
        $profileDir/bin/stopServer.sh $serverName  > /dev/null 2>&1
      fi
      #echo "Start application server"
      ./jython.sh -w ${WAS_HOME} message.jy "start.application.server"
    else
      #echo "Start application server if it hasn't been started"
      ./jython.sh -w ${WAS_HOME} message.jy "start.application.server.if"
    fi
    $profileDir/bin/startServer.sh $serverName > $tmpFile 2>&1
    cat $tmpFile | grep "ADMU3027" >/dev/null  2>&1
    #test $? = 0 &&  echo "application server already started on $serverName"
    test $? = 0 &&  ./jython.sh -w ${WAS_HOME} message.jy "application.server.already.started" $serverName
    
    # record server status
    cat $tmpFile | grep "ADMU3027" >/dev/null  2>&1
    if [ $? -eq 0 ]; then
       initServerStatus="start"
    fi
    
    cat $tmpFile | grep "ADMU3000I" >/dev/null  2>&1
    if [ $? = 0 ]; then
       initServerStatus="stop"
    fi
    
    cat $tmpFile | grep "ADMU3000I" >/dev/null 2>&1 || cat $tmpFile | grep "ADMU3027" >/dev/null 2>&1
    test $? != 0 && {
      #echo "Unable to start application server on $serverName"
      ./jython.sh -w ${WAS_HOME}  message.jy "application.server.start.failed" $serverName
      wasStarted=0
    }
    rm -rf $tmpFile
  else
    #echo "Start deploy manager if it hasn't been started"
    ./jython.sh -w ${WAS_HOME} message.jy "start.deployment.manager.server.if"
    $profileDir/bin/startManager.sh  > $tmpFile

    cat $tmpFile | grep "ADMU3027" >/dev/null 2>&1 
    #test $? = 0 &&  echo "manager server already started"
    test $? = 0 &&  ./jython.sh -w ${WAS_HOME}  message.jy "deployment.manager.server.already.started"
    
    # record server status
    cat $tmpFile | grep "ADMU3027" >/dev/null  2>&1
    if [ $? -eq 0 ]; then
       initServerStatus="start"
    fi
    
    cat $tmpFile | grep "ADMU3000I" >/dev/null  2>&1
    if [ $? = 0 ]; then
       initServerStatus="stop"
    fi
    
    cat $tmpFile | grep "ADMU3000I" >/dev/null 2>&1 || cat $tmpFile | grep "ADMU3027" >/dev/null 2>&1
    test $? != 0 && {
      #echo "Unable to start deploy manager server"
      ./jython.sh -w ${WAS_HOME} message.jy "deployment.manager.server.start.failed"
      wasStarted=0
    }
    rm -rf $tmpFile
  fi
  if [ $wasStarted -ne 1 ]; then
    if [ ! "$runFile" = "NULL" ]; then
      #echo "Can't run the $runFile without server started"
      ./jython.sh -w ${WAS_HOME}  message.jy "can.not.run.ivt" "$runFile"
      exit
    else
      if [ $testMode -gt 2 ]; then
        testMode=2
      fi
    fi
  fi
fi





#######################################################
#                                                     #
# Run Install Verification Test                       #
#                                                     #
#######################################################

echo ""

#######################################################
#                                                     #
# Don't need connect to server if testMode is         #
# less than 3                                         #
#                                                     #
#######################################################

WASLIB=${WAS_HOME}/lib
PLUGINS=${WAS_HOME}/plugins
SHOWCASELIB=${WAS_HOME}/installableApps.wbm/showcase/scripts/lib
LC_JAR=`ls ${PLUGINS}/com.ibm.wbimonitor.lifecycle.jar`
LC_SPI_JAR=`ls ${PLUGINS}/com.ibm.wbimonitor.lifecycle.spi.jar`
REPOS_JAR=`ls ${PLUGINS}/com.ibm.wbimonitor.repository.jar`
WS_CP=${WASLIB}/wbminstall_util.jar:${WASLIB}/wbminstall_log.jar:${LC_JAR}:${LC_SPI_JAR}:${SHOWCASELIB}/JSON4J.jar:${REPOS_JAR}

#work around JVM bug on AIX
LIBPATH=
export LIBPATH

if [ $testMode -lt 3 ]; then
  $profileDir/bin/wsadmin.sh -wsadmin_classpath $WS_CP -conntype NONE -lang jython \
      -f showcase.jy $serverName "false" $testMode  $profileDir $xmlFileName $profileType \
      $runDir $runFile $keep -javaoption "-DWAS_HOME=${WAS_HOME}" 
  
else
  if [ "$security" = "true" ]; then
  #######################################################
  #                                                     #
  # Connects with server with user id and password      #
  # provided                                            #
  #                                                     #
  #######################################################
    $profileDir/bin/wsadmin.sh -wsadmin_classpath $WS_CP -user $userId -password $password \
      -lang jython -f showcase.jy $serverName "true" $userId $password $testMode \
      $profileDir  $xmlFileName $profileType $runDir $runFile $modelDir $keep -javaoption "-DWAS_HOME=${WAS_HOME}"
    $profileDir/bin/stopServer.sh $serverName -username $userId -password $password  > /dev/null 2>&1
    if [ "$initServerStatus" = "start" ]; then
    	$profileDir/bin/startServer.sh $serverName > /dev/null 2>&1
    fi
  else
  #######################################################
  #                                                     #
  # Connects with server without security               #
  #                                                     #
  #######################################################
    $profileDir/bin/wsadmin.sh -wsadmin_classpath $WS_CP -lang jython \
      -f showcase.jy $serverName "false" $testMode  $profileDir $xmlFileName $profileType  \
      $runDir $runFile $modelDir $keep -javaoption "-DWAS_HOME=${WAS_HOME}"
    $profileDir/bin/stopServer.sh $serverName  > /dev/null 2>&1
    if [ "$initServerStatus" = "start" ]; then
    	$profileDir/bin/startServer.sh $serverName > /dev/null 2>&1
    fi
  fi
fi


mv $wsadminPropFile ${profileDir}/properties/wsadmin.properties 


#######################################################
#                                                     #
# Other tests (not through wsadmin)                   #
#                                                     #
#######################################################


echo ""
#echo "Done"
