#   Licensed Materials - Property of IBM
#   5724-M24
#   Copyright IBM Corporation 2007,2009. All Rights Reserved.
#   US Government Users Restricted Rights - Use, duplication or disclosure
#   restricted by GSA ADP Schedule Contract with IBM Corp.
#

import java
#-------------------------------------------------------------------------------
# This jython script installs the referenced WAR
#-------------------------------------------------------------------------------

def wsadminToList(inStr):
        outList=[]
        if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
                tmpList = inStr[1:-1].split(" ")
        else:
                tmpList = inStr.split("\n")  #splits for Windows or Linux
        for item in tmpList:
                item = item.rstrip();        #removes any Windows "\r"
                if (len(item)>0):
                        outList.append(item)
        return outList
#endDef

#########################################################
# installWar subroutine
# location - location where the WAR resides
# warName - name of the war in the location directory
# appName - name of the Application
# nodeName - name of the WAS node
# contextRoot - context root for the web application
#########################################################
def installWar ( location, warName, appName, nodeName, contextRoot ):
        rc = 0
        print "INFO:  Entering installWar"
        print "INFO:  location="+location+",warName="+warName+",appName="+appName+",nodeName="+nodeName, "contextRoot="+contextRoot

        #--------------------------------------------------------------
        # set up globals
        #--------------------------------------------------------------
        global AdminConfig
 
        #--------------------------------------------------------------
        # do some sanity checking 
        #     -- do we have a node by this name? 
        #--------------------------------------------------------------
        #cellname = AdminControl.getCell( )
        cellName = AdminConfig.showAttribute(AdminConfig.list("Cell"), "name")
        node = AdminConfig.getid("/Node:"+nodeName+"/" )
        print "INFO:  checking for existence of node "+nodeName
        if (len(node) == 0):
                print "INFO:  Error -- node not found for name "+nodeName
                rc = -1
                return rc 
        #endIf 

        #---------------------------------------------------------
        # First, list the existing applications 
        #---------------------------------------------------------
        apps = AdminApp.list( )
        print "INFO:  Installed applications: "
        print apps

        # Check if App is already installed on the target server
        # Comparing the application name.
        appExist = "False"
        for tmpAppName in wsadminToList(apps):
       	        if (cmp(tmpAppName, appName) == 0):
               	        appExist = "True"
                       	break 
                #endIf 
	#endFor 
  

        #---------------------------------------------------------
        # Here is the war file we'll be dealing with... 
        #---------------------------------------------------------
        defapp = location+"/"+warName+".war"

        #---------------------------------------------------------
        # Build the Map Web Module To Virtual Host options string 
        #
        # NOTE: this may have to be moved outside of this script
        #       because the string may be built by rules specific
        #       to the Web App definition
        #---------------------------------------------------------
        mapWebModOptStr='-MapWebModToVH [[ "'+warName+'.war" '+warName+'.war,WEB-INF/web.xml default_host ]]'
        print "INFO:  mapWebModOptStr="+str(mapWebModOptStr)

        #---------------------------------------------------------
        # A very simple install command 
        #---------------------------------------------------------
        if (cmp(appExist, "True") == 0):
                print "WARNING: "+warName+".war (ApplicationName: "+appName+") is already installed on server."
		print "WARNING: Uninstallation of "+appName+" to begin. "

                AdminApp.uninstall(appName )

                #check for success
                appExist = "False"
                for tmpAppName in wsadminToList(AdminApp.list()):
                        if (cmp(tmpAppName, appName) == 0):
                                appExist = "True"
                                break 
                        #endIf 
                #endFor 
                if (cmp(appExist, "False") == 0):
                        print "INFO:  Existing Application "+appName+" successfully removed."
                        AdminConfig.save( )
                else:
                        print "ERROR: Existing Application "+appName+" could not be removed."
                #endElse 
        #endIf 

        #remove the logic below per defect 573743
        
        #service = AdminConfig.list("TransactionService" )
        #trans_opts = [["transactionLogDirectory", ";0"]]
        #AdminConfig.modify(service, trans_opts )
        #AdminConfig.save( )

        print "INFO:  Installation of New Web Application "+appName+" beginning."
        try:
        	# AdminApp.install(defapp, ["-appname", appName, "-node", nodeName, "-contextroot", contextRoot] )
            AdminApp.install(defapp, ["-appname", appName, "-node", nodeName, "-contextroot", contextRoot, mapWebModOptStr] )
        except:
            print "Exception occurs in AdminApp.install."
            rc = -1	
	
        #
        # check for success       
        #
        appExist = "False"
        for tmpAppName in wsadminToList(AdminApp.list()):
                 if (cmp(tmpAppName, appName) == 0):
                         appExist = "True"
                         break 
                 #endIf 
        #endFor 
        if (cmp(appExist, "True") == 0):
                 print "INFO:  New Application "+appName+" successfully installed."
                 AdminConfig.save( )
        else:
                 print "ERROR: New Application "+appName+" could not be installed."
                 rc = -1
        #endElse 

        AdminConfig.save( )
        print "INFO:  Exiting installWar"	        
        return rc
#endDef 

#-----------------------------------------------------------------
# Main
#-----------------------------------------------------------------
#if ((len(sys.argv) != 6)):
#        print "installWar: this script requires 6 parameters: scriptname, location of war, war, application, node, contextroot"
#        print "e.g.:     installWar.py /opt/WebSphere/VoiceServer/war wvsapp WVS mynode MyService"
#else:
#        installWar(sys.argv[1], sys.argv[2], sys.argv[3], sys.argv[4] sys.arg[5])
#endif 

