#  Licensed Materials - Property of IBM
#  5724-M24
#  Copyright IBM Corporation 2008, 2009. All Rights Reserved.
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#

import sys
import java

def wsadminToList(inStr):
        outList=[]
        if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
                tmpList = inStr[1:-1].split() #splits space-separated lists,
        else:
                tmpList = inStr.split("\n")   #splits for Windows or Linux
        for item in tmpList:
                item = item.rstrip();         #removes any Windows "\r"
                if (len(item)>0):
                        outList.append(item)
        return outList
#endDef

# get line separator 
lineSeparator = java.lang.System.getProperty('line.separator') 

class UtilWsadminHolder:
    AdminConfig = None
    AdminTask = None

class Scope:
    CLUSTER_SCOPE = 1
    CELL_SCOPE = 2
    NODE_SCOPE = 3
    SERVER_SCOPE = 4
# instance variables are...
#    cell
#    node
#    server
#    cluster
    
    def __init__(self, cluster, cell, node, server):
        self.cluster = cluster
        self.cell = cell
        self.node = node
        self.server = server
        self.containmentPathMap = {}
        self.containmentPathMap[Scope.CLUSTER_SCOPE] = "/Cell:" + cell + "/Cluster:" + cluster + "/"
        self.containmentPathMap[Scope.CELL_SCOPE] = "/Cell:" + cell + "/"
        self.containmentPathMap[Scope.NODE_SCOPE] = "/Cell:" + cell + "/Node:" + node + "/"
        self.containmentPathMap[Scope.SERVER_SCOPE] = "/Cell:" + cell + "/Node:" + node + "/Server:" + server + "/"

    def getConfigId(self, scopeLevel):
        return AdminConfig.getid(self.getContainmentPath(scopeLevel))

    def getContainmentPath(self, scopeLevel):
        return self.containmentPathMap[scopeLevel]

class SchedulerInfo:
# instance variables are.... They are created in __init__ so they don't end up Class variables
# name
# desc
# jndiName
# datasourceJNDIName
# datasourceAlias
# workManagerInfoJNDIName
# category
# pollInterval
# tablePrefix
# useAdminRoles

    def __init__(self, name, desc, jndiName, datasourceJNDIName, datasourceAlias, workManagerInfoJNDIName, category, pollInterval, tablePrefix, useAdminRoles):
        self.name = name
        self.desc = desc
        self.jndiName = jndiName
        self.datasourceJNDIName = datasourceJNDIName
        self.datasourceAlias = datasourceAlias
        self.workManagerInfoJNDIName = workManagerInfoJNDIName
        self.category = category
        self.pollInterval = pollInterval
        self.tablePrefix = tablePrefix
        self.useAdminRoles = useAdminRoles

def getScheduler(scope, scopeLevel, schedulerName):
    schedulerConfigId = UtilWsadminHolder.AdminConfig.getid("/SchedulerConfiguration:" + schedulerName + "/" )
    
    if (schedulerConfigId == ""):
        print "Did not find Scheduler: " + schedulerName
        return None
    else:
        print "Found Scheduler: " + schedulerConfigId
        return schedulerConfigId

def createScheduler(scope, scopeLevel, schedulerInfo):
    schedulerConfigId = getScheduler(scope, scopeLevel, schedulerInfo.name)
    
    if (schedulerConfigId == None):
        nameAttr = ["name",schedulerInfo.name]
        descAttr = ["description",schedulerInfo.desc]
        jndiNameAttr = ["jndiName",schedulerInfo.jndiName]
        datasourceJNDINameAttr = ["datasourceJNDIName",schedulerInfo.datasourceJNDIName]
        datasourceAliasAttr = ["datasourceAlias",schedulerInfo.datasourceAlias]
        workManagerInfoJNDINameAttr = ["workManagerInfoJNDIName",schedulerInfo.workManagerInfoJNDIName]
        categoryAttr = ["category",schedulerInfo.category]
        pollIntervalAttr = ["pollInterval",schedulerInfo.pollInterval]
        tablePrefixAttr = ["tablePrefix",schedulerInfo.tablePrefix]
        useAdminRolesAttr = ["useAdminRoles",schedulerInfo.useAdminRoles]

        schedulerCreateArgs = [nameAttr, descAttr, jndiNameAttr, datasourceJNDINameAttr, datasourceAliasAttr, workManagerInfoJNDINameAttr, categoryAttr, pollIntervalAttr, tablePrefixAttr, useAdminRolesAttr]
        
        parentContainment = scope.getContainmentPath(scopeLevel) + "SchedulerProvider:SchedulerProvider/"
        parentId = UtilWsadminHolder.AdminConfig.getid(parentContainment)

        print "Create Schedulter with", schedulerCreateArgs, "under parent", parentId, "based on containment", parentContainment
        schedulerConfigId = UtilWsadminHolder.AdminConfig.create("SchedulerConfiguration", parentId, schedulerCreateArgs)

    return schedulerConfigId


#--------------------------------------------------------------------
# Create Data Services Scheduler
#--------------------------------------------------------------------
scopeString = sys.argv[0]
cellName = sys.argv[1]
nodeName = sys.argv[2]
serverName = sys.argv[3]

dssName=sys.argv[4]
dssDesc=sys.argv[5]
dssJndiName=sys.argv[6]
dssDatasourceJNDIName=sys.argv[7]
dssDatasourceAlias=sys.argv[8]
dssWorkManagerInfoJNDIName=sys.argv[9]
dssCategory=sys.argv[10]
dssPollInterval=sys.argv[11]
dssTablePrefix=sys.argv[12]
dssUseAdminRoles=sys.argv[13]

ndType=sys.argv[14]

UtilWsadminHolder.AdminConfig = AdminConfig
UtilWsadminHolder.AdminTask = AdminTask

if (ndType == "managed"):
    try:
        cellName = AdminControl.getCell()
    except:
        print "warning: AdminControl may not be available."   

scope = Scope("clusterName", cellName, nodeName, serverName)
scopeLevel = ""
if(scopeString =="CELL"):
    scopeLevel = Scope.CELL_SCOPE
elif(scopeString =="NODE"):
    scopeLevel = Scope.NODE_SCOPE
elif(scopeString =="SERVER"):
    scopeLevel = Scope.SERVER_SCOPE
    
print "scopeLevel="+str(scopeLevel)    

dataServicesSchedulerInfo = SchedulerInfo( dssName, dssDesc, dssJndiName, dssDatasourceJNDIName, dssDatasourceAlias, dssWorkManagerInfoJNDIName, dssCategory, dssPollInterval, dssTablePrefix, dssUseAdminRoles)
# Check for DataServices Scheduler
# If it does not exist then create it.
if (getScheduler(scope, scopeLevel, dataServicesSchedulerInfo.name) == None):
    print "Create " + dataServicesSchedulerInfo.name + " if needed"
    createScheduler(scope, scopeLevel, dataServicesSchedulerInfo)

AdminConfig.save()




