#  Licensed Materials - Property of IBM
#  5724-M24
#  Copyright IBM Corporation 2009, 2011. All Rights Reserved.
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.

# This file is meant to be used as a Jython module.
# To use in your script:
#   import os
#   execfile(os.path.normpath(os.path.join(profilePath, 'config.wbm/MonitorProfileVals.py')))
#   sys.path.append(os.path.normpath(os.path.join(templatePath, '../actions/scripts/modules')))
#   import ResourceHelper
 
import time

def createEnvironmentVariable(scope, name, value):
	existingValue = getEnvironmentVariable(scope, name)
	if existingValue:
		log('At scope %s, the environment variable %s = "%s".' % (scope, name, existingValue))
	else:
		log('At scope %s, the environment variable %s is not set.' % (scope, name))
	if existingValue != value:
		log('At scope %s, the environment variable %s will be set to "%s".' % (scope, name, value))
		AdminTask.setVariable([ '-scope', scope, '-variableName', name, '-variableValue', value ])

def createDatasource(targetDBProviderConfigId, createDatasourceArgs, createDatasourceProperties, connectionPoolAttributes, customProperties, containerManagedAuthenticationAlias):
	log("ENTRY createDatasource")
	log("Database provider: %s" % targetDBProviderConfigId) 
	log("Arguments: %s" % createDatasourceArgs) 
	log("Properties: %s" % createDatasourceProperties) 
	log("Connection pool attributes: %s" % connectionPoolAttributes) 
	log("Custom properties: %s" % customProperties)
	log("CMP authentication alias: %s" % containerManagedAuthenticationAlias)
	
	# create data source 
	log('Creating datasource...')  
	configureResourceProperties = '[' + ' '.join([ "[%s %s %s]" % (key, type, value) for (key,type,value) in createDatasourceProperties]) + ']'
	datasourceConfigId = AdminTask.createDatasource(targetDBProviderConfigId, '[%s -configureResourceProperties %s]' % (" ".join(["-%s '%s'" % (key, value) for key, value in createDatasourceArgs.items()]), configureResourceProperties))
	
	# create mapping module for data source
	log('Creating module mapping for datasource...')  
	AdminConfig.create('MappingModule', datasourceConfigId, [[ 'authDataAlias',  containerManagedAuthenticationAlias],['mappingConfigAlias', 'DefaultPrincipalMapping']])
	
	# update connection pool attributes
	log('Setting connection pool atributes...') 
	connectionPoolId = AdminConfig.showAttribute(datasourceConfigId, 'connectionPool')
	AdminConfig.modify(connectionPoolId, '[' + ' '.join(['[%s \"%s\"]' % (key, value) for (key, value) in connectionPoolAttributes.items()]) + ']')
	
	# update custom properties
	log('Updating custom properties...')
	propertySetId = AdminConfig.showAttribute(datasourceConfigId, 'propertySet')
	resourceProperties = AdminConfig.showAttribute(propertySetId, 'resourceProperties')
	for resourceProperty in resourceProperties[1:len(resourceProperties)-1].split(' '):
		for name, value in customProperties.items():
			if AdminConfig.showAttribute(resourceProperty, 'name') == name:
				AdminConfig.modify(resourceProperty, [['value', value]])
				break
	
	# lookup CMP connector factory
	log('Looking up CMP connector factory...') 
	for cmpConnectorFactory in AdminConfig.list('CMPConnectorFactory').splitlines():
		if datasourceConfigId == AdminConfig.showAttribute(cmpConnectorFactory, 'cmpDatasource'):
			cmpConnectionFactoryConfigId = cmpConnectorFactory
			break
	
	# updating CMP connector factory
	log('Updating CMP connector factory...') 
	AdminConfig.modify(cmpConnectionFactoryConfigId, [['authDataAlias', createDatasourceArgs['componentManagedAuthenticationAlias']],['xaRecoveryAuthAlias',createDatasourceArgs['xaRecoveryAuthAlias']]])
	
	# create mapping module for CMP connection factory
	log('Creating module mapping for CMP connection factory...')  
	AdminConfig.create('MappingModule', cmpConnectionFactoryConfigId, [['authDataAlias', containerManagedAuthenticationAlias], ['mappingConfigAlias', 'DefaultPrincipalMapping']])
	
	log('EXIT createdDatasource %s' % datasourceConfigId )
	return datasourceConfigId

def createJDBCProvider(createJDBCProviderArgs):
	log('ENTRY createJDBCProvider')
	log('Arguments: %s' % createJDBCProviderArgs) 
	providerConfigId = AdminTask.createJDBCProvider(["-%s \"%s\"" % (key, value) for key, value in createJDBCProviderArgs.items()])
	log('EXIT createJDBCProvider %s' % providerConfigId)  
	return providerConfigId

def deployEventService(eventServiceArgs, busMemberArgs, jmsAuthAliasArgs):
	log('ENTRY deployEventService')
	busMemberArgsAsString = " ".join(["-%s \"%s\"" % (key, value) for key, value in busMemberArgs.items()])
	eventServiceArgsAsString = " ".join(["-%s \"%s\"" % (key, value) for key, value in eventServiceArgs.items()])
	jmsAuthAliasArgsAsString = " ".join(["-%s \"%s\"" % (key, value) for key, value in jmsAuthAliasArgs.items()])
	log('Arguments (-eventService): %s' % eventServiceArgsAsString) 
	log('Arguments (-busMember): %s' % busMemberArgsAsString) 
	log('Arguments (-jmsAuthAlias): %s' % jmsAuthAliasArgsAsString)
	AdminTask.wbmDeployCEIEventService("[ -busMember [%s] -eventService [%s] -jmsAuthAlias [%s]]" % (busMemberArgsAsString, eventServiceArgsAsString, jmsAuthAliasArgsAsString))
	log('EXIT deployEventService')
	return

def getEnvironmentVariable(scope, name):
	return AdminTask.showVariables(['-scope', scope, '-variableName', name])

def log(s):
	print time.strftime('[%x %X %Z]'),'ResourceHelper',s
