#  Licensed Materials - Property of IBM
#  5724-M24
#  Copyright IBM Corporation 2007, 2012. All Rights Reserved.
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#

##################################################################
# Create resources needed by Monitor Server
# If Monitor Server is being installed on an
# ND deployment manager (dmgr), create a subset of the resources.
##################################################################

import sys
import os

# add the profile modules directory to the sys.path 
sys.path.append(os.path.normpath(os.path.join(os.getcwd(), 'scripts/modules')))

# import helper modules (found in the above profile modules directory)
import ResourceHelper

# "import" server common script
execfile(os.path.normpath(os.path.join(os.path.join(os.getcwd(), 'scripts/common'), 'MonitorServerUtil.py')))

# the following two lines are needed by the server common script
UtilWsadminHolder.AdminConfig = AdminConfig
UtilWsadminHolder.AdminTask = AdminTask

# import profile properties generated by the installer
profilePropertiesFile = os.path.normpath(os.path.join(sys.registry['user.install.root'], 'config.wbm/MonitorProfileVals.py')) 
print "Profile properties being loaded from %s" % profilePropertiesFile 
execfile(profilePropertiesFile)

if (isUTE == "true"):
	print "\n### Creating Monitor Server resources for Toolkit"
elif (ndType == "dmgr"):
	print "\n### Creating Monitor Server resources for deployment manager"
else:
	print "\n### Creating Monitor Server resources for standalone node"

# calculated values
cellName = AdminConfig.showAttribute(AdminConfig.list("Cell"), "name")
busName = "MONITOR.%s.Bus" % cellName
busAliasDesc = "Authentication for %s" % busName
dashboardGenAliasDesc = "Authentication for dashboard generation"

emitterFactoryInfo = EmitterFactoryInfo(emitterFactoryName, emitterFactoryJndi, emitterFactoryDesc, None, emitterFactorySyncJndi)
lifecycleWorkManagerInfo = WorkManagerInfo( lcwmName, lcwmJndi, lcwmDesc, lcwmMinThreads, lcwmMaxThreads, lcwmIsGrowable, lcwmThreadPriority, lcwmServiceNames)

# normalize the JDBC driver path
print "JDBC_DRIVER_PATH = %s" % JDBC_DRIVER_PATH
wasInstallRoot = os.path.normpath(sys.registry['was.install.root'])
print 'wasInstallRoot = %s' % wasInstallRoot
jdbcDriverPath = os.path.normpath(JDBC_DRIVER_PATH)
print 'jdbcDriverPath = %s' % jdbcDriverPath
jdbcDriverPath = jdbcDriverPath.replace(wasInstallRoot, '${WAS_INSTALL_ROOT}')
print 'jdbcDriverPath = %s' % jdbcDriverPath

# ############################################################
# # Handy vars for referencing various scopes
# ############################################################
scope = Scope(clusterName, cellName, nodeName, serverName)
cellScopeParameter = 'Cell=%s' % cellName
nodeScopeParameter = 'Node=%s' % nodeName
serverScopeParameter = 'Node=%s,Server=%s' % (nodeName, serverName)

# ############################################################
# # Create WebSphere environment variables
# ############################################################

# define WAS_INSTALL_ROOT as cell scope so 'Test Connection' works on cell scoped data sources
ResourceHelper.createEnvironmentVariable(cellScopeParameter, 'WAS_INSTALL_ROOT', wasInstallRoot)

# define the other variables at both cell and node scopes
for variableScope in (cellScopeParameter, nodeScopeParameter):
	ResourceHelper.createEnvironmentVariable(variableScope, 'WBM_JDBC_DRIVER_PATH', jdbcDriverPath)
	if DB2_JDBC_DRIVER_NATIVEPATH:
		ResourceHelper.createEnvironmentVariable(variableScope, 'DB2UNIVERSAL_JDBC_DRIVER_NATIVEPATH', DB2_JDBC_DRIVER_NATIVEPATH)
	if(wbmDBType in [S_COMMON_DB_DERBY_EMBEDDED]):
		pass # nothing to do here
	elif(wbmDBType in [S_COMMON_DB_DB2, S_COMMON_DB_DB2_ZOS, S_COMMON_DB_DB2_ZOS_8, S_COMMON_DB_DB2_ZOS_9]):
		if not ResourceHelper.getEnvironmentVariable(variableScope, 'DB2390_JDBC_DRIVER_PATH'):
			ResourceHelper.createEnvironmentVariable(variableScope, 'DB2390_JDBC_DRIVER_PATH', jdbcDriverPath)
		if not ResourceHelper.getEnvironmentVariable(variableScope, 'DB2UNIVERSAL_JDBC_DRIVER_PATH'):
			ResourceHelper.createEnvironmentVariable(variableScope, 'DB2UNIVERSAL_JDBC_DRIVER_PATH', jdbcDriverPath)
		if not ResourceHelper.getEnvironmentVariable(variableScope, 'UNIVERSAL_JDBC_DRIVER_PATH'):
			ResourceHelper.createEnvironmentVariable(variableScope, 'UNIVERSAL_JDBC_DRIVER_PATH', jdbcDriverPath)
#		if not ResourceHelper.getEnvironmentVariable(variableScope, 'DB2_JDBC_DRIVER_PATH'):
#			ResourceHelper.createEnvironmentVariable(variableScope, 'DB2_JDBC_DRIVER_PATH', jdbcDriverPath)
	elif(wbmDBType in [S_COMMON_DB_ORACLE_11g, S_COMMON_DB_ORACLE, "Oracle"]):
		if not ResourceHelper.getEnvironmentVariable(variableScope, 'ORACLE_JDBC_DRIVER_PATH'):
			ResourceHelper.createEnvironmentVariable(variableScope, 'ORACLE_JDBC_DRIVER_PATH', jdbcDriverPath)
	elif(wbmDBType in [S_COMMON_DB_MS_SQLSERVER]):
		if not ResourceHelper.getEnvironmentVariable(variableScope, 'MICROSOFT_JDBC_DRIVER_PATH'):
			ResourceHelper.createEnvironmentVariable(variableScope, 'MICROSOFT_JDBC_DRIVER_PATH', jdbcDriverPath)

# ############################################################
# # Create J2C authentication aliases
# ############################################################

busAuthAliasInfo = AuthAliasInfo(busAliasName, busAliasDesc, busAliasUsername, busAliasPassword)
qcfAuthAliasInfo = AuthAliasInfo(qcfAuthAliasName, qcfAuthAliasDesc, qcfAuthAliasUsername, qcfAuthAliasPassword)
eeAuthAliasInfo = AuthAliasInfo(eeAuthAliasName, eeAuthAliasDesc, eeAuthAliasUsername, eeAuthAliasPassword)
datasourceAuthAliasInfo = AuthAliasInfo(datasourceAuthAliasName, datasourceAuthAliasDesc, datasourceAuthAliasUsername, datasourceAuthAliasPassword)
adminDatasourceAuthAliasInfo = AuthAliasInfo(datasourceAdminAuthAliasName, datasourceAdminAuthAliasDesc, datasourceAuthAliasUsername, datasourceAuthAliasPassword)
dashboardGenAuthAliasInfo = AuthAliasInfo(dashboardGenAliasName, dashboardGenAliasDesc, busAliasUsername, busAliasPassword)

# create auth alias for monitor runtime datasource	
print "Create " + datasourceAuthAliasInfo.name + " if needed"
createAuthenticationAlias(datasourceAuthAliasInfo)

# create auth alias for monitor admin datasource	
print "Create " + adminDatasourceAuthAliasInfo.name + " if needed"
createAuthenticationAlias(adminDatasourceAuthAliasInfo)

# Create auth alias for Queue Connection Factories
print "Create " + qcfAuthAliasInfo.name + " if needed"
createAuthenticationAlias(qcfAuthAliasInfo)

# Create auth alias for Event Emitter
print "Create " + eeAuthAliasInfo.name + " if needed"
createAuthenticationAlias(eeAuthAliasInfo)

# Create auth alias for monitor bus
print "Create " + busAuthAliasInfo.name + " if needed"
createAuthenticationAlias(busAuthAliasInfo)

# Create auth alias for dashboard generation
print "Create " + dashboardGenAuthAliasInfo.name + " if needed"
createAuthenticationAlias(dashboardGenAuthAliasInfo)


# ############################################################
# # Create JDBC database providers
# ############################################################

# set common create database provider task arguments
createJDBCProviderArgs = {}
createJDBCProviderArgs["scope"] = cellScopeParameter
# createJDBCProviderArgs["classpath"] = jdbcProviderClassPath

# set database type specific create database provider task arguments
if(wbmDBType in [S_COMMON_DB_DERBY_EMBEDDED]):
	createJDBCProviderArgs["databaseType"] = "Derby"
	createJDBCProviderArgs["providerType"] = "Derby JDBC Provider"
	createJDBCProviderArgs["implementationType"] = "XA data source"
	#createJDBCProviderArgs["classpath"] = "${DERBY_JDBC_DRIVER_PATH}/derby.jar"
	#createJDBCProviderArgs["implementationClassName"] = "org.apache.derby.jdbc.EmbeddedXADataSource"
elif(wbmDBType in [S_COMMON_DB_DB2, S_COMMON_DB_DB2_ZOS, S_COMMON_DB_DB2_ZOS_8, S_COMMON_DB_DB2_ZOS_9]):
	createJDBCProviderArgs["databaseType"] = "DB2"
	createJDBCProviderArgs["providerType"] = "DB2 Universal JDBC Driver Provider"
	createJDBCProviderArgs["classpath"] = "${WBM_JDBC_DRIVER_PATH}/db2jcc4.jar;${WBM_JDBC_DRIVER_PATH}/db2jcc_license_cu.jar;${WBM_JDBC_DRIVER_PATH}/db2jcc_license_cisuz.jar"
	if(int(datasourceDriverType) == 4):
		createJDBCProviderArgs["implementationType"] = "XA data source"
	else:
		createJDBCProviderArgs["implementationType"] = "Connection Pool Data Source"			
	#createJDBCProviderArgs["classpath"] = "${DB2UNIVERSAL_JDBC_DRIVER_PATH}/db2jcc4.jar;${UNIVERSAL_JDBC_DRIVER_PATH}/db2jcc_license_cu.jar;${DB2UNIVERSAL_JDBC_DRIVER_PATH}/db2jcc_license_cisuz.jar"
	#createJDBCProviderArgs["nativePath"] = "${DB2UNIVERSAL_JDBC_DRIVER_NATIVEPATH}"
	#createJDBCProviderArgs["implementationClassName"] = "org.apache.derby.jdbc.EmbeddedXADataSource"
	# defect 629244 - removed
        #if(int(datasourceDriverType) == 4):
	#	createJDBCProviderArgs["isolated"] = "true"
	#	createJDBCProviderArgs["nativePath"] = ""              
elif(wbmDBType in [S_COMMON_DB_ORACLE_11g, S_COMMON_DB_ORACLE, "Oracle"]):
	createJDBCProviderArgs["databaseType"] = "Oracle"
	createJDBCProviderArgs["providerType"] = "Oracle JDBC Driver"
	createJDBCProviderArgs["implementationType"] = "XA data source"
	createJDBCProviderArgs["classpath"] = "${WBM_JDBC_DRIVER_PATH}/ojdbc6.jar"
	#createJDBCProviderArgs["classpath"] = "${ORACLE_JDBC_DRIVER_PATH}/ojdbc6.jar"
	#createJDBCProviderArgs["implementationClassName"] = "oracle.jdbc.xa.client.OracleXADataSource"
	# defect 629244 - removed
        #if(int(datasourceDriverType) == 4):
	#	createJDBCProviderArgs["isolated"] = "true"
	#	createJDBCProviderArgs["nativePath"] = ""  	
elif(wbmDBType in [S_COMMON_DB_MS_SQLSERVER]):
	createJDBCProviderArgs["databaseType"] = "SQL Server"
	createJDBCProviderArgs["providerType"] = "Microsoft SQL Server JDBC Driver"
	createJDBCProviderArgs["implementationType"] = "XA data source"
	createJDBCProviderArgs["classpath"] = "${WBM_JDBC_DRIVER_PATH}/sqljdbc4.jar"


# lookup existing business monitor jdbc database provider
providerConfigId = getJdbcProviderConfigId(scope, Scope.CELL_SCOPE, jdbcProviderName)

# if not found, create the business monitor jdbc database provider
if(not providerConfigId):
	createJDBCProviderArgs["name"] = jdbcProviderName
	createJDBCProviderArgs["description"] = jdbcProviderDesc
	providerConfigId = ResourceHelper.createJDBCProvider(createJDBCProviderArgs)

# create a second provider when the database type is DB2 for z/OS
if(wbmDBType in [S_COMMON_DB_DB2_ZOS, S_COMMON_DB_DB2_ZOS_8, S_COMMON_DB_DB2_ZOS_9]):
	
	# lookup existing jdbc database provider for DMS when using DB2 for z/OS
	dmsProviderConfigId = getJdbcProviderConfigId(scope, Scope.CELL_SCOPE, dmsJdbcProviderName)
	
	# if not found, create a jdbc database provider for DMS when using DB2 for z/OS
	if(not dmsProviderConfigId): 
		createDMSJDBCProviderArgs = {}
		createDMSJDBCProviderArgs["scope"] = cellScopeParameter
		createDMSJDBCProviderArgs["databaseType"] = "DB2"
		createDMSJDBCProviderArgs["providerType"] = "DB2 Universal JDBC Driver Provider"
		createDMSJDBCProviderArgs["implementationType"] = "Connection Pool Data Source"
		createDMSJDBCProviderArgs["classpath"] = "${WBM_JDBC_DRIVER_PATH}/db2jcc4.jar;${WBM_JDBC_DRIVER_PATH}/db2jcc_license_cu.jar;${WBM_JDBC_DRIVER_PATH}/db2jcc_license_cisuz.jar"
		createDMSJDBCProviderArgs["name"] = dmsJdbcProviderName
		createDMSJDBCProviderArgs["description"] = dmsJdbcProviderDesc
		dmsProviderConfigId = ResourceHelper.createJDBCProvider(createDMSJDBCProviderArgs)

# ############################################################
# # Create JDBC data sources
# ############################################################

# set common create datasource task arguments
createDatasourceArgs = {}
createDatasourceArgs["containerManagedPersistence"] = "true"


# set common create datasource task properties
createDatasourceProperties = []

# set common datasource connection pool attributes
connectionPoolAttributes = {}
connectionPoolAttributes['maxConnections'] = datasourceMaxConnections

# set common datasource custom properties
datasourceCustomProperties = {}
datasourceCustomProperties['webSphereDefaultIsolationLevel'] = 2

# set database type specific create datasource task arguments
if(wbmDBType in [S_COMMON_DB_DERBY_EMBEDDED]):
	createDatasourceArgs["dataStoreHelperClassName"] = "com.ibm.websphere.rsadapter.DerbyDataStoreHelper"	
elif(wbmDBType in [S_COMMON_DB_DB2, S_COMMON_DB_DB2_ZOS, S_COMMON_DB_DB2_ZOS_8, S_COMMON_DB_DB2_ZOS_9]):
	createDatasourceArgs["dataStoreHelperClassName"] = "com.ibm.websphere.rsadapter.DB2UniversalDataStoreHelper"	
elif(wbmDBType in [S_COMMON_DB_ORACLE_11g, S_COMMON_DB_ORACLE, "Oracle"]):
	#createDatasourceArgs["dataStoreHelperClassName"] = "com.ibm.websphere.rsadapter.Oracle10gDataStoreHelper"	
	createDatasourceArgs["dataStoreHelperClassName"] = "com.ibm.websphere.rsadapter.Oracle11gDataStoreHelper"	
elif(wbmDBType in [S_COMMON_DB_MS_SQLSERVER]):
	createDatasourceArgs["dataStoreHelperClassName"] = "com.ibm.websphere.rsadapter.MicrosoftSQLServerDataStoreHelper"
	
# set database type specific create datasource task properties
if(wbmDBType in [S_COMMON_DB_DERBY_EMBEDDED]):
	createDatasourceProperties.append(['databaseName', 'java.lang.String', '${USER_INSTALL_ROOT}/databases/%s' % (databaseName)])
elif(wbmDBType in [S_COMMON_DB_DB2]):
	createDatasourceProperties.append(['databaseName', 'java.lang.String' , databaseName])
	createDatasourceProperties.append(['driverType'  , 'java.lang.Integer', datasourceDriverType])
	createDatasourceProperties.append(['serverName'  , 'java.lang.String' , datasourceServerName])
	createDatasourceProperties.append(['portNumber'  , 'java.lang.Integer', datasourcePortNumber])
elif(wbmDBType in [S_COMMON_DB_DB2_ZOS, S_COMMON_DB_DB2_ZOS_8, S_COMMON_DB_DB2_ZOS_9]):
	createDatasourceProperties.append(['databaseName', 'java.lang.String' , subsystemName])
	createDatasourceProperties.append(['driverType'  , 'java.lang.Integer', datasourceDriverType])
	createDatasourceProperties.append(['serverName'  , 'java.lang.String' , datasourceServerName])
	createDatasourceProperties.append(['portNumber'  , 'java.lang.Integer', datasourcePortNumber])
elif(wbmDBType in [S_COMMON_DB_ORACLE_11g, S_COMMON_DB_ORACLE, "Oracle"]):
	createDatasourceProperties.append(['URL', 'java.lang.String', 'jdbc:oracle:%s:@//%s:%s/%s' % ({'2':'oci','4':'thin'}[datasourceDriverType], datasourceServerName, datasourcePortNumber, databaseName)]) 
elif(wbmDBType in [S_COMMON_DB_MS_SQLSERVER]):
	createDatasourceProperties.append(['databaseName', 'java.lang.String' , databaseName])
	createDatasourceProperties.append(['serverName'  , 'java.lang.String' , datasourceServerName])
	createDatasourceProperties.append(['portNumber'  , 'java.lang.Integer', datasourcePortNumber])
	datasourceCustomProperties['sendStringParametersAsUnicode'] = "true"


# create monitor runtime datasource 
if not getDatasourceConfigId(scope, Scope.CELL_SCOPE, jdbcProviderName, datasourceName):
	connectionPoolAttributes['testConnection'] = "false"
	createDatasourceArgs["name"] = datasourceName
	createDatasourceArgs["description"] =  datasourceDesc 
	createDatasourceArgs["jndiName"] = datasourceJndi
	createDatasourceArgs["componentManagedAuthenticationAlias"] = datasourceAuthAliasName
	createDatasourceArgs["xaRecoveryAuthAlias"] = datasourceAuthAliasName 
	datasourceConfigId = ResourceHelper.createDatasource(providerConfigId, createDatasourceArgs, createDatasourceProperties, connectionPoolAttributes, datasourceCustomProperties, datasourceAuthAliasName)

# create monitor admin datasource 
if not getDatasourceConfigId(scope, Scope.CELL_SCOPE, jdbcProviderName, adminDatasourceName):
	connectionPoolAttributes['testConnection'] = "false"
	createDatasourceArgs["name"] = adminDatasourceName
	createDatasourceArgs["description"] =  adminDatasourceDesc 
	createDatasourceArgs["jndiName"] = adminDatasourceJndi
	createDatasourceArgs["componentManagedAuthenticationAlias"] = datasourceAdminAuthAliasName
	createDatasourceArgs["xaRecoveryAuthAlias"] = datasourceAdminAuthAliasName 
	datasourceConfigId = ResourceHelper.createDatasource(providerConfigId, createDatasourceArgs, createDatasourceProperties, connectionPoolAttributes, datasourceCustomProperties, datasourceAdminAuthAliasName)

# create monitor messaging engine datasource 
if not getDatasourceConfigId(scope, Scope.CELL_SCOPE, jdbcProviderName, meDatasourceName):
	connectionPoolAttributes['testConnection'] = "false"
	createDatasourceArgs["name"] = meDatasourceName
	createDatasourceArgs["description"] =  meDatasourceDesc 
	createDatasourceArgs["jndiName"] = meDatasourceJndi
	createDatasourceArgs["componentManagedAuthenticationAlias"] = datasourceAuthAliasName
	createDatasourceArgs["xaRecoveryAuthAlias"] = datasourceAuthAliasName 
	datasourceConfigId = ResourceHelper.createDatasource(providerConfigId, createDatasourceArgs, createDatasourceProperties, connectionPoolAttributes, datasourceCustomProperties, datasourceAuthAliasName)

# create monitor queue bypass routing datasource 
if not getDatasourceConfigId(scope, Scope.CELL_SCOPE, jdbcProviderName, routingDatasourceName):
	connectionPoolAttributes['testConnection'] = "false"
	createDatasourceArgs["name"] = routingDatasourceName
	createDatasourceArgs["description"] =  routingDatasourceDesc 
	createDatasourceArgs["jndiName"] = routingDatasourceJndi
	createDatasourceArgs["componentManagedAuthenticationAlias"] = datasourceAuthAliasName
	createDatasourceArgs["xaRecoveryAuthAlias"] = datasourceAuthAliasName 
	datasourceConfigId = ResourceHelper.createDatasource(providerConfigId, createDatasourceArgs, createDatasourceProperties, connectionPoolAttributes, datasourceCustomProperties, datasourceAuthAliasName)

# create monitor DMS datasource for DB2 for z/OS 
if(wbmDBType == S_COMMON_DB_DB2_ZOS or wbmDBType == S_COMMON_DB_DB2_ZOS_8 or wbmDBType == S_COMMON_DB_DB2_ZOS_9):
	if not getDatasourceConfigId(scope, Scope.CELL_SCOPE, dmsJdbcProviderName, dmsDatasourceName):
		connectionPoolAttributes['testConnection'] = "false"
		createDatasourceArgs["name"] = dmsDatasourceName
		createDatasourceArgs["description"] =  dmsDatasourceDesc 
		createDatasourceArgs["jndiName"] = dmsDatasourceJndi
		createDatasourceArgs["componentManagedAuthenticationAlias"] = datasourceAuthAliasName
		createDatasourceArgs["xaRecoveryAuthAlias"] = datasourceAuthAliasName 
		datasourceConfigId = ResourceHelper.createDatasource(dmsProviderConfigId, createDatasourceArgs, createDatasourceProperties, connectionPoolAttributes, datasourceCustomProperties, datasourceAuthAliasName)

# ------------------------------------------------------------
# ------------------------------------------------------------
# ------------------------------------------------------------
    
if (ndType != "dmgr"):
	# Check for CEI
	# if it does not exist.  skip
	# else add our emitter profile
	if (getEmitterFactory(scope, Scope.CELL_SCOPE, emitterFactoryInfo.name) == None):
		print "Create " + emitterFactoryInfo.name + " if needed"
		createEmitterFactory(scope, Scope.CELL_SCOPE, emitterFactoryInfo)
	
# Check for Lifecycle WorkManager
# If it does not exist then create it.
if (getWorkManager(scope, Scope.CELL_SCOPE, lifecycleWorkManagerInfo.name) == None):
	print "Create " + lifecycleWorkManagerInfo.name + " if needed"
	createWorkManager(scope, Scope.CELL_SCOPE, lifecycleWorkManagerInfo)

AdminConfig.save()

# Set the statement cache size to zero for SQL Server
if(wbmDBType == S_COMMON_DB_MS_SQLSERVER):
	if getDatasourceConfigId(scope, Scope.CELL_SCOPE, jdbcProviderName, datasourceName):
		print "datasourceName %s" % datasourceName 
		newDS=AdminConfig.getid("/Cell:"+cellName+"/JDBCProvider:"+jdbcProviderName+"/DataSource:"+datasourceName+"/")
		AdminConfig.modify(newDS, '[[statementCacheSize "0"]]')
	if getDatasourceConfigId(scope, Scope.CELL_SCOPE, jdbcProviderName, adminDatasourceName):
		print "adminDatasourceName %s" % adminDatasourceName 
		newDS=AdminConfig.getid("/Cell:"+cellName+"/JDBCProvider:"+jdbcProviderName+"/DataSource:"+adminDatasourceName+"/")
		AdminConfig.modify(newDS, '[[statementCacheSize "0"]]')
	if getDatasourceConfigId(scope, Scope.CELL_SCOPE, jdbcProviderName, meDatasourceName):
		print "meDatasourceName %s" % meDatasourceName 
		newDS=AdminConfig.getid("/Cell:"+cellName+"/JDBCProvider:"+jdbcProviderName+"/DataSource:"+meDatasourceName+"/")
		AdminConfig.modify(newDS, '[[statementCacheSize "0"]]')
	if getDatasourceConfigId(scope, Scope.CELL_SCOPE, jdbcProviderName, routingDatasourceName):
		print "routingDatasourceName %s" % routingDatasourceName 
		newDS=AdminConfig.getid("/Cell:"+cellName+"/JDBCProvider:"+jdbcProviderName+"/DataSource:"+routingDatasourceName+"/")
		AdminConfig.modify(newDS, '[[statementCacheSize "0"]]')
	if getDatasourceConfigId(scope, Scope.CELL_SCOPE, jdbcProviderName, dmsDatasourceName):
		print "dmsDatasourceName %s" % dmsDatasourceName 
		newDS=AdminConfig.getid("/Cell:"+cellName+"/JDBCProvider:"+jdbcProviderName+"/DataSource:"+dmsDatasourceName+"/")
		AdminConfig.modify(newDS, '[[statementCacheSize "0"]]')
	AdminConfig.save()  


if((wbmDBType == S_COMMON_DB_DB2_ZOS or wbmDBType == S_COMMON_DB_DB2_ZOS_8 or wbmDBType == S_COMMON_DB_DB2_ZOS_9) and (int(datasourceDriverType) == 2)):
	print "datasourceDriverType %s" % datasourceDriverType 
	fullyMaterializeLobAttr = [["name", "fullyMaterializeLobData"], ["value", "false"], ["type", "java.lang.Boolean"]]
	if getDatasourceConfigId(scope, Scope.CELL_SCOPE, jdbcProviderName, datasourceName):
		print "datasourceName %s" % datasourceName 
		newDS=AdminConfig.getid("/Cell:"+cellName+"/JDBCProvider:"+jdbcProviderName+"/DataSource:"+datasourceName+"/")
		propertySet = AdminConfig.showAttribute(newDS,"propertySet")
		propertyList = AdminConfig.list("J2EEResourceProperty", propertySet).splitlines()
		for elem in propertyList:
			if (AdminConfig.showAttribute(elem,"name") == "fullyMaterializeLobData"):
				AdminConfig.modify(elem,fullyMaterializeLobAttr)
	if getDatasourceConfigId(scope, Scope.CELL_SCOPE, jdbcProviderName, adminDatasourceName):
		print "adminDatasourceName %s" % adminDatasourceName 
		newDS=AdminConfig.getid("/Cell:"+cellName+"/JDBCProvider:"+jdbcProviderName+"/DataSource:"+adminDatasourceName+"/")
		propertySet = AdminConfig.showAttribute(newDS,"propertySet")
		propertyList = AdminConfig.list("J2EEResourceProperty", propertySet).splitlines()
		for elem in propertyList:
			if (AdminConfig.showAttribute(elem,"name") == "fullyMaterializeLobData"):
				AdminConfig.modify(elem,fullyMaterializeLobAttr)
	if getDatasourceConfigId(scope, Scope.CELL_SCOPE, jdbcProviderName, meDatasourceName):
		print "meDatasourceName %s" % meDatasourceName 
		newDS=AdminConfig.getid("/Cell:"+cellName+"/JDBCProvider:"+jdbcProviderName+"/DataSource:"+meDatasourceName+"/")
		propertySet = AdminConfig.showAttribute(newDS,"propertySet")
		propertyList = AdminConfig.list("J2EEResourceProperty", propertySet).splitlines()
		for elem in propertyList:
			if (AdminConfig.showAttribute(elem,"name") == "fullyMaterializeLobData"):
				AdminConfig.modify(elem,fullyMaterializeLobAttr)
	if getDatasourceConfigId(scope, Scope.CELL_SCOPE, jdbcProviderName, routingDatasourceName):
		print "routingDatasourceName %s" % routingDatasourceName 
		newDS=AdminConfig.getid("/Cell:"+cellName+"/JDBCProvider:"+jdbcProviderName+"/DataSource:"+routingDatasourceName+"/")
		propertySet = AdminConfig.showAttribute(newDS,"propertySet")
		propertyList = AdminConfig.list("J2EEResourceProperty", propertySet).splitlines()
		for elem in propertyList:
			if (AdminConfig.showAttribute(elem,"name") == "fullyMaterializeLobData"):
				AdminConfig.modify(elem,fullyMaterializeLobAttr)
	if getDatasourceConfigId(scope, Scope.CELL_SCOPE, dmsJdbcProviderName, dmsDatasourceName):
		print "dmsDatasourceName %s" % dmsDatasourceName 
		newDS=AdminConfig.getid("/Cell:"+cellName+"/JDBCProvider:"+dmsJdbcProviderName+"/DataSource:"+dmsDatasourceName+"/")
		propertySet = AdminConfig.showAttribute(newDS,"propertySet")
		propertyList = AdminConfig.list("J2EEResourceProperty", propertySet).splitlines()
		for elem in propertyList:
			if (AdminConfig.showAttribute(elem,"name") == "fullyMaterializeLobData"):
				AdminConfig.modify(elem,fullyMaterializeLobAttr)
	AdminConfig.save()  

#Enable Application Security
security = AdminConfig.getid("/Cell:"+cellName+"/Security:/")
print "security="+str(security)
attr = ["appEnabled","true"]
properties = [attr]
AdminConfig.modify(security,properties)
AdminConfig.save()  

#Enable Run in development mode.
if (isUTE == "true"):
    serverCfgId = scope.getConfigId(Scope.SERVER_SCOPE)
    print "serverCfgId=" + serverCfgId
    attr = ["developmentMode","true"]
    properties = [attr]
    AdminConfig.modify(serverCfgId,properties)
    AdminConfig.save()

if (ndType != "dmgr"):

	# deploy CEI
	deployEventServiceBusMemberArgs = {}
	deployEventServiceBusMemberArgs["server"] = serverName
	deployEventServiceBusMemberArgs["node"] = nodeName
	if(msFileStore == "true"):
		deployEventServiceBusMemberArgs["fileStore"] = "true"
	else:
		deployEventServiceBusMemberArgs["createDefaultDatasource"] = "false"
		deployEventServiceBusMemberArgs["datasourceJndiName"] = meDatasourceJndi
		deployEventServiceBusMemberArgs["datasourceAuthAlias"] = datasourceAuthAliasName 
		deployEventServiceBusMemberArgs["databaseSchema"] = "MONCM00"
		if(wbmDBType == S_COMMON_DB_DB2_ZOS or wbmDBType.startswith(S_COMMON_DB_DB2_ZOS)):
			deployEventServiceBusMemberArgs["createTables"] = "false"
		else:
			deployEventServiceBusMemberArgs["createTables"] = "true"

	deployEventServiceEventServiceArgs = {}
	deployEventServiceEventServiceArgs["server"] = serverName
	deployEventServiceEventServiceArgs["node"] = nodeName
	
	deployEventServiceJMSAuthAliasArgs = {}
	deployEventServiceJMSAuthAliasArgs["user"] = busAliasUsername
	deployEventServiceJMSAuthAliasArgs["password"] = busAliasPassword
	
	ResourceHelper.deployEventService(deployEventServiceEventServiceArgs, deployEventServiceBusMemberArgs, deployEventServiceJMSAuthAliasArgs)
	#AdminTask.deployEventService("-serverName " + serverName)

	# Enable the startup bean service
	print "List all Services"
	allServicesString = AdminConfig.list("Service")
	allServicesArray = allServicesString.splitlines()

	serviceConfigId = None
	cellNodeServerString = "cells/" + cellName + "/nodes/" + nodeName + "/servers/" + serverName
	print "Checking Services for a match to StartupBeansService, and then to ", cellNodeServerString
	for i in range(len(allServicesArray)):
		if (allServicesArray[i].find("StartupBeansService") != -1):
			print "Found a StartupBeansService"
			if (allServicesArray[i].find(cellNodeServerString) != -1):
				print "Found the right StartupBeansService"
				serviceConfigId = allServicesArray[i]
	if (serviceConfigId != None):
		serviceEnableArgs = [["enable", "true"]]
		print "Modifying", serviceConfigId, "using", serviceEnableArgs
		AdminConfig.modify(serviceConfigId, serviceEnableArgs)

#Disable CEI Event datastore in production mode if it's not already set by others
if (ndType != "dmgr"):
    if(isWDPE != "true"):	
      if(ceiAlreadyDeployed != "true"):
        attr = None
        if(isUTE == "true"):
            attr = ["enableDataStore","true"]
        else:
            attr = ["enableDataStore","false"]
            
        print "attr ="+str(attr)    
        serverContainmentPath = scope.getContainmentPath(Scope.SERVER_SCOPE)
        ceiProvider = AdminConfig.getid(serverContainmentPath+"EventInfrastructureProvider:/")
        print "ceiProvider=" + ceiProvider
    
        esps = AdminConfig.list("EventServerProfile",ceiProvider).splitlines()
        print "esps="+str(esps)
        
        defaultESPJndiName = "com/ibm/events/configuration/event-server/Default"
        defaultESP = esps[0]
    
        for i in range(len(esps)):
            if(len(esps[i])>0): 
               jndiName = AdminConfig.showAttribute(esps[i],"jndiName")
               print "jndiName ="+jndiName
               if(jndiName == defaultESPJndiName):
                   defaultESP = esps[i]
                   break
        
        if(defaultESP != None):
            print "defaultESP="+defaultESP
            properties = [attr]
            AdminConfig.modify(defaultESP,properties)
            AdminConfig.save()  

#Set JVM initial and maximum heap size
if (ndType != "dmgr"):
    if (isUTE == "true"):
        setJVMHeapSize(scope, uteMinHeapSize, uteMaxHeapSize)
    else:
        setJVMHeapSize(scope, productionMinHeapSize, productionMaxHeapSize)
    AdminConfig.save()
else:
    setJVMHeapSize(scope, dmgrMinHeapSize, dmgrMaxHeapSize)
    AdminConfig.save()
