#***************************************************************
# Licensed Material - Property of IBM
#
# 5724-M24
#
# Copyright IBM Corp. 2008.  All rights reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM
# Corp.
#***************************************************************

import java
import sys

from java.util import ResourceBundle
from java.text import MessageFormat
from MessageBundleKeys import MessageBundleKeys as MBK
from WSAdminUtils import *
from Consts import Consts as CONSTS

ConfigObjectHolder.AdminApp = AdminApp
ConfigObjectHolder.AdminControl = AdminControl
ConfigObjectHolder.AdminConfig = AdminConfig
ConfigObjectHolder.AdminTask = AdminTask


def getMenuOption(title, options):
	choice = None
	
	while (choice == None):
		print CONSTS.SMALL_DIVIDER
		print
		print title
		for i in range(len(options)):
			print str(i+1) + ") " + str(options[i])
		
		choice = raw_input(MessageFormat.format(rb.getString(MBK.ENTER_MENU_SELECTION), [1, len(options)]))
		
		if ((not choice.isnumeric()) or (int(choice) < 1) or (int(choice) > len(options))):
			print rb.getString(MBK.INVALID_MENU_SELECTION)
			choice = None
		else:
			choice = int(choice)
	
	return choice

def doMainMenu():
	menuSelection = None
	
	while (menuSelection != 5):
		menuSelection = getMenuOption(rb.getString(MBK.MAIN_MENU_TITLE), [rb.getString(MBK.SHOW_ARCHIVING_STATUS), rb.getString(MBK.ENABLE_ARCHIVING), rb.getString(MBK.DISABLE_ARCHIVING), rb.getString(MBK.RELOAD_CEI), rb.getString(MBK.EXIT)])
	
		if (menuSelection == 1):
			showEventArchivingStatus()
		elif (menuSelection == 2):
			doEnableEventArchiving()
		elif (menuSelection == 3):
			doDisableEventArchiving()
		elif (menuSelection == 4):
			wsadmin.reloadCEIConfig()
			print
			print rb.getString(MBK.CEI_RELOADED)
			print CONSTS.SMALL_DIVIDER
			
		
def doEnableEventArchiving():
	menuSelection = None
	
	options = []
	
	while (menuSelection != len(options)):
		options = []

		eventGroupLists = wsadmin.getAllEventGroupLists()
		for eventGroupList in eventGroupLists:
			scope = wsadmin.determineScope(eventGroupList)
			archivingEventGroup = wsadmin.getArchivingEventGroup(eventGroupList)
			
			if (archivingEventGroup == None):
				# need to figure out if its not present and its not allowed to be present
				if (not wsadmin.canWASSupportEventArchiving(eventGroupList)):
					pass
					
				elif (not wsadmin.canWBMSupportEventArchiving(eventGroupList)):
					pass
					
				else:
					options.append(scope)
		
		
		options.append(rb.getString(MBK.DESIRED_CEI_NOT_IN_LIST))
		options.append(rb.getString(MBK.RETURN_TO_MAIN_MENU))
	
		menuSelection = getMenuOption(rb.getString(MBK.ENABLE_ARCHIVING_TITLE), options)
		
		if (menuSelection == (len(options)-1)):
			print
			print rb.getString(MBK.DESIRED_CEI_NOT_IN_LIST_HELP)
			print CONSTS.SMALL_DIVIDER
			
			showEventArchivingStatus()
			
		elif (menuSelection == len(options)):
			pass
			
		else:
			enablingScope = options[menuSelection-1]
			wsadmin.enableEventArchiving(enablingScope)
			
			print
			print MessageFormat.format(rb.getString(MBK.DONE_ENABLING), [str(enablingScope)])
			print CONSTS.SMALL_DIVIDER

def doDisableEventArchiving():
	menuSelection = None
	
	options = []
		
	while (menuSelection != len(options)):
		options = []

		eventGroupLists = wsadmin.getAllEventGroupLists()
		for eventGroupList in eventGroupLists:
			scope = wsadmin.determineScope(eventGroupList)
			archivingEventGroup = wsadmin.getArchivingEventGroup(eventGroupList)
			
			if (archivingEventGroup):
				options.append(scope)
		
		
		options.append(rb.getString(MBK.RETURN_TO_MAIN_MENU))
	
		menuSelection = getMenuOption(rb.getString(MBK.DISABLE_ARCHIVING_TITLE), options)
		
		if (menuSelection == len(options)):
			pass
			
		else:
			enablingScope = options[menuSelection-1]
			wsadmin.disableEventArchiving(enablingScope)
			
			print
			print MessageFormat.format(rb.getString(MBK.DONE_DISABLING), [str(enablingScope)])
			print CONSTS.SMALL_DIVIDER


def showEventArchivingStatus():
	print CONSTS.SMALL_DIVIDER
	print
	print rb.getString(MBK.EVENT_ARCHIVING_STATUS_TITLE)
	
	eventGroupLists = wsadmin.getAllEventGroupLists()
	counter = 1
	for eventGroupList in eventGroupLists:
		scope = wsadmin.determineScope(eventGroupList)
		archivingEventGroup = wsadmin.getArchivingEventGroup(eventGroupList)
		
		if (archivingEventGroup == None):
			# need to figure out if its not present and its not allowed to be present
			if (not wsadmin.canWASSupportEventArchiving(eventGroupList)):
				print str(counter) + ") " + str(scope) + " - " + rb.getString(MBK.ARCHIVING_WAS_TOO_OLD)
				
			elif (not wsadmin.canWBMSupportEventArchiving(eventGroupList)):
				print str(counter) + ") " + str(scope) + " - " + rb.getString(MBK.ARCHIVING_MONITOR_NOT_PRESENT)
				
			else:
				print str(counter) + ") " + str(scope) + " - " + rb.getString(MBK.ARCHIVING_DISABLED)
		else:
			print str(counter) + ") " + str(scope) + " - " + rb.getString(MBK.ARCHIVING_ENABLED)

		counter = counter+1
	
	print
	raw_input(rb.getString(MBK.PRESS_ANY_KEY))



if __name__ == "main":  # similar to "public static void main(String[] args)
	rb = ResourceBundle.getBundle(MBK.BUNDLE_NAME)
	wsadmin = WSAdminUtils()
	
	print rb.getString(MBK.TITLE)
	print CONSTS.LARGE_DIVIDER
	print
	doMainMenu()
	

