#  Licensed Materials - Property of IBM
#  5724-M24
#  Copyright IBM Corporation 2007, 2008. All Rights Reserved.
#  US Government Users Restricted Rights- Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
import sys, os, re
from java.lang import System
from win.path import removePathSpace
from util.system import commandExists,runCommand, commandSuccess
from com.ibm.wbmonitor.install.common.log import ILogger
from util.wbmlogger import WBMLogger

__all__ = []

CN = "uninstallutils"

def stopServer(profileDir, server):
   """Stop WAS servers: application server, node agent
      delopy manager
   """
   log = WBMLogger.log
   MN = "stopServer"

   shellExt = [".bat", ".sh"]
   binDir = os.path.join(profileDir, "bin")
   # -----------------------
   # | Application Server  |
   # -----------------------
   cmd = []
   cmd.append(os.path.join(binDir, "stopServer"))
   cmd.append(server)

   if (commandExists(cmd[0], shellExt)):
     System.out.print("Stop Application Server " +  server)
     rc = runCommand(cmd, 0, shellExt, [1.0])
     if (commandSuccess(rc)):
       print " successfully"
     else:
       print " failed"
     #process result: 
     #rc[0]: return code
     #rc[1]: stdout in a list
     #rc[2]: stderr in a list

   # -----------------------
   # | Node Agent          |
   # -----------------------
   cmd = []
   cmd.append(os.path.join(binDir, "stopNode"))

   if (commandExists(cmd[0], shellExt)):
     System.out.print("Stop Node Agent") 
     rc = runCommand(cmd, 0, shellExt)
     if (commandSuccess(rc)):
       print " successfully"
     else:
       print " failed"
     #process result: 
     #rc[0]: return code
     #rc[1]: stdout in a list
     #rc[2]: stderr in a list
     
   # -----------------------
   # | Deploy Manager      |
   # -----------------------
   cmd = []
   cmd.append(os.path.join(binDir, "stopDmgr"))

   if (commandExists(cmd[0], shellExt)):
     System.out.print("Stop Deploy Manager") 
     rc = runCommand(cmd, 0, shellExt)
     if (commandSuccess(rc)):
       print " successfully"
     else:
       print " failed"
     #process result: 
     #rc[0]: return code
     #rc[1]: stdout in a list
     #rc[2]: stderr in a list


   
def deleteProfile(profileDir, name):

   """uninstall profile with manageprofile
   """
   log = WBMLogger.log
   MN = "deleteProfile"
   shellExt = [".bat", ".sh"]


   binDir = os.path.join(profileDir, "bin")

   rc = getCellAndNode(binDir)
   foundCellNode = 0
   if (len(rc) > 0):
     cell=rc[0]
     node=rc[1]
     #print "Cell=",cell,",Node=",node
     foundCellNode = 1

   if (foundCellNode):
     cmd = [os.path.join(binDir, "manageprofiles"),
       "-delete", "-profileName", name, "-cellName",
       cell, "-nodeName", node]
     System.out.print("Delete profile " +  name)
     rc = runCommand(cmd, 0, shellExt, [1,0,0,0,0,0,0,0])
     if (commandSuccess(rc)):
       print " successfully"
     else:
       print " failed"
       mesg = "Check <WAS_HOME>/logs/manageprofiles/" + name + "_delete.log"
       print mesg
       log.msg(ILogger.TYPE_WARN, CN, MN, mesg)
     #process result: 
     #rc[0]: return code
     #rc[1]: stdout in a list
     #rc[2]: stderr in a list

     #validateAndUpdateRegistry
   else:
      print "can't find cell and node"
      #sys.exit(11)
  
def deleteFile(target, checkFlag):
 
   fileToRemove = target  

   if (System.getProperty("os.name").startswith("Windows")):
     cmd = ["del","/f", "/q"]
     fileToRemove = removePathSpace(fileToRemove)
   else:
     cmd = ["rm","-rf"]
     
   
   if (checkFlag and not os.path.exists(fileToRemove)):
     return [0, [],[]]
      
   cmd.append(fileToRemove)

   #print "" 
   #print "Delete ", fileToRemove
   rc = runCommand(cmd, 0, [])
   return commandSuccess(rc) 
     

def deleteDirectory(target, checkFlag):
 
   dirToRemove = target  

   if (System.getProperty("os.name").startswith("Windows")):
     cmd = ["rmdir","/s", "/q"]
     dirToRemove = removePathSpace(dirToRemove)
   else:
     cmd = ["rm","-rf"]
     
   
   if (checkFlag and not os.path.exists(dirToRemove)):
     return [0, [],[]]
      
   cmd.append(dirToRemove)

   rc = runCommand(cmd, 0, [])
   return commandSuccess(rc) 

  
def getCellAndNode(binPath):
  """Get call and node of current profile
     return a list with first item (rc[0]) is cell
     and the second item (rc[1]) is node. If error
     return []
  """

  log = WBMLogger.log
  MN = "getCellAndNode"
  import tempfile
  stdout = tempfile.mktemp()
  if (System.getProperty("os.name").startswith("Windows")):
    if (not os.path.exists(os.path.join(binPath,"setupCmdLine.bat"))):
      return []
    setupcmdline = os.path.join(binPath,"setupCmdLine.bat")
    setupcmdline = removePathSpace(setupcmdline)

    tmpCmd = os.path.join(System.getProperty("java.io.tmpdir"), "getcellandnode.bat")
    cmd = tmpCmd

    output = open(cmd, "w")
    output.write("@echo off\r\n")
    output.write("call ")
    output.write(setupcmdline)
    output.write("\r\n")
    output.write("echo %WAS_CELL%:%WAS_NODE%")
    output.close()
  else:
    if (not os.path.exists(os.path.join(binPath,"setupCmdLine.sh"))):
      return []
    cmd = ". " + os.path.join(binPath, "setupCmdLine.sh")
    cmd += "; echo ${WAS_CELL}:${WAS_NODE}"

  cmd += " > " + stdout

  log.msg(ILogger.TYPE_INFO, CN, MN, cmd)
  rc = os.system(cmd)
  if (System.getProperty("os.name").startswith("Windows")):
    os.remove(tmpCmd)
  result = "return code: " + str(rc)
  log.msg(ILogger.TYPE_INFO, CN, MN, result)
  if (rc != 0):
    return []

  input = open(stdout,"r")
  lines = input.readlines()
  input.close()
  os.remove(stdout)
  for line in lines:
    if (re.search(":", line)):
      items = line.split(":")
      if (len(items) != 2):
        return []
      else:
        items[0] = items[0].strip()
        items[1] = items[1].strip()
        log.msg(ILogger.TYPE_INFO, CN, MN, "Cell=" + items[0] + ", Node=" + items[1])
	return items
  return [] 


def moveFile(file, location):

  if (not os.path.exists(file)):
    return []

  if (not os.path.exists(location)):
    return []
  
  if (System.getProperty("os.name").startswith("Windows")):
    cmd = ["move", "/y", file, location]
  else:
    cmd = ["mv", "-f", file, location]

  rc = runCommand(cmd, 0, [])

  return commandSuccess(rc)


def deleteDirectoryHelp(dirName, flag):
  """Help function for deleting directory
     and process result
  """
  if (deleteDirectory(dirName, flag)):
    print " successfully"
  else:
    print " failed"

def deleteDirectoriesByPatternHelp(baseDirName, pattern, flag):
  """Help function for deleting directories based on pattern
     and process result
  """
  error = 0
  for i in os.listdir(baseDirName): 
    if (re.search(pattern, i)):
        wbmDir = os.path.join(baseDirName,i)
	if (not deleteDirectory(wbmDir, flag)):
          error += 1
  if (error == 0):
    print " successfully"
  else:
    print " failed"

def deleteFileHelp(fileName, flag):
  """Help function for deleting file
     and process result
  """
  if (deleteFile(fileName, flag)):
    print " successfully"
  else:
    print " failed"


def deleteDirsAndFiles(wasHome):

  """Delete monitor files and directories
  """

  print ""

  # ---------------------------------------
  # | Delete wbm lib under <WAS_HOME>/lib |
  # ---------------------------------------
  baseDir = os.path.join(wasHome,"lib")
  wbmLib = os.path.join(baseDir,"htmlshellwbm.jar")
  System.out.print("remove lib/htmlshellwbm.jar")
  deleteFileHelp(wbmLib, 0)

  wbmLib = os.path.join(baseDir,"wbminstall_util.jar")
  System.out.print("remove lib/wbminstall_util.jar")
  deleteFileHelp(wbmLib, 0)

  wbmLib = os.path.join(baseDir,"wbmMonitorSIBConfig.jar")
  System.out.print("remove lib/wbmwbmMonitorSIBConfig.jar")
  deleteFileHelp(wbmLib, 0)

  #wbmLib = os.path.join(baseDir,"wbminstall_log.jar")
  #System.out.print("remove lib/wbminstall_log.jar")
  #deleteFileHelp(wbmLib, 0)

  # ---------------------------------------
  # | Delete MonitorDataSecurity.war      |
  # | and wbmonitoradmin.war              |
  # ---------------------------------------
  baseDir = os.path.join(wasHome,"systemApps")
  baseDir = os.path.join(baseDir,"isclite.ear")

  warFile = os.path.join(baseDir,"MonitorDataSecurity.war")
  System.out.print("remove " + warFile)
  deleteDirectoryHelp(warFile, 1)

  warFile = os.path.join(baseDir,"wbmonitoradmin.war")
  System.out.print("remove " + warFile)
  deleteDirectoryHelp(warFile, 1)
   
   
  # ---------------------------------------
  # | Delete and file and direcotry has   |
  # | wbmonitor under <WAS_HOME>/plugins  |
  # ---------------------------------------
  baseDir = os.path.join(wasHome,"plugins")
  pluginsFiles = os.path.join(baseDir,"*.wbimonitor.*.jar")
  System.out.print("remove " + pluginsFiles)
  deleteFileHelp(pluginsFiles, 0)

  System.out.print("remove " + baseDir + "/*.wbimonitor.* directories")
  deleteDirectoriesByPatternHelp(baseDir, "\.wbimonitor\.", 0)


  # -------------------------------------------------
  # | Delete and file and direcotry has "wbm" under |
  # | <WAS_HOME>/bin/ProfileManagement              |
  # ------------------------------------------------|
  baseDir = os.path.join(wasHome,"bin")
  baseDir = os.path.join(baseDir,"ProfileManagement")

  pluginDir = os.path.join(baseDir,"plugins")
  pluginsFiles = os.path.join(pluginDir,"com.ibm.ws.pmt.wbm_6.1.0")
  System.out.print("remove " + pluginsFiles)
  deleteDirectoryHelp(pluginsFiles, 0)

  wbmDir = os.path.join(baseDir,"wbmonitor")
  System.out.print("remove " + wbmDir)
  deleteDirectoryHelp(pluginsFiles, 0)


  # -------------------------------------------------
  # | Delete and file and direcotry has "wbm" under |
  # | <WAS_HOME>/features	 	            |
  # ------------------------------------------------|
  baseDir = os.path.join(wasHome,"features")
  pluginsFiles = os.path.join(baseDir,"com.ibm.ws.monitor_6.1.0")
  System.out.print("remove " + pluginsFiles)
  deleteDirectoryHelp(pluginsFiles, 0)


  # ------------------------------------------------
  # | Delete any file and direcotry has "wbm." or  |
  # | "*.wbm.*" under <WAS_HOME>/properties        |
  # ------------------------------------------------
  baseDir = os.path.join(wasHome,"properties")
  baseDir = os.path.join(baseDir,"version")
  #1: version/install.wbm
  System.out.print("remove install.wbm")
  installWbm = os.path.join(baseDir,"install.wbm")
  deleteDirectoryHelp(installWbm, 0)

  #2: version/nif/components.wbm
  baseDir = os.path.join(baseDir,"nif")
  System.out.print("remove components.wbm")
  componentsWbm = os.path.join(baseDir,"components.wbm")
  deleteDirectoryHelp(componentsWbm, 0)

  System.out.print("remove componentmaps.wbm")
  componentmapsWbm = os.path.join(baseDir,"componentmaps.wbm")
  deleteDirectoryHelp(componentmapsWbm, 0)

  #3: version/nif/backup
  baseDir = os.path.join(baseDir,"backup")
  System.out.print("remove " + baseDir + "/*.wbm directories")
  deleteDirectoriesByPatternHelp(baseDir, "\.wbm$", 0)

  wbmFiles = os.path.join(baseDir,"wbm.*")
  System.out.print("remove " + wbmFiles)
  deleteFileHelp(wbmFiles, 0)

  wbmFiles = os.path.join(baseDir,"*.wbm.*")
  System.out.print("remove " + baseDir + "/*.wbm.* directories")
  deleteDirectoriesByPatternHelp(baseDir, "\.wbm\.", 0)
 

  # ------------------------------------------------
  # | Delete any directory has ".wbm" except       |
  # | scripts.wbm" under <WAS_HOME>                |
  # ------------------------------------------------
  
  System.out.print("remove " + wasHome + "/*.wbm except scripts.wbm")
  error = 0
  for i in os.listdir(wasHome): 
    if (re.search("\.wbm$", i) and (i != "scripts.wbm")):
        wbmDir = os.path.join(wasHome,i)
	if (not deleteDirectory(wbmDir, 0)):
          error += 1
  if (error == 0):
    print " successfully"
  else:
    print " failed"
        
  # ------------------------------------------------
  # | Delete any directory under <WAS_HOME>/       |
  # | scripts.wbm except cleanup                   |
  # ------------------------------------------------
  baseDir = os.path.join(wasHome,"scripts.wbm")
  System.out.print("remove directores  under " + baseDir + " except cleanup")
  error = 0
  for i in os.listdir(baseDir): 
    if (i != "cleanup"):
      wbmDir = os.path.join(baseDir,i)
      deleteDirectory(wbmDir, 1)
  if (error == 0):
    print " successfully"
  else:
    print " failed"
