#  Licensed Materials - Property of IBM
#  5724-M24
#  Copyright IBM Corporation 2007, 2008. All Rights Reserved.
#  US Government Users Restricted Rights- Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
from java.lang import String
from org.xml.sax.helpers import XMLFilterImpl
from xml.sax.saxutils import XMLGenerator,escape
import re


#Define constants for the two states we care about
ALLOW_CONTENT = 1
SUPPRESS_CONTENT = 2

class WBMXMLFilter(XMLFilterImpl):
    def __init__(self,upstream, downstream):
        XMLFilterImpl.__init__(self,upstream)
        self._downstream = downstream
	self._elements = []
	self._removeNewLine = "false"
        self._state_stack = []
        return


    def startDocument(self):
        #Set the initial state, and set up the stack of states
        self._state = ALLOW_CONTENT
        self._state_stack = [ALLOW_CONTENT]
        self._downstream.startDocument()
        return

    def startElement(self, uri, name, qName, attrs):

        if self._state == ALLOW_CONTENT:
	  for element in self._elements:
	    if (name == element):
              self._state = SUPPRESS_CONTENT
	      break

        self._state_stack.append(self._state)
          
        if self._state == ALLOW_CONTENT:
	    i = 0
	    myAttrs = {}
            while (i < attrs.getLength()):
	      myAttrs[attrs.getLocalName(i)] = attrs.getValue(i)
              i += 1
            self._downstream.startElement(name, myAttrs)
        return

    def endElement(self, uri, name, qName):
        self._state = self._state_stack.pop()
  	self._removeNewLine = "false"
        if self._state == ALLOW_CONTENT:
            self._downstream.endElement(name)
        else:
          self._state = self._state_stack[len(self._state_stack)-1]
	  self._removeNewLine = "true"
        return

    def characters(self, ch, start, len):
        #Only forward the event if the state warrants it
        if self._state == ALLOW_CONTENT:
	   content = String(ch, start,len) 
	   content = content.intern()
	   if (self._removeNewLine == "true"):
	     content = content.strip()
	   if (content != ""):
             self._downstream.characters(content)
	if self._removeNewLine == "true":
	   self._removeNewLine = "false"
        return


class WBMXMLGenerator(XMLGenerator):
  def __init__(self, out=None, encoding="iso-8859-1"):
    XMLGenerator.__init__(self, out, encoding)

  def startElement(self, name, attrs):
    self._out.write('<' + name)
    attrKeys = attrs.keys()
    attrKeys.sort()
    for i in attrKeys:
      self._out.write(' %s="%s"' % (i, escape(attrs[i])))
    self._out.write('>')




if __name__ == "__main__":
    print "Sample Usage"
    #import sys
    ##sys.argv[1]: WAS HOME
    ##sys.argv[2]: profileRigstry file name 
    #xmlReader = XMLReaderFactory.createXMLReader()
    #myout = open("my.xml", "w")
    ##downstream_handler = XMLGenerator(myout, "UTF-8")
    ##upstream, the parser, downstream, the next handler in the chain
    #filter_handler = ProcessProfileRegistry(sys.argv[1], parser, downstream_handler)
    ##The SAX filter base is designed so that the filter takes
    ##on much of the interface of the parser itself, including the
    ##"parse" method
    #filter_handler.parse(sys.argv[2])
    #myout.close()


