# Licensed Materials - Property of IBM
# 5724-M24
# Copyright IBM Corporation 2009,2011. All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

########################################################################
# Use the LifecycleServicesMBean to purge a model version 
# that is partially uninstalled
#
# Before running this script, verify that you have completed these steps:
# 1. Uninstall the enterprise application associated with the model version
# 2. Remove the Cognos cubes for the model version
# 3. Delete the schema for the model version
########################################################################

# Example: Running this script on Windows
#          Use forward slashes in the path specified by -wsadmin_classpath
# <PROFILE_DIR>\bin\wsadmin.bat 
#    -wsadmin_classpath "<WAS_DIR>\plugins\com.ibm.wbimonitor.lifecycle.spi.jar" 
#    -lang jython 
#    -f "<path_to_script>/purgeModelVersion.py" <MODEL_ID> <VERSION_DATE>

# Example: Running this script on Unix/Linux
# <PROFILE_DIR>/bin/wsadmin.sh 
#    -wsadmin_classpath "<WAS_DIR>/plugins/com.ibm.wbimonitor.lifecycle.spi.jar" 
#    -lang jython
#    -f "<path_to_script>/purgeModelVersion.py" <MODEL_ID> <VERSION_DATE>

from com.ibm.wbimonitor.lifecycle.spi import LifecycleVersionDate
from com.ibm.wbimonitor.lifecycle.spi import LifecycleConstants
from com.ibm.wbimonitor.lifecycle.spi.mbeans import LifecycleServicesMBeanFactory

################################################
# Function definition
################################################
def checkReturnCode (stepName, stepResult):
	rc = stepResult.getResultCode()
	msgList = stepResult.getMsgs()
	if rc == LifecycleConstants.SUCCESS:
		print '\n' + stepName + ' succeeded, rc=' + str(rc) + '...'
	elif rc == LifecycleConstants.WARNING:
		print '\n' + stepName + ' warning, rc=' + str(rc) + '...'
	else:
		print '\n' + stepName + ' failed, rc=' + str(rc) + '...'
	if msgList != None:
		msgCnt = 0
		for msg in msgList:
			msgCnt = msgCnt + 1
			print stepName + ' message ' + str(msgCnt) + ' = ' + msg

################################################
# Start doing work 
################################################

# get the model ID and version date
if sys.argv == None or len(sys.argv) < 2:
	print 'Model ID and version date must be passed to this script'
	print 'Stopping the script'
	sys.exit(1)
modelID = sys.argv[0]
versionDate = LifecycleVersionDate.parse( sys.argv[1] )

# verify that the model version has been partially uninstalled
print '\n'
print 'Before running this script, verify that you have completed these steps:'
print '1. Uninstall the enterprise application associated with the model version'
print '2. Remove the Cognos cubes for the model version' 
print '3. Delete the schema for the model version\n'
response = raw_input('Do you want to run this script now? (y or n)')
if response != 'y':
	print 'Stopping the script'
	sys.exit(1)

AdminControl.trace( 'com.ibm.wbimonitor.*=all=enabled' )

# get the MBean which will do the work
ls_mbean = LifecycleServicesMBeanFactory.getMBean( AdminControl.getAdminClient() )
print 'Monitor Version=' + ls_mbean.getMonitorVersion() + '\n'

# verify that the model version exists
ver = ls_mbean.listVersion( modelID, versionDate )
if ver == None:
	print 'Model [' + modelID + '] version [' + LifecycleVersionDate.format( versionDate ) + '] does not exist'
	sys.exit(1)

# remove the model version data from the database
result = ls_mbean.disableDashboards( modelID, versionDate )
checkReturnCode('disableDashboards', result)

# confirm that the model version has been uninstalled
result = ls_mbean.confirmUninstall( modelID, versionDate )
checkReturnCode('confirmUninstall', result)

# completely remove the model version metadata from the database
result = ls_mbean.unregister( modelID, versionDate )
checkReturnCode('unregister', result)

print 'The script has finished'

