#************************************************************************
#  Licensed Materials - Property of IBM
#  5724-M24
#  Copyright IBM Corporation 2007, 2010. All Rights Reserved.
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#
#************************************************************************

##################################################################
# Creates the bus for the Business Monitor server
# 
# wsadmin <wsadmin options> -f monitorSIBConfig.py [-cluster|-server] 
#                                                  [clusterName|nodeName serverName] 
# 
#                                                  [-datasourceJndiName jndiName]
#                                                  [-createDefaultDatasource true|false]
#                                                  [-createTables true|false]
#                                                  [-schemaName name]
# 
#                                                  [-filestoreLogDirectory dirName] 
#                                                  [-filestorePermanentStoreDirectory dirName] 
#                                                  [-filestoreTemporaryStoreDirectory dirName]
#
# If no parameters are provided, all required information will be requested 
# on the command line by the script.
#
# If cluster is chosen, the user must supply a cluster name and either the 
# jndiName of a datasource for the ME's database, or Log and Permanent 
# filestore parameters (Temporary defaults to the same as Permanent).
#
# If server is chosen, the user must supply the nodename and servername.  
# If no other parameters are given then the ME will use the filestore.  If the 
# filestore parameters are not supplied then the default filestore locations 
# will be used. A default Derby database and datasource can be used by 
# supplying the '-createDefaultDatasource true' option.  If a datasourceJndiName
# is supplied no datasource will be created.
# 
# NOTE: when supplying filestore locations as parameters '/' should be used as 
# the path separator rather than '\', even on Windows platforms.
#
# If filestore is chosen, users should tune the store sizes as appropriate 
# through normal administrative commands and interfaces.
#
# If you wish to use datastore then the Monitor_JDBC_Alias Authentication Alias
# must also exist.  This alias must grant access to the database used by the 
# Messaging Engine.  This alias is not required if using the default datasource.
# 
# -createTables is optional - it defaults to true
# -schemaName is optional
#
# The script will create the bus for the Business Monitor server, configure 
# bus security for the Monitor userid and create the ActionManager Queue.  
# 
# The Authentication Alias MonitorBusAuth MUST exist to execute this script.
# This Alias should be created when Monitor is installed. This alias is used
# by the Business Monitor server to connect to the bus to send and receive messgaes.
# 
# 
##################################################################
import java 
from com.ibm.ws.bootstrap import ExtClassLoader

##################################################################
# Utilities
###################################################################


###########################################################
# takes a message key and inserts for the mesasge and outputs a usage error
###########################################################
def usageError(errorKey, params=None):
    if (params == None):
        _usageError(getMessage(errorKey))
    else:
        _usageError(getMessage(errorKey, params))


###########################################################
# takes a String error and outputs a validation error with it.
###########################################################
def _usageError(error):
    print ""
    print "*************************************************************"
    print "* "+ getMessage("Incorrect_Usage",[error])
    print "*************************************************************"
    print ""
    print "wsadmin <wsadmin options> -f monitorSIBConfig.py [-cluster|-server]"
    print "                                                 [clusterName|nodeName serverName]"
    print "                                                 [-datasourceJndiName jndiName]" 
    print "                                                 [-createDefaultDatasource true|false]"
    print "                                                 [-createTables true|false]"
    print "                                                 [-schemaName name]"
    print "                                                 [-datasourceAuthAlias aliasName]"
    print "                                                 [-filestoreLogDirectory dirName]"
    print "                                                 [-filestorePermanentStoreDirectory dirName]"
    print "                                                 [-filestoreTemporaryStoreDirectory dirName]"
    print ""
    print ""
    raise ValueError(getMessage("Incorrect_Usage",[error]))
    

###########################################################
# takes a message key and inserts for the mesasge and outputs a validation error
###########################################################
def validationError (errorKey, params=None):
    if (params == None):
        _validationError(getMessage(errorKey))
    else:
        _validationError(getMessage(errorKey, params))

###########################################################
# takes a String error and outputs a validation error with it.
###########################################################
def _validationError(error):
    print ""
    print "*************************************************************"
    print "* "+getMessage("Validation_Failed",[error])
    print "*************************************************************"
    print ""
    raise ValueError(getMessage("Validation_Failed",[error]))


###########################################################
# gets a message with inserts from a message key wna inserts as an array
###########################################################
def getMessage(key, paramArray=None):
    if (paramArray==None):
        return bundle.getString(key)
    else:
        return java.text.MessageFormat.format(bundle.getString(key), paramArray)

###########################################################

thisLocale = java.util.Locale.getDefault()
bundleName = "wbm.monitorSIBConfig"
bundle = java.util.ResourceBundle.getBundle(bundleName, thisLocale, ExtClassLoader.getInstance())


True = 1==1
False = 1==0

MonitorBusAuth = "MonitorBusAuth"
Monitor_JDBC_Alias = "Monitor_JDBC_Alias"

###################################################################
# Variables
###################################################################

interactive=False
doCluster=False
doServer=False
doDatastore=False
doFilestore=False
createDefaultDatasource=False
createTables=True

datasourceJndiName=""
filestoreLogDirectory=""
filestorePermanentStoreDirectory=""
filestoreTemporaryStoreDirectory=""
busUserName = ""
qualifiedMonitorBusAuth = ""
qualifiedMonitor_JDBC_Alias = ""
schemaName = ""


###################################################################
# Check if the script is being run interactively
###################################################################
if ((len(sys.argv) == 0)):
        print getMessage("interactive")
        interactive = True
###################################################################
# Command line parameters passed in - evaluate
###################################################################
else:
    # Determine if cluster on server bus member is requested
    busMemberType = sys.argv[0]
###################################################################
# Validate Cluster parameters
###################################################################
    if (busMemberType == "-cluster"):
        if ((len(sys.argv) < 2)):
            usageError("specify_cluster_name")
        else:
            clusterName = sys.argv[1]
            clusterId=AdminConfig.getid("/ServerCluster:"+clusterName+"/")
            if (clusterId==""):
                validationError("cluster_not_exist",[clusterName])
            doCluster=True
            nextArg = 2

###################################################################
# Validate Server parameters
###################################################################
    elif (busMemberType == "-server"):
        if ((len(sys.argv) < 3)):
            usageError("specify_node_and_server")
        else:
            nodeName = sys.argv[1]
            serverName = sys.argv[2]
            nodeId=AdminConfig.getid("/Node:"+nodeName+"/")
            if (nodeId==""):
                validationError("node_not_exist", [nodeName])
            serverId=AdminConfig.getid("/Node:"+nodeName+"/Server:"+serverName+"/")
            if (serverId==""):
                validationError("server_not_exist", [nodeName,serverName])
            doServer=True
            nextArg = 3

###################################################################
# 
###################################################################
    else :
        usageError("specify_cluster_or_server")

###################################################################
# Validate filestore/datastore parameters
###################################################################
    while (len(sys.argv) > nextArg):
        param = sys.argv[nextArg]
        nextArg +=1

        if (len(sys.argv) <= nextArg):
            usageError("specify_value_for",[param])
        value = sys.argv[nextArg]
        nextArg +=1

        if (param == "-datasourceJndiName"):
            datasourceJndiName = value
            doDatastore=True
        elif (param == "-createDefaultDatasource"):
            doDatastore=True
            if (value == "true"):
                createDefaultDatasource=True
            elif (value == "false"):
                createDefaultDatasource=False
            else:
                usageError("unexpected_value_tf", ["-createDefaultDatasource",value])
        elif (param == "-datasourceAuthAlias"):
            doDatastore=True
            Monitor_JDBC_Alias = value
        elif (param == "-createTables"):
            doDatastore=True
            if (value == "true"):
                createTables=True
            elif (value == "false"):
                createTables=False
            else:
                usageError("unexpected_value_tf", ["-createTables",value])
        elif (param == "-schemaName"):
            schemaName = value
            doDatastore=True
        elif (param == "-filestoreLogDirectory"):
            filestoreLogDirectory = value
            doFilestore=True
            usefilestoredefaults=False
        elif (param == "-filestorePermanentStoreDirectory"):
            filestorePermanentStoreDirectory = value
            doFilestore=True
            usefilestoredefaults=False
        elif  (param == "-filestoreTemporaryStoreDirectory"):
            filestoreTemporaryStoreDirectory = value
            doFilestore=True
            usefilestoredefaults=False
        else:
            usageError("unknown_parameter",[param])

###################################################################
# Check that only filestore or datastore information has been set
###################################################################
    if (doDatastore & doFilestore):
        usageError("specify_filestore_or_datastore")

###################################################################
# If Clusters have been selected then datastore or filestore information must be specified
###################################################################
    if (doCluster):
        if ((doDatastore != True) & (doFilestore != True)):
            usageError("specify_fs_or_ds_for_cluster")
        if (doFilestore):
            #check that Log and Permanent have been defined
            if ((filestoreLogDirectory=="") | (filestorePermanentStoreDirectory=="")) :
                usageError("specify_fs_log_dirs_for_cluster")
        if (doDatastore):
            #check that a datasource jndi is specified and createDefaultDatasource is not specified
            if (datasourceJndiName == ""):
                usageError("specify_ds_for_cluster")
            if (createDefaultDatasource):
                usageError("default_ds_not_valid_on_cluster")

###################################################################
# Validate datastore options
###################################################################

    if (doDatastore):
        if (createDefaultDatasource):
            if (datasourceJndiName != ""):
                usageError("jndiname_not_valid_with_create_default_ds")
        else:
            if (datasourceJndiName == ""):
                usageError("specify_jndi_if_create_default_false")


###################################################################
# End of parsing passed parameters.
###################################################################

celllist = AdminConfig.list("Cell").splitlines()
cellid = celllist[0]
i= cellid.find('(')
cellName=cellid[0:i]
busName = "MONITOR."+cellName+".Bus"

###################################################################
# Check that the bus does not already exist
###################################################################

existingBus=AdminConfig.getid("/SIBus:"+busName+"/")

if (existingBus != ""):
    validationError("bus_already_exists",[busName])


###################################################################
# If script is being run interactively, query for values.
###################################################################



if (interactive):
    print getMessage("want_to_add_server_or_cluster")
    busMemberType = raw_input(getMessage("enter_server_or_cluster"))
    if (busMemberType==""):
        busMemberType="server"

###################################################################
# get Cluster information
###################################################################
    if (busMemberType == "cluster"):
        clusterlist = AdminConfig.list("ServerCluster").splitlines()
        if len(clusterlist)<1:
            validationError("no_clusters_exist")
        print getMessage("clusters_in_cell_are")
        defaultcname=""
        for clid in clusterlist:
            i= clid.find('(')
            name=clid[0:i]
            print name
            if (defaultcname==""):
                defaultcname=name

        print getMessage("enter_cluster_to_add")
        clusterName = raw_input(getMessage("hit_enter_to_accept_default",[defaultcname]))
        if (clusterName==""):
            clusterName=defaultcname
        else:
            clusterId=AdminConfig.getid("/ServerCluster:"+clusterName+"/")
            if (clusterId==""):
                validationError("cluster_not_exist",[clusterName])
        doCluster=True

###################################################################
# get server information
###################################################################
    elif (busMemberType == "server"):
        # list all nodes
        nodelist = AdminConfig.list("Node").splitlines()
        nodenamelist = []
        for nid in nodelist:
            i= nid.find('(')
            name=nid[0:i]
            # check that the node has appServers, if so add it to the list of possible nodes
            serverType = '[-serverType APPLICATION_SERVER -nodeName '+name+']'
            servers = AdminTask.listServers(serverType).splitlines()
            if (len(servers)>0):
                nodenamelist.append(name)
        # choose a node
        print getMessage("nodes_in_cell_are")
        for nn in nodenamelist:
            print nn
        print getMessage("enter_node_to_add")
        nodeName = raw_input(getMessage("hit_enter_to_accept_default",[nodenamelist[0]]))
        if (nodeName==""):
            nodeName=nodenamelist[0]
        else:
            nodeId=AdminConfig.getid("/Node:"+nodeName+"/")
            if (nodeId==""):
                validationError("node_not_exist",[nodeName])
        ##########################################################

        serverType = '[-serverType APPLICATION_SERVER -nodeName '+nodeName+']'
        serverlist = AdminTask.listServers(serverType).splitlines()
        print getMessage("servers_on_node",[nodeName])
        defaultsname=""
        for sid in serverlist:
            i= sid.find('(')
            name=sid[0:i]
            print name
            if (defaultsname==""):
                defaultsname=name
        print getMessage("enter_server_to_add")
        serverName = raw_input(getMessage("hit_enter_to_accept_default",[defaultsname]))
        if (serverName==""):
            serverName=defaultsname
        else:
            serverId=AdminConfig.getid("/Node:"+nodeName+"/Server:"+serverName+"/")
            if (serverId==""):
                validationError("server_not_exist_on_node", [serverName,nodeName])

        doServer=True

###################################################################
# not cluster or server - error
###################################################################
    else:
        usageError("specify_cluster_or_server_interactive")

###################################################################
# Get choice of filestore (default for server) or datastore (default for cluster)
###################################################################
    
    storeDefault=""
    if (doServer):
        storeDefault="filestore"
    elif (doCluster):
        storeDefault="datastore"

    print getMessage("filestore_or_datastore")
    storeinput = raw_input(getMessage("hit_enter_to_accept_default",[storeDefault]))
    if (storeinput == ""):
        storeinput = storeDefault

###################################################################
# Get datastore information
###################################################################
    if (storeinput == "datastore"):
        doDatastore=True
        if (doCluster):
            datasourceJndiName = raw_input(getMessage("enter_JNDI_name"))
            if (storeinput == ""):
                validationError("must_specify_jndi_name")
        else:
            #default datasource
            print getMessage("enter_JNDI_name")
            datasourceJndiName = raw_input(getMessage("hit_enter_for_derby"))
            if (datasourceJndiName == ""):
                createDefaultDatasource=True

        # schema name and create tables
        if (createDefaultDatasource == False):

            print getMessage("aliases_in_cell")
            aliasidlist = AdminConfig.list("JAASAuthData").splitlines()
            for aliasid in aliasidlist:
                qualifiedaliasName = AdminConfig.showAttribute(aliasid,"alias")
                print "  " + qualifiedaliasName

            print getMessage("enter_alias_name")
            aliasName = raw_input(getMessage("hit_enter_to_accept_default",[Monitor_JDBC_Alias]))
            if (aliasName!=""):
                Monitor_JDBC_Alias=aliasName            

            print getMessage("enter_schema_name")
            schemaName = raw_input(getMessage("hit_enter_for_default_no_value"))

            print getMessage("create_tables")
            input = raw_input(getMessage("enter_yes_or_no"))
            if ((input == "") | (input == "yes")):
                createTables = True
            elif ((input == "no")):
                createTables = False


###################################################################
# Get filestore info
# If server, allow the use of defaults. If cluster, always ask for values.
###################################################################
    elif (storeinput == "filestore"):
        askForFilestoreValues=True
        if (doServer):
            print getMessage("use_default_fs_locations")
            yesorno = raw_input(getMessage("enter_yes_or_no"))
            if ((yesorno == "") | (yesorno =="yes")):
                askForFilestoreValues=False

        if (askForFilestoreValues):
            # ask for log store path
            print getMessage("enter_log_path")
            filestoreLogDirectory = raw_input(": ")
            if (filestoreLogDirectory == ""):
                validationError("log_path_must_be_specified")

            # ask for permanent store path
            print getMessage("enter_perm_path")
            filestorePermanentStoreDirectory = raw_input(": ")
            if (filestorePermanentStoreDirectory == ""):
                validationError("perm_path_must_be_specified")

            # ask for temporary store path
            print getMessage("enter_temp_path")
            filestoreTemporaryStoreDirectory = raw_input(getMessage("hit_enter_for_same"))

        doFilestore=True
        
###################################################################
# Not filestore or datastore - error
###################################################################
    else:
        validationError(entry_not_valid, [storeinput])


###################################################################
# Validate required Authentication Aliases
###################################################################

aliasidlist = AdminConfig.list("JAASAuthData").splitlines()
for aliasid in aliasidlist:
    qualifiedaliasName = AdminConfig.showAttribute(aliasid,"alias")
    i= qualifiedaliasName.find('/')
    name=qualifiedaliasName[i+1:len(qualifiedaliasName)]
    if (name==MonitorBusAuth):
        busUserName = AdminConfig.showAttribute(aliasid,"userId")
        qualifiedMonitorBusAuth = qualifiedaliasName
if (busUserName ==""):
    validationError("auth_alias_must_exist ",[MonitorBusAuth])


# validate that the Monitor_JDBC_Alias exists.
# If not doing datastore then it is not needed
# if using the defaultDatasource it is not needed
if (doDatastore & (createDefaultDatasource != True)):
    foundBusJDBCAlias = False
    for aliasid in aliasidlist:
        qualifiedaliasName = AdminConfig.showAttribute(aliasid,"alias")
        i= qualifiedaliasName.find('/')
        name=qualifiedaliasName[i+1:len(qualifiedaliasName)]
        if (name==Monitor_JDBC_Alias):
            foundBusJDBCAlias = True
            qualifiedMonitor_JDBC_Alias = qualifiedaliasName
    if (foundBusJDBCAlias != True):
        validationError("datastore_auth_alias_must_exist" ,[Monitor_JDBC_Alias])

###################################################################
# All parameters should now be set and verified.  Configure the Bus
###################################################################

createBusArgs = ["-bus",busName,"-interEngineAuthAlias",qualifiedMonitorBusAuth,"-description","Bus for the Business Monitor server"]
print getMessage("creating_bus",[busName])
AdminTask.createSIBus(createBusArgs)


args = ["-bus",busName]
if (doCluster):
    args.append("-cluster")
    args.append(clusterName)
elif (doServer):
    args.append("-node")
    args.append(nodeName)
    args.append("-server")
    args.append(serverName)

if (doDatastore):
    args.append("-dataStore")
    if (createDefaultDatasource):
        args.append("-createDefaultDatasource")
        args.append("true")
    else:
        args.append("-createDefaultDatasource")
        args.append("false")
        args.append("-datasourceJndiName")
        args.append(datasourceJndiName)

        args.append("-createTables")
        if (createTables):
            args.append("true")
        else:
            args.append("false")

        if (schemaName != ""):
            args.append("-schemaName")
            args.append(schemaName)
        args.append("-authAlias")
        args.append(qualifiedMonitor_JDBC_Alias)
elif (doFilestore):
    args.append("-fileStore")
    if (filestoreLogDirectory != ""):
        args.append("-logDirectory")
        args.append(filestoreLogDirectory)
    if (filestorePermanentStoreDirectory != ""):
        args.append("-permanentStoreDirectory")
        args.append(filestorePermanentStoreDirectory)
    if (filestoreTemporaryStoreDirectory != ""):
        args.append("-temporaryStoreDirectory")
        args.append(filestoreTemporaryStoreDirectory)
    else:
        args.append("-temporaryStoreDirectory")
        args.append(filestorePermanentStoreDirectory)

print getMessage("adding_bus_member")
AdminTask.addSIBusMember(args)

destArgs=["-bus",busName,"-type","Queue","-name","ActionManagerQueueDestination","-description","Queue for Business Monitor Action Manager"]
if (doCluster):
    destArgs.append("-cluster")
    destArgs.append(clusterName)
elif (doServer):
    destArgs.append("-node")
    destArgs.append(nodeName)
    destArgs.append("-server")
    destArgs.append(serverName)
print getMessage("creating_action_services_dest")
AdminTask.createSIBDestination(destArgs)

###################################################################
# Configure security on the newly created bus
###################################################################
if (busUserName!="${adminUserName}"):
    print getMessage("configuring_bus_security",[MonitorBusAuth,busUserName])
    securityArgs=["-bus",busName,"-user",busUserName]
    AdminTask.addUserToBusConnectorRole(securityArgs)
    
###################################################################
# set the custom property to avoid issues with db users not 
# not authorized to use the trucate table command
###################################################################
msgEngineList=AdminTask.listSIBEngines("[-bus " + busName + "  ]").splitlines()
msgEngine = msgEngineList[0]
AdminConfig.create('Property', msgEngine, '[[name "sib.msgstore.jdbcUseDeleteInsteadOfTruncateAtStartup"] [description "Monitor"] [value "true"]]')


###################################################################
# Save the changes
###################################################################

print getMessage("saving_changes")
AdminConfig.save()
print getMessage("saved",[busName])




